<?php

$LANG = array(
    'organization' => 'Organização',
    'name' => 'Nome',
    'website' => 'Website',
    'work_phone' => 'Telefone',
    'address' => 'Morada',
    'address1' => 'Rua',
    'address2' => 'Complemento',
    'city' => 'Cidade',
    'state' => 'Distrito/Província',
    'postal_code' => 'Código Postal',
    'country_id' => 'País',
    'contacts' => 'Contatos',
    'first_name' => 'Primeiro Nome',
    'last_name' => 'Último Nome',
    'phone' => 'Telefone',
    'email' => 'E-mail',
    'additional_info' => 'Informações Adicionais',
    'payment_terms' => 'Condições de Pagamento',
    'currency_id' => 'Moeda',
    'size_id' => 'Tamanho da empresa',
    'industry_id' => 'Indústria',
    'private_notes' => 'Notas Privadas',
    'invoice' => 'Nota de Pagamento',
    'client' => 'Cliente',
    'invoice_date' => 'Data da NP',
    'due_date' => 'Data de Vencimento',
    'invoice_number' => 'Número NP',
    'invoice_number_short' => 'NP#',
    'po_number' => 'Núm. Ordem de Serviço',
    'po_number_short' => 'OS #',
    'frequency_id' => 'Frequência',
    'discount' => 'Desconto',
    'taxes' => 'Impostos',
    'tax' => 'Imposto',
    'item' => 'Item',
    'description' => 'Descrição',
    'unit_cost' => 'Custo Unitário',
    'quantity' => 'Quantidade',
    'line_total' => 'Total',
    'subtotal' => 'Subtotal',
    'paid_to_date' => 'Pago até à data',
    'balance_due' => 'Valor',
    'invoice_design_id' => 'Modelo',
    'terms' => 'Condições',
    'your_invoice' => 'A sua Nota de Pagamento',
    'remove_contact' => 'Remover contato',
    'add_contact' => 'Adicionar contato',
    'create_new_client' => 'Criar novo cliente',
    'edit_client_details' => 'Editar detalhes do cliente',
    'enable' => 'Ativar',
    'learn_more' => 'Saber mais',
    'manage_rates' => 'Gerir taxas',
    'note_to_client' => 'Observações',
    'invoice_terms' => 'Condições da Nota de Pagamento',
    'save_as_default_terms' => 'Guardar como condição padrão',
    'download_pdf' => 'Download PDF',
    'pay_now' => 'Pagar agora',
    'save_invoice' => 'Guardar Nota Pag.',
    'clone_invoice' => 'Clonar para fatura',
    'archive_invoice' => 'Arquivar Nota Pag.',
    'delete_invoice' => 'Apagar Nota Pag.',
    'email_invoice' => 'Enviar Nota Pag.',
    'enter_payment' => 'Introduzir Pag.',
    'tax_rates' => 'Impostos',
    'rate' => 'Valor',
    'settings' => 'Definições',
    'enable_invoice_tax' => 'Permitir especificar o <b>imposto da nota de pagamento</b>',
    'enable_line_item_tax' => 'Permitir especificar os <b>impostos por item</b>',
    'dashboard' => 'Dashboard',
    'dashboard_totals_in_all_currencies_help' => 'Note: add a :link named ":name" to show the totals using a single base currency.',
    'clients' => 'Clientes',
    'invoices' => 'Notas Pag.',
    'payments' => 'Pagamentos',
    'credits' => 'Créditos',
    'history' => 'Histórico',
    'search' => 'Pesquisa',
    'sign_up' => 'Registar',
    'guest' => 'Convidado',
    'company_details' => 'Detalhes da Empresa',
    'online_payments' => 'Pagamentos Online',
    'notifications' => 'Notificações',
    'import_export' => 'Importar/Exportar',
    'done' => 'Feito',
    'save' => 'Guardar',
    'create' => 'Criar',
    'upload' => 'Upload',
    'import' => 'Importar',
    'download' => 'Download',
    'cancel' => 'Cancelar',
    'close' => 'Fechar',
    'provide_email' => 'Forneça um endereço de e-mail válido',
    'powered_by' => 'Powered by',
    'no_items' => 'Sem itens',
    'recurring_invoices' => 'Notas de Pagamento Recorrentes',
    'recurring_help' => '<p>Automatically send clients the same invoices weekly, bi-monthly, monthly, quarterly or annually. </p>
        <p>Use :MONTH, :QUARTER or :YEAR for dynamic dates. Basic math works as well, for example :MONTH-1.</p>
        <p>Examples of dynamic invoice variables:</p>
        <ul>
          <li>"Gym membership for the month of :MONTH" >> "Gym membership for the month of July"</li>
          <li>":YEAR+1 yearly subscription" >> "2015 Yearly Subscription"</li>
          <li>"Retainer payment for :QUARTER+1" >> "Retainer payment for Q2"</li>
        </ul>',
    'recurring_quotes' => 'Recurring Quotes',
    'in_total_revenue' => 'no total de faturação',
    'billed_client' => 'Faturado ao cliente',
    'billed_clients' => 'Clientes faturados',
    'active_client' => 'Cliente ativo',
    'active_clients' => 'Clientes ativos',
    'invoices_past_due' => 'Notas de Pag. Vencidas',
    'upcoming_invoices' => 'Próximas Notas de Pag.',
    'average_invoice' => 'Média por Nota de Pag.',
    'archive' => 'Arquivar',
    'delete' => 'Apagar',
    'archive_client' => 'Arquivar Cliente',
    'delete_client' => 'Apagar Cliente',
    'archive_payment' => 'Arquivar Pagamento',
    'delete_payment' => 'Apagar Pagamento',
    'archive_credit' => 'Arquivar Crédito',
    'delete_credit' => 'Apagar Crédito',
    'show_archived_deleted' => 'Mostrar arquivados/apagados',
    'filter' => 'Filtrar',
    'new_client' => 'Novo Cliente',
    'new_invoice' => 'Nova Nota Pag.',
    'new_payment' => 'Introduzir Pagamento',
    'new_credit' => 'Introduzir Crédito',
    'contact' => 'Contato',
    'date_created' => 'Data de Criação',
    'last_login' => 'Último Login',
    'balance' => 'Saldo',
    'action' => 'Ação',
    'status' => 'Estado',
    'invoice_total' => 'Total da Nota de Pag.',
    'frequency' => 'Frequência',
    'range' => 'Range',
    'start_date' => 'Data Inicial',
    'end_date' => 'Data Final',
    'transaction_reference' => 'Referência da Transação',
    'method' => 'Método',
    'payment_amount' => 'Valor do Pagamento',
    'payment_date' => 'Data do Pagamento',
    'credit_amount' => 'Valor do Crédito',
    'credit_balance' => 'Balanço do Crédito',
    'credit_date' => 'Data do Crédito',
    'empty_table' => 'Sem dados disponíveis',
    'select' => 'Selecionar',
    'edit_client' => 'Editar Cliente',
    'edit_invoice' => 'Editar Nota Pag.',
    'create_invoice' => 'Criar Nota Pag.',
    'enter_credit' => 'Introduzir Crédito',
    'last_logged_in' => 'Último acesso em',
    'details' => 'Detalhes',
    'standing' => 'Resumo',
    'credit' => 'Crédito',
    'activity' => 'Atividade',
    'date' => 'Data',
    'message' => 'Mensagem',
    'adjustment' => 'Ajuste',
    'are_you_sure' => 'Tem a certeza?',
    'payment_type_id' => 'Tipo de pagamento',
    'amount' => 'Valor',
    'work_email' => 'E-mail',
    'language_id' => 'Idioma',
    'timezone_id' => 'Fuso Horário',
    'date_format_id' => 'Formato da Data',
    'datetime_format_id' => 'Formato da Data/Hora',
    'users' => 'Utilizadores',
    'localization' => 'Localização',
    'remove_logo' => 'Remover logo',
    'logo_help' => 'Suportados: JPEG, GIF and PNG',
    'payment_gateway' => 'Gateway de Pagamento',
    'gateway_id' => 'Gateway',
    'email_notifications' => 'Notificações por E-mail',
    'email_sent' => 'Notificar-me por e-mail quando a nota de pagamento for <b>enviada</b>',
    'email_viewed' => 'Notificar-me por e-mail quando a nota de pagamento for <b>visualizada</b>',
    'email_paid' => 'Notificar-me por e-mail quando a nota de pagamento for <b>paga</b>',
    'site_updates' => 'Atualizações',
    'custom_messages' => 'Mensagens personalizadas',
    'default_email_footer' => 'Definir assinatura de e-mail padrão',
    'select_file' => 'Por favor selecionar um arquivo',
    'first_row_headers' => 'Usar as primeiras linhas como cabeçalho',
    'column' => 'Coluna',
    'sample' => 'Exemplo',
    'import_to' => 'Importar para',
    'client_will_create' => 'será criado um cliente',
    'clients_will_create' => 'serão criados clientes',
    'email_settings' => 'Definições de E-mail',
    'client_view_styling' => 'Estilo de visualização do cliente',
    'pdf_email_attachment' => 'Attach PDF',
    'custom_css' => 'CSS Personalizado',
    'import_clients' => 'Importar Dados do Cliente',
    'csv_file' => 'Ficheiro CSV',
    'export_clients' => 'Exportar Dados do Cliente',
    'created_client' => 'Cliente criado com sucesso',
    'created_clients' => ':count clientes criados com sucesso',
    'updated_settings' => 'Definições atualizadas com sucesso',
    'removed_logo' => 'Logo removido com sucesso',
    'sent_message' => 'Mensagem enviada com sucesso',
    'invoice_error' => 'Verifique se selecionou um cliente e que não há nenhum outro erro',
    'limit_clients' => 'Desculpe, isto irá exceder o limite de :count clientes',
    'payment_error' => 'Ocorreu um erro ao processar o pagamento. Por favor tente novamente mais tarde.',
    'registration_required' => 'Inicie sessão para enviar uma nota de pagamento por e-mail',
    'confirmation_required' => 'Please confirm your email address, :link to resend the confirmation email.',
    'updated_client' => 'Cliente atualizado com sucesso',
    'archived_client' => 'Cliente arquivado com sucesso',
    'archived_clients' => ':count clientes arquivados com sucesso',
    'deleted_client' => 'Clientes removidos com sucesso',
    'deleted_clients' => ':count clientes removidos com sucesso',
    'updated_invoice' => 'Nota de Pagamento atualizada com sucesso',
    'created_invoice' => 'Nota de Pagamento criada com sucesso',
    'cloned_invoice' => 'Nota de Pagamento clonada com sucesso',
    'emailed_invoice' => 'Nota de Pagamento enviada por e-mail com sucesso',
    'and_created_client' => 'e o cliente foi criado',
    'archived_invoice' => 'Nota de Pagamento arquivado com sucesso',
    'archived_invoices' => ':count nota de pagamentos arquivados com sucesso',
    'deleted_invoice' => 'Nota de Pagamento apagados com sucesso',
    'deleted_invoices' => ':count nota de pagamentos apagados com sucesso',
    'created_payment' => 'Pagamento criado com sucesso',
    'created_payments' => ':count pagamento(s) criados com sucesso',
    'archived_payment' => 'Pagamento arquivado com sucesso',
    'archived_payments' => ':count pagamentos arquivados com sucesso',
    'deleted_payment' => 'Pagamento apagado com sucesso',
    'deleted_payments' => ':count pagamentos apagados com sucesso',
    'applied_payment' => 'Pagamentos aplicados com sucesso',
    'created_credit' => 'Crédito criado com sucesso',
    'archived_credit' => 'Crédito arquivado com sucesso',
    'archived_credits' => ':count créditos arquivados com sucesso',
    'deleted_credit' => 'Crédito apagado com sucesso',
    'deleted_credits' => ':count créditos apagados com sucesso',
    'imported_file' => 'Arquivo importado com sucesso',
    'updated_vendor' => 'Fornecedor atualizado com sucesso',
    'created_vendor' => 'Fornecedor criado com sucesso',
    'archived_vendor' => 'Fornecedor arquivado com sucesso',
    'archived_vendors' => ':count fornecedores arquivados com sucesso',
    'deleted_vendor' => 'Fornecedor removido com sucesso',
    'deleted_vendors' => ':count fornecedores removidos com sucesso',
    'confirmation_subject' => 'Confirmação de Conta do Invoice Ninja',
    'confirmation_header' => 'Confirmação de Conta',
    'confirmation_message' => 'Por favor clique no link abaixo para confirmar a sua conta.',
    'invoice_subject' => 'New invoice :number from :account',
    'invoice_message' => 'Para visualizar a sua nota de pagamento de :amount, clique no link abaixo.',
    'payment_subject' => 'Pagamento recebido',
    'payment_message' => 'Obrigado, pagamento de :amount confirmado',
    'email_salutation' => 'Caro :name,',
    'email_signature' => 'Atenciosamente,',
    'email_from' => 'Equipe InvoiceNinja',
    'invoice_link_message' => 'Para visualizar a nota de pagamento do seu cliente clique no link abaixo:',
    'notification_invoice_paid_subject' => 'Nota de Pagamento :invoice foi paga por :client',
    'notification_invoice_sent_subject' => 'Nota de Pagamento :invoice foi enviada por :client',
    'notification_invoice_viewed_subject' => 'Nota de Pagamento :invoice foi visualizada por :client',
    'notification_invoice_paid' => 'Um pagamento de :amount foi realizado pelo cliente :client através da nota de pagamento :invoice.',
    'notification_invoice_sent' => 'O cliente :client foi notificado por e-mail referente à nota de pagamento :invoice de :amount.',
    'notification_invoice_viewed' => 'O cliente :client visualizou a nota de pagamento :invoice de :amount.',
    'reset_password' => 'Pode redefinir a sua palavra-passe clicando no link seguinte:',
    'secure_payment' => 'Pagamento Seguro',
    'card_number' => 'Número do cartão',
    'expiration_month' => 'Mês de expiração',
    'expiration_year' => 'Ano de expiração',
    'cvv' => 'CVV',
    'logout' => 'Sair',
    'sign_up_to_save' => 'Faça login para guardar o seu trabalho',
    'agree_to_terms' => 'I agree to the :terms',
    'terms_of_service' => 'Condições do Serviço',
    'email_taken' => 'O endereço de e-mail já está registrado',
    'working' => 'Processando',
    'success' => 'Successo',
    'success_message' => 'Registou-se com sucesso. Por favor que no link de confirmação recebido para confirmar o seu endereço de e-mail.',
    'erase_data' => 'A sua conta não está registada, apagará todos os dados permanentemente.',
    'password' => 'Palavra-passe',
    'pro_plan_product' => 'Plano Profissional',
    'pro_plan_success' => 'Muito Obrigado! Assim que o pagamento for confirmado o seu plano será ativado.',
    'unsaved_changes' => 'Existem alterações não guardadas',
    'custom_fields' => 'Campos Personalizados',
    'company_fields' => 'Campos para Empresa',
    'client_fields' => 'Campos para Clientes',
    'field_label' => 'Nome do Campo',
    'field_value' => 'Valor do Campo',
    'edit' => 'Editar',
    'set_name' => 'Informe o nome da sua empresa',
    'view_as_recipient' => 'Visualizar como destinatário',
    'product_library' => 'Lista de Produtos',
    'product' => 'Produto',
    'products' => 'Produtos',
    'fill_products' => 'Sugerir produtos',
    'fill_products_help' => 'Selecionando o produto <b>descrição e preço</b> serão preenchidos automaticamente',
    'update_products' => 'Atualização automática dos produtos',
    'update_products_help' => 'Atualizando na nota de pagamento o <b>produto também será atualizado</b>',
    'create_product' => 'Criar Produto',
    'edit_product' => 'Editar Prodruto',
    'archive_product' => 'Arquivar Produto',
    'updated_product' => 'Produto atualizado',
    'created_product' => 'Produto criado',
    'archived_product' => 'Produto arquivado',
    'pro_plan_custom_fields' => ':link para ativar campos personalizados adquira o Plano Profissional',
    'advanced_settings' => 'Definições Avançadas',
    'pro_plan_advanced_settings' => ':link para ativar as definições avançadas adquira o Plano Profissional',
    'invoice_design' => 'Design das Nota Pag.',
    'specify_colors' => 'Definição de Cores',
    'specify_colors_label' => 'Selecione as cores para a sua nota de pagamento',
    'chart_builder' => 'Contrutor de Gráficos',
    'ninja_email_footer' => 'Created by :site | Create. Send. Get Paid.',
    'go_pro' => 'Adquira o Plano Pro',
    'quote' => 'Orçamento',
    'quotes' => 'Orçamentos',
    'quote_number' => 'Número do Orçamento',
    'quote_number_short' => 'Orçamento #',
    'quote_date' => 'Data do Orçamento',
    'quote_total' => 'Total do Orçamento',
    'your_quote' => 'Seu Orçamento',
    'total' => 'Total',
    'clone' => 'Clonar',
    'new_quote' => 'Novo Orçamento',
    'create_quote' => 'Criar Orçamento',
    'edit_quote' => 'Editar Orçamento',
    'archive_quote' => 'Arquivar Orçamento',
    'delete_quote' => 'Apagar Orçamento',
    'save_quote' => 'Guardar Oçamento',
    'email_quote' => 'Enviar Orçamento',
    'clone_quote' => 'Clone To Quote',
    'convert_to_invoice' => 'Converter em Nota de Pag.',
    'view_invoice' => 'Visualizar nota de pag.',
    'view_client' => 'Visualizar Cliente',
    'view_quote' => 'Visualizar Orçamento',
    'updated_quote' => 'Orçamento atualizado',
    'created_quote' => 'Orçamento criado',
    'cloned_quote' => 'Orçamento clonado',
    'emailed_quote' => 'Orçamento enviado',
    'archived_quote' => 'Orçamento aquivado',
    'archived_quotes' => ':count Orçamento(s) arquivado(s)',
    'deleted_quote' => 'Orçamento apagado',
    'deleted_quotes' => ':count Orçamento(s) apagados(s)',
    'converted_to_invoice' => 'Orçamento convertido em nota de pag,',
    'quote_subject' => 'New quote :number from :account',
    'quote_message' => 'Para visualizar o orçamento de :amount, clique no link abaixo.',
    'quote_link_message' => 'Para visualizar o orçamento clique no link abaixo',
    'notification_quote_sent_subject' => 'Orçamento :invoice enviado para :client',
    'notification_quote_viewed_subject' => 'Orçamento :invoice visualizado por :client',
    'notification_quote_sent' => 'O cliente :client recebeu o Orçamento :invoice de:amount.',
    'notification_quote_viewed' => 'O cliente :client visualizou o Orçamento :invoice de :amount.',
    'session_expired' => 'Sessão expirada.',
    'invoice_fields' => 'Campos da Nota Pag.',
    'invoice_options' => 'Opções da Nota Pag.',
    'hide_paid_to_date' => 'Ocultar data de pagamento',
    'hide_paid_to_date_help' => 'Apenas mostrar a "Data de Pagamento" quanto o pagamento tiver sido efetuado.',
    'charge_taxes' => 'Impostos',
    'user_management' => 'Gerir utilizadores',
    'add_user' => 'Adicionar utilizadores',
    'send_invite' => 'Enviar convite',
    'sent_invite' => 'Convite enviado',
    'updated_user' => 'Utilizador atualizado',
    'invitation_message' => 'Recebeu um convite de :invitor. ',
    'register_to_add_user' => 'Registe-se para adicionar um utilizador',
    'user_state' => 'Distrito',
    'edit_user' => 'Editar Utilizador',
    'delete_user' => 'Apagar Utilizador',
    'active' => 'Ativo',
    'pending' => 'Pendente',
    'deleted_user' => 'Utilizador apagado',
    'confirm_email_invoice' => 'Deseja enviar esta nota de pagamento?',
    'confirm_email_quote' => 'Deseja enviar este orçamento?',
    'confirm_recurring_email_invoice' => 'Deseja enviar esta nota de pagamento?',
    'confirm_recurring_email_invoice_not_sent' => 'Are you sure you want to start the recurrence?',
    'cancel_account' => 'Cancelar Conta',
    'cancel_account_message' => 'Aviso: Irá apagar permanentemente a sua conta.',
    'go_back' => 'Voltar',
    'data_visualizations' => 'Visualização de Dados',
    'sample_data' => 'Dados de Exemplo',
    'hide' => 'Ocultar',
    'new_version_available' => 'Uma nova versão :releases_link está disponível. A sua versão é v:user_version, a última versão é v:latest_version',
    'invoice_settings' => 'Configuração das Notas de Pagamento',
    'invoice_number_prefix' => 'Prefixo na Numeração das Notas de Pagamento',
    'invoice_number_counter' => 'Numeração das Notas de Pagamento',
    'quote_number_prefix' => 'Prefixo na Numeração dos Orçamentos',
    'quote_number_counter' => 'Numeração dos Orçamentos',
    'share_invoice_counter' => 'Usar numeração das nota de pagamentos',
    'invoice_issued_to' => 'Nota de Pagamento emitida para',
    'invalid_counter' => 'Para evitar conflitos defina prefixos de numeração para Notas de Pagamento e Orçamentos',
    'mark_sent' => 'Marcar como Enviada',
    'gateway_help_1' => ':link para registar Authorize.net.',
    'gateway_help_2' => ':link para registar Authorize.net.',
    'gateway_help_17' => ':link para adquirir a sua "PayPal API signature".',
    'gateway_help_27' => ':link registe-se no 2Checkout.com. Para garantir o rastreamento dos pagamentos configure o  :complete_link como URL de redirecionamento em Account > Site Management in the 2Checkout portal.',
    'gateway_help_60' => ':link to create a WePay account.',
    'more_designs' => 'Mais Modelos',
    'more_designs_title' => 'Modelos Adicionais',
    'more_designs_cloud_header' => 'Adquira o Plano Pro para mais modelos',
    'more_designs_cloud_text' => '',
    'more_designs_self_host_text' => '',
    'buy' => 'Comprar',
    'bought_designs' => 'Novos Modelos Adicionados',
    'sent' => 'Sent',
    'vat_number' => 'NIF',
    'timesheets' => 'Folha de horas',
    'payment_title' => 'Indique a morada de faturação e as informações do Cartão de Crédito',
    'payment_cvv' => '*This is the 3-4 digit number on the back of your card',
    'payment_footer1' => '*A morada de faturação deve ser igual à morada associada ao Cartão de Crédito.',
    'payment_footer2' => '*Clique em "Pagar Agora" apenas uma vez - esta operação pode levar até 1 Minuto para ser processada.',
    'id_number' => 'ID Number',
    'white_label_link' => 'White Label',
    'white_label_header' => 'White Label',
    'bought_white_label' => 'Licença "white label" ativada',
    'white_labeled' => 'White labeled',
    'restore' => 'Restaurar',
    'restore_invoice' => 'Restaurar Nota Pag.',
    'restore_quote' => 'Restaurar Orçamento',
    'restore_client' => 'Restaurar Cliente',
    'restore_credit' => 'Restaurar Crédito',
    'restore_payment' => 'Restaurar Pagamento',
    'restored_invoice' => 'Nota de Pagamento restaurada',
    'restored_quote' => 'Orçamento restaurado',
    'restored_client' => 'Cliente restaurado',
    'restored_payment' => 'Pagamento restaurado',
    'restored_credit' => 'Crédito restaurado',
    'reason_for_canceling' => 'Ajude-nos a melhorar, envie suas sugestões.',
    'discount_percent' => '%',
    'discount_amount' => 'Valor',
    'invoice_history' => 'Histórico de Notas de Pagamento',
    'quote_history' => 'Histórico de Orçamentos',
    'current_version' => 'Versão Atual',
    'select_version' => 'Selecionar versão',
    'view_history' => 'Visualizar Histórico',
    'edit_payment' => 'Editar Pagamento',
    'updated_payment' => 'Pagamento atualizado',
    'deleted' => 'Apagado',
    'restore_user' => 'Restaurar Utilizador',
    'restored_user' => 'Utilizador restaurado',
    'show_deleted_users' => 'Mostrar utilizadores apagados',
    'email_templates' => 'Modelo de E-mail',
    'invoice_email' => 'E-mail para Notas de Pag.',
    'payment_email' => 'E-mail para Pagamentos',
    'quote_email' => 'E-mail para Orçamentos',
    'reset_all' => 'Redifinir Todos',
    'approve' => 'Aprovar',
    'token_billing_type_id' => 'Token de Cobrança',
    'token_billing_help' => 'Store payment details with WePay, Stripe, Braintree or GoCardless.',
    'token_billing_1' => 'Desativado',
    'token_billing_2' => 'A checkbox de Opt-in está visível mas não seleccionada',
    'token_billing_3' => 'A checkbox de Opt-out está visível e seleccionada',
    'token_billing_4' => 'Sempre',
    'token_billing_checkbox' => 'Guardar detalhes do cartão',
    'view_in_gateway' => 'Ver em :gateway',
    'use_card_on_file' => 'Utilizar Cartão em Arquivo',
    'edit_payment_details' => 'Editar detalhes do pagamento',
    'token_billing' => 'Guardar detalhes do cartão',
    'token_billing_secure' => 'Dados armazenados com seguração por :link',
    'support' => 'Suporte',
    'contact_information' => 'Informações de Contato',
    '256_encryption' => 'Criptografia de 256-Bit',
    'amount_due' => 'Valor em dívida',
    'billing_address' => 'Morada de faturação',
    'billing_method' => 'Tipo de pagamento',
    'order_overview' => 'Geral',
    'match_address' => '*A morada de faturação deve ser igual à morada associada ao Cartão de Crédito.',
    'click_once' => '*Clique em "Pagar Agora" apenas uma vez - esta operação pode levar até 1 Minuto para processar.',
    'invoice_footer' => 'Rodapé da Nota Pag.',
    'save_as_default_footer' => 'Guardar como rodapé padrão',
    'token_management' => 'Gerir Token',
    'tokens' => 'Tokens',
    'add_token' => 'Adicionar Token',
    'show_deleted_tokens' => 'Mostrar tokents apagados',
    'deleted_token' => 'Token apagado',
    'created_token' => 'Token criado',
    'updated_token' => 'Token atualizado',
    'edit_token' => 'Editat Token',
    'delete_token' => 'Apagar Token',
    'token' => 'Token',
    'add_gateway' => 'Adicionar Gateway',
    'delete_gateway' => 'Apagar Gateway',
    'edit_gateway' => 'Editar Gateway',
    'updated_gateway' => 'Gateway atualizado',
    'created_gateway' => 'Gateway Criado',
    'deleted_gateway' => 'Gateway Apagado',
    'pay_with_paypal' => 'PayPal',
    'pay_with_card' => 'Cartão de Crédito',
    'change_password' => 'Alterar palavra-passe',
    'current_password' => 'Palavra-passe atual',
    'new_password' => 'Nova palavra-passe',
    'confirm_password' => 'Confirmar palavra-passe',
    'password_error_incorrect' => 'Palavra-passe atual incorreta.',
    'password_error_invalid' => 'Nova palavra-passe inválida.',
    'updated_password' => 'Palavra-passe atualizada',
    'api_tokens' => 'API Tokens',
    'users_and_tokens' => 'Utilizadores & Tokens',
    'account_login' => 'Iniciar sessão',
    'recover_password' => 'Recuperar palavra-passe',
    'forgot_password' => 'Esqueceu-se da palavra-passe?',
    'email_address' => 'E-mail',
    'lets_go' => 'Vamos!',
    'password_recovery' => 'Recuperar palavra-passe',
    'send_email' => 'Enviar email',
    'set_password' => 'Definir palavra-passe',
    'converted' => 'Convertido',
    'email_approved' => 'Notificar-me por e-mail quando um orçamento for <b>aprovado</b>',
    'notification_quote_approved_subject' => 'Orçamento :invoice foi aprovado por :client',
    'notification_quote_approved' => 'O cliente :client aprovou o Orçamento :invoice de :amount.',
    'resend_confirmation' => 'Reenviar e-mail de confirmação',
    'confirmation_resent' => 'E-mail de confirmação reenviado',
    'gateway_help_42' => ':link aceder BitPay.<br/>Aviso: use a "Legacy API Key", não "API token".',
    'payment_type_credit_card' => 'Cartão de Crédito',
    'payment_type_paypal' => 'PayPal',
    'payment_type_bitcoin' => 'Bitcoin',
    'payment_type_gocardless' => 'GoCardless',
    'knowledge_base' => 'Base de Conhecimento',
    'partial' => 'Depósito/Parcial',
    'partial_remaining' => ':partial de :balance',
    'more_fields' => 'Mais Campos',
    'less_fields' => 'Menos Campos',
    'client_name' => 'Client Name',
    'pdf_settings' => 'Definições do PDF',
    'product_settings' => 'Definições de Produtos',
    'auto_wrap' => 'Quebrar Linhas',
    'duplicate_post' => 'Atenção: a página anterior foi enviada duas vezes. A segunda vez foi ignorada.',
    'view_documentation' => 'Ver Documentação',
    'app_title' => 'Free Open-Source Online Invoicing',
    'app_description' => 'O Invoice Ninja é uma solução gratuita e open-source para faturar e cobrar serviços e produtos a clientes. Com o Invoice Ninja, poderá criar fácilmente faturas atrativas através de qualquer dispositivo que tenha acesso à internet. Os seus clientes podem imprimir as suas faturas, transferir como PDF e até mesmo pagar online dentro do sistema.',
    'rows' => 'linhas',
    'www' => 'www',
    'logo' => 'Logo',
    'subdomain' => 'Subdomínio',
    'provide_name_or_email' => 'Indique um nome ou email',
    'charts_and_reports' => 'Gráficos & Relatórios',
    'chart' => 'Gráfico',
    'report' => 'Relatório',
    'group_by' => 'Agrupado por',
    'paid' => 'Pago',
    'enable_report' => 'Relatório',
    'enable_chart' => 'Gráfico',
    'totals' => 'Totais',
    'run' => 'Executar',
    'export' => 'Exportar',
    'documentation' => 'Documentação',
    'zapier' => 'Zapier',
    'recurring' => 'Recorrente',
    'last_invoice_sent' => 'Última cobrança enviada a :date',
    'processed_updates' => 'Atualização completa',
    'tasks' => 'Tarefas',
    'new_task' => 'Nova Tarefa',
    'start_time' => 'Início',
    'created_task' => 'Tarefa criada',
    'updated_task' => 'Tarefa atualizada',
    'edit_task' => 'Editar Tarefa',
    'clone_task' => 'Clone Task',
    'archive_task' => 'Arquivar Tarefa',
    'restore_task' => 'Restaurar Tarefa',
    'delete_task' => 'Apagar Tarefa',
    'stop_task' => 'Parar Tarefa',
    'time' => 'Tempo',
    'start' => 'Iniciar',
    'stop' => 'Parar',
    'now' => 'Agora',
    'timer' => 'Temporizador',
    'manual' => 'Manual',
    'date_and_time' => 'Data & Hora',
    'second' => 'Second',
    'seconds' => 'Seconds',
    'minute' => 'Minute',
    'minutes' => 'Minutes',
    'hour' => 'Hour',
    'hours' => 'Hours',
    'task_details' => 'Detalhes da Tarefa',
    'duration' => 'Duração',
    'time_log' => 'Time Log',
    'end_time' => 'Final',
    'end' => 'Fim',
    'invoiced' => 'Faturado',
    'logged' => 'Em aberto',
    'running' => 'Em execução',
    'task_error_multiple_clients' => 'Tarefas não podem pertencer a clientes diferentes',
    'task_error_running' => 'Parar as tarefas em execução',
    'task_error_invoiced' => 'Tarefa já faturada',
    'restored_task' => 'Tarefa restaurada',
    'archived_task' => 'Tarefa arquivada',
    'archived_tasks' => ':count Tarefas arquivadas',
    'deleted_task' => 'Tarefa apagada',
    'deleted_tasks' => ':count Tarefas apagadas',
    'create_task' => 'Criar Tarefa',
    'stopped_task' => 'Tarefa interrompida',
    'invoice_task' => 'Faturar Tarefa',
    'invoice_labels' => 'Etiquetas das Notas de Pag.',
    'prefix' => 'Prefixo',
    'counter' => 'Contador',
    'payment_type_dwolla' => 'Dwolla',
    'gateway_help_43' => ':link aceder Dwolla.',
    'partial_value' => 'Deve ser maior que zero e menor que o total',
    'more_actions' => 'Mais ações',
    'pro_plan_title' => 'NINJA PRO',
    'pro_plan_call_to_action' => 'Adquira Agora!',
    'pro_plan_feature1' => 'Sem Limite de Clientes',
    'pro_plan_feature2' => '+10 Modelos de nota de pagamentos',
    'pro_plan_feature3' => 'URLs personalizadas - "SeuNome.InvoiceNinja.com"',
    'pro_plan_feature4' => 'Sem "Created by Invoice Ninja"',
    'pro_plan_feature5' => 'Múltiplos usuários & Histórico de Atividades',
    'pro_plan_feature6' => 'Orçamentos & Pedidos',
    'pro_plan_feature7' => 'Campos personalizados',
    'pro_plan_feature8' => 'Opção para anexar PDFs aos e-mails',
    'resume' => 'Retormar',
    'break_duration' => 'Interromper',
    'edit_details' => 'Editar Detalhes',
    'work' => 'Trabalhar',
    'timezone_unset' => 'Por favor :link defina a sua timezone',
    'click_here' => 'clique aqui',
    'email_receipt' => 'E-mail para envio do recibo de pagamento',
    'created_payment_emailed_client' => 'Pagamento informado e notificado ao cliente por e-mail',
    'add_company' => 'Adicionar Empresa',
    'untitled' => 'Sem Título',
    'new_company' => 'Nova Empresa',
    'associated_accounts' => 'Contas vinculadas',
    'unlinked_account' => 'Contas desvinculadas',
    'login' => 'Iniciar sessão',
    'or' => 'ou',
    'email_error' => 'Houve um problema ao enviar o e-mail',
    'confirm_recurring_timing' => 'Aviso: e-mails são enviados na hora de início.',
    'confirm_recurring_timing_not_sent' => 'Note: invoices are created at the start of the hour.',
    'payment_terms_help' => 'Definir  <b> a data de vencimento padrão </b>',
    'unlink_account' => 'Desvincular Conta',
    'unlink' => 'Desvincular',
    'show_address' => 'Mostrar morada',
    'show_address_help' => 'Solicitar morada de faturação ao cliente',
    'update_address' => 'Atualizar Morada',
    'update_address_help' => 'Atualizar morada do cliente',
    'times' => 'Tempo',
    'set_now' => 'Agora',
    'dark_mode' => 'Modo Escuro',
    'dark_mode_help' => 'Use a dark background for the sidebars',
    'add_to_invoice' => 'Adicionar na nota de pagamento :invoice',
    'create_new_invoice' => 'Criar nota de pagamento',
    'task_errors' => 'Corrija os tempos sobrepostos',
    'from' => 'De',
    'to' => 'Para',
    'font_size' => 'Tamanho do Texto',
    'primary_color' => 'Cor Principal',
    'secondary_color' => 'Cor Secundaria',
    'customize_design' => 'Personalizar Modelo',
    'content' => 'Conteúdo',
    'styles' => 'Estilos',
    'defaults' => 'Padrões',
    'margins' => 'Margens',
    'header' => 'Cabeçalho',
    'footer' => 'Rodapé',
    'custom' => 'Personalizado',
    'invoice_to' => 'Nota de Pagamento para',
    'invoice_no' => 'Nota de Pagamento No.',
    'quote_no' => 'Orçamento número',
    'recent_payments' => 'Pagamentos Recentes',
    'outstanding' => 'Em Aberto',
    'manage_companies' => 'Gerir Empresas',
    'total_revenue' => 'Total faturado',
    'current_user' => 'Utilizador',
    'new_recurring_invoice' => 'Nova Nota de Pagamento Recorrente',
    'recurring_invoice' => 'Nota de Pagamento Recorrente',
    'new_recurring_quote' => 'New Recurring Quote',
    'recurring_quote' => 'Recurring Quote',
    'recurring_too_soon' => 'Demasiado cedo para criar nova nota de pagamento recorrente, agendamento para :date',
    'created_by_invoice' => 'Criada a partir da Nota de Pagamento :invoice',
    'primary_user' => 'Utilizador Principal',
    'help' => 'Ajuda',
    'customize_help' => '<p>We use :pdfmake_link to define the invoice designs declaratively. The pdfmake :playground_link provides a great way to see the library in action.</p>
                        <p>If you need help figuring something out post a question to our :forum_link with the design you\'re using.</p>',
    'playground' => 'playground',
    'support_forum' => 'support forum',
    'invoice_due_date' => 'Data de vencimento',
    'quote_due_date' => 'Valido até',
    'valid_until' => 'Válido até',
    'reset_terms' => 'Redifinir Condições',
    'reset_footer' => 'Redifinir Rodapé',
    'invoice_sent' => ':count nota de pag. enviada',
    'invoices_sent' => ':count notas de pag. enviadas',
    'status_draft' => 'Rascunho',
    'status_sent' => 'Enviado',
    'status_viewed' => 'Visualizado',
    'status_partial' => 'Parcial',
    'status_paid' => 'Pago',
    'status_unpaid' => 'Unpaid',
    'status_all' => 'All',
    'show_line_item_tax' => 'Exibir <b>impostos dos itens</b>',
    'iframe_url' => 'Website',
    'iframe_url_help1' => 'Copie o código abaixo para o seu site.',
    'iframe_url_help2' => 'Pode testar ao clicar  em  \'Ver como destinatário\' numa nota de pagamento.',
    'auto_bill' => 'Cobrança Automática',
    'military_time' => '24h',
    'last_sent' => 'Último Envio',
    'reminder_emails' => 'E-mails de Lembrete',
    'quote_reminder_emails' => 'Quote Reminder Emails',
    'templates_and_reminders' => 'Modelos & Lembretes',
    'subject' => 'Assunto',
    'body' => 'Conteúdo',
    'first_reminder' => 'Primeiro Lembrete',
    'second_reminder' => 'Segundo Lembrete',
    'third_reminder' => 'Terceiro Lembrete',
    'num_days_reminder' => 'Dias após o vencimento',
    'reminder_subject' => 'Lembrente: Nota de Pagamento :invoice de :account',
    'reset' => 'Redefinir',
    'invoice_not_found' => 'A nota de pagamento não está disponível',
    'referral_program' => 'Programa de Indicação',
    'referral_code' => 'Código de Indicação',
    'last_sent_on' => 'Último envio em :date',
    'page_expire' => 'Esta página a expirar, :click_here para continuar a trabalhar',
    'upcoming_quotes' => 'Próximos Orçamentos',
    'expired_quotes' => 'Orçamentos Expirados',
    'sign_up_using' => 'Aceder',
    'invalid_credentials' => 'Utilizador e/ou palavra-passe inválidos',
    'show_all_options' => 'Mostrar todas as opções',
    'user_details' => 'Detalhes do Utilizador',
    'oneclick_login' => 'Connected Account',
    'disable' => 'Desativar',
    'invoice_quote_number' => 'Nº de Notas de Pag. e Orçamentos',
    'invoice_charges' => 'Sobretaxas da Nota de Pagamento',
    'notification_invoice_bounced' => 'Não foi possível entregar a Nota de Pagamento :invoice a :contact.',
    'notification_invoice_bounced_subject' => 'A Nota de Pagamento :invoice não foi entregue',
    'notification_quote_bounced' => 'Não foi possível entregar o Orçamento :invoice a :contact.',
    'notification_quote_bounced_subject' => 'O Orçamento :invoice não foi entregue',
    'custom_invoice_link' => 'Link de Faturas Personalizado',
    'total_invoiced' => 'Notas de Pagamento',
    'open_balance' => 'Em Aberto',
    'verify_email' => 'Um e-mail de verificação foi enviado para a sua caixa de entrada..',
    'basic_settings' => 'Definições Básicas',
    'pro' => 'Pro',
    'gateways' => 'Gateways de Pagamento',
    'next_send_on' => 'Próximo Envio: :date',
    'no_longer_running' => 'Esta nota de pagamento não está agendada',
    'general_settings' => 'Definições Gerais',
    'customize' => 'Personalizar',
    'oneclick_login_help' => 'Crie uma conta para aceder sem palavra-passe.',
    'referral_code_help' => 'Recomende o nosso sistema.',
    'enable_with_stripe' => 'Ativar | Requer Stripe',
    'tax_settings' => 'Definições de Impostos',
    'create_tax_rate' => 'Adicionar Imposto',
    'updated_tax_rate' => 'Imposto Atualizado',
    'created_tax_rate' => 'Imposto Adicionado',
    'edit_tax_rate' => 'Editar Imposto',
    'archive_tax_rate' => 'Arquivar Imposto',
    'archived_tax_rate' => 'Imposto Arquivado',
    'default_tax_rate_id' => 'Imposto Padrão',
    'tax_rate' => 'Imposto',
    'recurring_hour' => 'Hora Recorrente',
    'pattern' => 'Padrão',
    'pattern_help_title' => 'Ajuda para Padrões',
    'pattern_help_1' => 'Criar números de notas de pagamento personalizados especificando um padrão',
    'pattern_help_2' => 'Variáveis disponíveis:',
    'pattern_help_3' => 'Exemplo, :example seria convertido para :value',
    'see_options' => 'Veja as Opções',
    'invoice_counter' => 'Contador de Notas de Pagamento',
    'quote_counter' => 'Contador de Orçamentos',
    'type' => 'Tipo',
    'activity_1' => ':user criou o cliente :client',
    'activity_2' => ':user arquivou o cliente :client',
    'activity_3' => ':user removeu o cliente :client',
    'activity_4' => ':user criou a nota de pagamento :invoice',
    'activity_5' => ':user atualizou a nota de pagamento :invoice',
    'activity_6' => ':user emailed invoice :invoice for :client to :contact',
    'activity_7' => ':contact viewed invoice :invoice for :client',
    'activity_8' => ':user arquivou a nota de pagamento :invoice',
    'activity_9' => ':user removeu a nota de pagamento :invoice',
    'activity_10' => ':contact entered payment :payment for :payment_amount on invoice :invoice for :client',
    'activity_11' => ':user atualizou o pagamento :payment',
    'activity_12' => ':user arquivou o pagamento :payment',
    'activity_13' => ':user removeu o pagamento :payment',
    'activity_14' => ':user adicionou crédito :credit',
    'activity_15' => ':user atualizou crédito :credit',
    'activity_16' => ':user arquivou crédito :credit',
    'activity_17' => ':user removeu crédito :credit',
    'activity_18' => ':user adicionou o orçamento :quote',
    'activity_19' => ':user atualizou  o orçamento :quote',
    'activity_20' => ':user emailed quote :quote for :client to :contact',
    'activity_21' => ':contact visualizou o orçamento :quote',
    'activity_22' => ':user arquivou o orçamento :quote',
    'activity_23' => ':user removeu o orçamento :quote',
    'activity_24' => ':user restaurou o orçamento :quote',
    'activity_25' => ':user restaurou a nota de pagamento :invoice',
    'activity_26' => ':user restaurou o cliente :client',
    'activity_27' => ':user restaurou o pagamento :payment',
    'activity_28' => ':user restaurou o crédito :credit',
    'activity_29' => ':contact approved quote :quote for :client',
    'activity_30' => ':user criou o fornecedor :vendor',
    'activity_31' => ':user arquivou o fornecedor :vendor',
    'activity_32' => ':user apagou o fornecedor :vendor',
    'activity_33' => ':user restaurou o fornecedor :vendor',
    'activity_34' => ':user criou a despesa :expense',
    'activity_35' => ':user arquivou a despesa :expense',
    'activity_36' => ':user apagou a despesa :expense',
    'activity_37' => ':user restaurou a despesa :expense',
    'activity_42' => ':user criou a tarefa :task',
    'activity_43' => ':user atualizou a tarefa :task',
    'activity_44' => ':user arquivou a tarefa :task',
    'activity_45' => ':user apagou a tarefa :task',
    'activity_46' => ':user restaurou a tarefa :task',
    'activity_47' => ':user atualizou a despesa :expense',
    'activity_48' => ':user updated ticket :ticket',
    'activity_49' => ':user closed ticket :ticket',
    'activity_50' => ':user merged ticket :ticket',
    'activity_51' => ':user split ticket :ticket',
    'activity_52' => ':contact opened ticket :ticket',
    'activity_53' => ':contact reopened ticket :ticket',
    'activity_54' => ':user reopened ticket :ticket',
    'activity_55' => ':contact replied ticket :ticket',
    'activity_56' => ':user viewed ticket :ticket',

    'payment' => 'Pagamento',
    'system' => 'Sistema',
    'signature' => 'Assinatura do E-mail',
    'default_messages' => 'Mensagens Padrões',
    'quote_terms' => 'Condições do Orçamento',
    'default_quote_terms' => 'Condições Padrões dos Orçamentos',
    'default_invoice_terms' => 'Definir condições padrões da notas de pag.',
    'default_invoice_footer' => 'Definir padrão',
    'quote_footer' => 'Rodapé do Orçamento',
    'free' => 'Grátis',
    'quote_is_approved' => 'Successfully approved',
    'apply_credit' => 'Aplicar Crédito',
    'system_settings' => 'Definições do Sistema',
    'archive_token' => 'Arquivar Token',
    'archived_token' => 'Token arquivado',
    'archive_user' => 'Arquivar Utilizador',
    'archived_user' => 'Utilizador arquivado',
    'archive_account_gateway' => 'Delete Gateway',
    'archived_account_gateway' => 'Gateway arquivado',
    'archive_recurring_invoice' => 'Arquivar Nota de Pagamento Recorrente',
    'archived_recurring_invoice' => 'Nota de Pagamento Recorrente arquivada',
    'delete_recurring_invoice' => 'Remover Nota de Pagamento Recorrente',
    'deleted_recurring_invoice' => 'Nota de Pagamento Recorrente removida',
    'restore_recurring_invoice' => 'Restaurar Nota de Pagamento Recorrente',
    'restored_recurring_invoice' => 'Nota de Pagamento Recorrente restaurada',
    'archive_recurring_quote' => 'Archive Recurring Quote',
    'archived_recurring_quote' => 'Successfully archived recurring quote',
    'delete_recurring_quote' => 'Delete Recurring Quote',
    'deleted_recurring_quote' => 'Successfully deleted recurring quote',
    'restore_recurring_quote' => 'Restore Recurring Quote',
    'restored_recurring_quote' => 'Successfully restored recurring quote',
    'archived' => 'Arquivado',
    'untitled_account' => 'Empresa Sem Nome',
    'before' => 'Antes',
    'after' => 'Depois',
    'reset_terms_help' => 'Redefinir para as condições padrões',
    'reset_footer_help' => 'Redefinir  para o rodapé padrão',
    'export_data' => 'Exportar Dados',
    'user' => 'Utilizador',
    'country' => 'País',
    'include' => 'Incluir',
    'logo_too_large' => 'O seu logo tem :size, para uma melhor performance sugerimos que este tamanho não ultrapasse 200KB',
    'import_freshbooks' => 'Importar de FreshBooks',
    'import_data' => 'Importar Dados',
    'source' => 'Fonte',
    'csv' => 'CSV',
    'client_file' => 'Arquivo de Clientes',
    'invoice_file' => 'Arquivo de Notas de Pagamento',
    'task_file' => 'Arquivo de Tarefas',
    'no_mapper' => 'Mapeamento inválido',
    'invalid_csv_header' => 'CSV com cabeçalho inválido',
    'client_portal' => 'Portal do Cliente',
    'admin' => 'Admin',
    'disabled' => 'Desativado',
    'show_archived_users' => 'Mostrar utilizadores arquivados',
    'notes' => 'Observações',
    'invoice_will_create' => 'invoice will be created',
    'invoices_will_create' => 'notas de pagamento serão criadas',
    'failed_to_import' => 'Falhou a importação dos seguintes registos',
    'publishable_key' => 'Chave Publicável',
    'secret_key' => 'Chave Secreta',
    'missing_publishable_key' => 'Defina a sua chave publicável do Stripe para um melhor processo de pagamento',
    'email_design' => 'Template de E-mail',
    'due_by' => 'Vencido a :date',
    'enable_email_markup' => 'Ativar Marcação',
    'enable_email_markup_help' => 'Tornar mais fácil para os seus clientes efetuarem os pagamentos, acrescentando marcação schema.org a seus e-mails.',
    'template_help_title' => 'Ajuda de Templates',
    'template_help_1' => 'Variáveis disponíveis:',
    'email_design_id' => 'Estilo de e-mails',
    'email_design_help' => 'Make your emails look more professional with HTML layouts.',
    'plain' => 'Plano',
    'light' => 'Claro',
    'dark' => 'Escuro',
    'industry_help' => 'Usado para fornecer comparações entre empresas.',
    'subdomain_help' => 'Indique o subdomínio ou mostre a nota de pag. no seu site.',
    'website_help' => 'Display the invoice in an iFrame on your own website',
    'invoice_number_help' => 'Especifique um prefixo ou use um padrão personalizado para definir dinamicamente o número da nota de pagamento.',
    'quote_number_help' => 'Especifique um prefixo ou use um padrão personalizado para definir dinamicamente o número do orçamento.',
    'custom_client_fields_helps' => 'Add a field when creating a client and optionally display the label and value on the PDF.',
    'custom_account_fields_helps' => 'Adicionar um rótulo e um valor para a seção detalhes da empresa do PDF.',
    'custom_invoice_fields_helps' => 'Add a field when creating an invoice and optionally display the label and value on the PDF.',
    'custom_invoice_charges_helps' => 'Adicionar uma entrada de texto na página Criar/Editar Nota de Pagamento e incluir nos subtotais da nota de pagamento.',
    'token_expired' => 'Token de acesso expirado. Tente novamente!',
    'invoice_link' => 'Link da Nota de Pagamento',
    'button_confirmation_message' => 'Clique para confirmar seu endereço de e-mail.',
    'confirm' => 'Confirmar',
    'email_preferences' => 'Preferências de E-mails',
    'created_invoices' => ':count nota de pagamento(s) criadas com sucesso',
    'next_invoice_number' => 'O número da próxima nota de pagamento será :number.',
    'next_quote_number' => 'O número do próximo orçamento será :number.',
    'days_before' => 'dias antes de',
    'days_after' => 'dias depois de',
    'field_due_date' => 'data de vencimento',
    'field_invoice_date' => 'data da nota de pagamento',
    'schedule' => 'Agendamento',
    'email_designs' => 'Design de E-mails',
    'assigned_when_sent' => 'Assinar quando enviar',
    'white_label_purchase_link' => 'Adquira uma licença white label',
    'expense' => 'Despesa',
    'expenses' => 'Despesas',
    'new_expense' => 'Introduzir Despesa',
    'enter_expense' => 'Incluir Despesa',
    'vendors' => 'Fornecedor',
    'new_vendor' => 'Novo Fornecedor',
    'payment_terms_net' => 'Net',
    'vendor' => 'Fornecedor',
    'edit_vendor' => 'Editar Fornecedor',
    'archive_vendor' => 'Arquivar Fornecedor',
    'delete_vendor' => 'Apagar Fornecedor',
    'view_vendor' => 'Visualizar Fornecedor',
    'deleted_expense' => 'Despesa excluída com sucesso',
    'archived_expense' => 'Despesa arquivada com sucesso',
    'deleted_expenses' => 'Despesas excluídas com sucesso',
    'archived_expenses' => 'Despesas arquivadas com sucesso',
    'expense_amount' => 'Total de Despesas',
    'expense_balance' => 'Saldo das Despesas',
    'expense_date' => 'Data da Despesa',
    'expense_should_be_invoiced' => 'Esta despesa deve ser faturada?',
    'public_notes' => 'Notas Públicas',
    'invoice_amount' => 'Total da Nota de Pagamento',
    'exchange_rate' => 'Taxa de Câmbio',
    'yes' => 'Sim',
    'no' => 'Não',
    'should_be_invoiced' => 'Deve ser faturada',
    'view_expense' => 'Visualizar despesa # :expense',
    'edit_expense' => 'Editar Despesa',
    'archive_expense' => 'Arquivar Despesa',
    'delete_expense' => 'Apagar Despesa',
    'view_expense_num' => 'Despesa # :expense',
    'updated_expense' => 'Despesa atualizada com sucesso',
    'created_expense' => 'Despesa criada com sucesso',
    'enter_expense' => 'Incluir Despesa',
    'view' => 'Visualizar',
    'restore_expense' => 'Restaurar Despesa',
    'invoice_expense' => 'Nota de Pagamento da Despesa',
    'expense_error_multiple_clients' => 'Despesas não podem pertencer a clientes diferentes',
    'expense_error_invoiced' => 'Despesa já faturada',
    'convert_currency' => 'Converter moeda',
    'num_days' => 'Número de dias',
    'create_payment_term' => 'Criar Termo de Pagamento',
    'edit_payment_terms' => 'Editar Termos de Pagamento',
    'edit_payment_term' => 'Editar Termo de Pagamento',
    'archive_payment_term' => 'Arquivar Termo de Pagamento',
    'recurring_due_dates' => 'Data de Vencimento das Notas de Pagamento Recorrentes',
    'recurring_due_date_help' => '<p>Definir automaticamente a data de vencimento da nota de pagamento.</p>
        <p>Notas de Pagamento em um ciclo mensal ou anual com vencimento anterior ou na data em que são criadas serão nota de pagamentodas para o próximo mês. Notas de Pagamento com vencimento no dia 29 ou 30 nos meses que não tem esse dia será nota de pagamentoda no último dia do mês..</p>
        <p>Notas de Pagamento em um clclo mensal com vencimento no dia da semana em que foi criada serão nota de pagamentodas para a próxima semana.</p>
        <p>Exemplo:</p>
        <ul>
          <li>Hoje é dia 15, vencimento no primeiro dia do mês. O Vencimento será no primeiro dia do próximo mês.</li>
          <li>Hoje é dia 15, vencimento no último dia do mês. O Vencimento será no último dia do mês corrente</li>
          <li>Hoje é dia 15, vencimento no dia 15. O venciemnto será no dia 15 do <strong>próximo</strong> mês.</li>
          <li>Hoje é Sexta-Feira, vencimento na primeira sexta-feira. O venciemnto será na próxima sexta-feira, não hoje.</li>
        </ul>',
    'due' => 'Vencimento',
    'next_due_on' => 'Próximo Vencimento: :date',
    'use_client_terms' => 'Usar condições do cliente',
    'day_of_month' => ':ordinal dia do mês ',
    'last_day_of_month' => 'Último dia do mês',
    'day_of_week_after' => ':ordinal :day depois',
    'sunday' => 'Domingo',
    'monday' => 'Segunda-Feira',
    'tuesday' => 'Terça-Feira',
    'wednesday' => 'Quarta-Feira',
    'thursday' => 'Quinta-Feira',
    'friday' => 'Sexta-Feira',
    'saturday' => 'Sábado',
    'header_font_id' => 'Fonte do Cabeçalho',
    'body_font_id' => 'Fonte dos Textos',
    'color_font_help' => 'Nota: A cor primária também é utilizada no portal do cliente e no e-mail personalizado.',
    'live_preview' => 'Pré-visualização',
    'invalid_mail_config' => 'Falha ao enviar e-mail, verifique as definições.',
    'invoice_message_button' => 'Para visualizar a sua nota de pagamento de :amount, clique no botão abaixo.',
    'quote_message_button' => 'Para visualizar o seu orçamento de :amount, clique no botão abaixo.',
    'payment_message_button' => 'Obrigado pelo pagamento de :amount.',
    'payment_type_direct_debit' => 'Débito',
    'bank_accounts' => 'Contas Bancárias',
    'add_bank_account' => 'Adicionar Conta Bancária',
    'setup_account' => 'Configurar Conta',
    'import_expenses' => 'Importar Despesas',
    'bank_id' => 'Banco',
    'integration_type' => 'Tipo de Integração',
    'updated_bank_account' => 'Conta bancária atualizada com sucesso',
    'edit_bank_account' => 'Editar Conta Bancária',
    'archive_bank_account' => 'Arquivar Conta Bancária',
    'archived_bank_account' => 'Conta bancária arquivada com sucesso',
    'created_bank_account' => 'Conta bancária criada com sucesso',
    'validate_bank_account' => 'Validar Conta Bancária',
    'bank_password_help' => 'Nota: a sua palavra-passe é transferida de forma segura e não será armazenada em nossos servidores.',
    'bank_password_warning' => 'Atenção: a sua palavra-passe será transferida de forma não segura, considere habilitar HTTPS.',
    'username' => 'Utilizador',
    'account_number' => 'Conta número',
    'account_name' => 'Nome da Conta',
    'bank_account_error' => 'Failed to retrieve account details, please check your credentials.',
    'status_approved' => 'Aprovado',
    'quote_settings' => 'Definições dos Orçamentos',
    'auto_convert_quote' => 'Auto Convert',
    'auto_convert_quote_help' => 'Converter automaticamente um orçamento quando for aprovado pelo cliente.',
    'validate' => 'Validado',
    'info' => 'Info',
    'imported_expenses' => ':count_vendors fornecedor(s) e :count_expenses despesa(s) importadas com sucesso',
    'iframe_url_help3' => 'Nota: se o seu plano aceita detalhes do cartão de crédito  recomendamos que tenha HTTPS no seu site.',
    'expense_error_multiple_currencies' => 'As despesas não podem ter diferentes moedas.',
    'expense_error_mismatch_currencies' => 'As configurações de moeda do cliente não coincidem com a moeda nesta despesa.',
    'trello_roadmap' => 'Trello Roadmap',
    'header_footer' => 'Cabeçalho/Rodapé',
    'first_page' => 'primeira página',
    'all_pages' => 'todas as páginas',
    'last_page' => 'última página',
    'all_pages_header' => 'Mostrar cabeçalho ativo',
    'all_pages_footer' => 'Mostrar rodapé ativo',
    'invoice_currency' => 'Moeda da Nota de Pagamento',
    'enable_https' => 'Recomendamos a utilização de HTTPS para receber os detalhes do cartão de crédito online.',
    'quote_issued_to' => 'Orçamento emitido para',
    'show_currency_code' => 'Código da Moeda',
    'free_year_message' => 'Your account has been upgraded to the pro plan for one year at no cost.',
    'trial_message' => 'A sua conta receberá gratuitamente duas semanas para testar nosso plano pro.',
    'trial_footer' => 'Your free pro plan trial lasts :count more days, :link to upgrade now.',
    'trial_footer_last_day' => 'This is the last day of your free pro plan trial, :link to upgrade now.',
    'trial_call_to_action' => 'Iniciar período de testes',
    'trial_success' => 'Ativado duas semanas de teste para testar o plano Pro',
    'overdue' => 'Vencido',


    'white_label_text' => 'Comprar UM ANO da licença de marca branca por $:price para remover o branding do Invoice Ninja das notas de pagamento e do portal do cliente.',
    'user_email_footer' => 'Para ajustar as suas definições de notificações de e-mail aceda :link',
    'reset_password_footer' => 'Se não solicitou a redefinição da palavra-passe por favor envie um e-mail para o nosso suporte: :email',
    'limit_users' => 'Desculpe, isto irá exceder o limite de :limit utilizadores',
    'more_designs_self_host_header' => 'Obtenha mais 6 modelos de nota de pagamento por apenas $:price',
    'old_browser' => 'Please use a :link',
    'newer_browser' => 'newer browser',
    'white_label_custom_css' => ':link apenas $:price para permitir um estilo personalizado e apoiar o nosso projecto.',
    'bank_accounts_help' => 'Connect a bank account to automatically import expenses and create vendors. Supports American Express and :link.',
    'us_banks' => '400+ US banks',

    'pro_plan_remove_logo' => ':link para remover a logo do Invoice Ninja contratando o plano profissional',
    'pro_plan_remove_logo_link' => 'Clique aqui',
    'invitation_status_sent' => 'Sent',
    'invitation_status_opened' => 'Opened',
    'invitation_status_viewed' => 'Visto',
    'email_error_inactive_client' => 'Não é possível enviar e-mails para clientes inativos',
    'email_error_inactive_contact' => 'Não é possível enviar e-mails para contatos inativos',
    'email_error_inactive_invoice' => 'Não é possível enviar e-mails de nota de pagamentos inativas',
    'email_error_inactive_proposal' => 'Emails can not be sent to inactive proposals',
    'email_error_user_unregistered' => 'Registe-se para enviar e-mails',
    'email_error_user_unconfirmed' => 'Confirme a sua conta para enviar e-mails',
    'email_error_invalid_contact_email' => 'E-mail do contato inválido',

    'navigation' => 'Navegação',
    'list_invoices' => 'Listar Notas de Pagamento',
    'list_clients' => 'Listar Clientes',
    'list_quotes' => 'Listar Orçamentos',
    'list_tasks' => 'Listar Tarefas',
    'list_expenses' => 'Listar Despesas',
    'list_recurring_invoices' => 'Listar Notas de Pagamento Recorrentes',
    'list_payments' => 'Listar Pagamentos',
    'list_credits' => 'Listar Créditos',
    'tax_name' => 'Nome do Imposto',
    'report_settings' => 'Configuração de Relatórios',
    'search_hotkey' => 'atalho /',

    'new_user' => 'Novo Utilizador',
    'new_product' => 'Novo Produto',
    'new_tax_rate' => 'Novo Imposto',
    'invoiced_amount' => 'Total da Nota de Pag.',
    'invoice_item_fields' => 'Campos de itens na Nota de Pagamento',
    'custom_invoice_item_fields_help' => 'Adicionar um campo ao adicionar um item e mostrar a etiqueta e valor no PDF.',
    'recurring_invoice_number' => 'Nº Recorrente',
    'recurring_invoice_number_prefix_help' => 'Specify a prefix to be added to the invoice number for recurring invoices.',

    // Client Passwords
    'enable_portal_password' => 'Proteger notas de pag. com palavra-passe',
    'enable_portal_password_help' => 'Permite definir uma palavra-passe para cada contacto. Se uma palavra-passe for definida, o contacto deverá introduzir a palavra-passe antes de visualizar a nota de pagamento.',
    'send_portal_password' => 'Generate Automatically',
    'send_portal_password_help' => 'Se não definir uma palavra-passe, será gerada uma automaticamente e enviada com a primeira nota de pagamento.',

    'expired' => 'Expirada',
    'invalid_card_number' => 'Cartão de crédito inválido.',
    'invalid_expiry' => 'Data de expiração inválida.',
    'invalid_cvv' => 'O código CVV é inválido.',
    'cost' => 'Custo',
    'create_invoice_for_sample' => 'Nota: crie a primeira nota de pagamento para ver uma pré-visualização aqui.',

    // User Permissions
    'owner' => 'Proprietário',
    'administrator' => 'Administrador',
    'administrator_help' => 'Permite ao utilizador gerir utilizadores, alterar definições e modificar registos.',
    'user_create_all' => 'Criar clientes, notas de pagamento, etc.',
    'user_view_all' => 'Ver todos os clientes, notas de pagamento, etc.',
    'user_edit_all' => 'Editar todos os clientes, notas de pagamento, etc.',
    'gateway_help_20' => ':link para ativar o Sage Pay.',
    'gateway_help_21' => ':link para ativar o Sage Pay.',
    'partial_due' => 'Vencimento Parcial',
    'restore_vendor' => 'Restaurar Fornecedor',
    'restored_vendor' => 'Fornecedor restarurado com sucesso',
    'restored_expense' => 'Despesa restaurada com sucesso',
    'permissions' => 'Permissões',
    'create_all_help' => 'Permite o utilizador criar e alterar registos',
    'view_all_help' => 'Permite o utilizador visualizar registos que ele não criou',
    'edit_all_help' => 'Permite ao utilizador editar registos que ele não criou',
    'view_payment' => 'Ver Pagamento',

    'january' => 'Janeiro',
    'february' => 'Fevereiro',
    'march' => 'Março',
    'april' => 'Abril',
    'may' => 'Maio',
    'june' => 'Junho',
    'july' => 'Julho',
    'august' => 'Agosto',
    'september' => 'Setembro',
    'october' => 'Outubro',
    'november' => 'Novembro',
    'december' => 'Dezembro',

    // Documents
    'documents_header' => 'Documentos:',
    'email_documents_header' => 'Documentos:',
    'email_documents_example_1' => 'Recibo de Widgets.pdf',
    'email_documents_example_2' => 'Ficheiros Finais.zip',
    'quote_documents' => 'Quote Documents',
    'invoice_documents' => 'Invoice Documents',
    'expense_documents' => 'Expense Documents',
    'invoice_embed_documents' => 'Documentos Embutidos',
    'invoice_embed_documents_help' => 'Incluir imagens anexadas na nota de pagamento.',
    'document_email_attachment' => 'Anexar Documentos',
    'ubl_email_attachment' => 'Attach UBL',
    'download_documents' => 'Transferir Documentos (:size)',
    'documents_from_expenses' => 'De despesas:',
    'dropzone_default_message' => 'Arrastar ficheiros para enviar',
    'dropzone_default_message_disabled' => 'Uploads disabled',
    'dropzone_fallback_message' => 'O seu browser não suporta envio de ficheiros através de drag\'n\'drop.',
    'dropzone_fallback_text' => 'Por favor utilize o formulário abaixo para enviar ficheiros em modo de compatibilidade.',
    'dropzone_file_too_big' => 'Ficheiro demasiado grande ({{filesize}}MiB). Tamanho máximo: {{maxFilesize}}MiB.',
    'dropzone_invalid_file_type' => 'Não pode enviar este tipo de ficheiros.',
    'dropzone_response_error' => 'O servidor respondeu com o código {{statusCode}}.',
    'dropzone_cancel_upload' => 'Cancelar envio',
    'dropzone_cancel_upload_confirmation' => 'Tem a certeza que pretende cancelar este envio?',
    'dropzone_remove_file' => 'Remover ficheiro',
    'documents' => 'Documentos',
    'document_date' => 'Data do Documento',
    'document_size' => 'Tamanho',

    'enable_client_portal' => 'Portal do Cliente',
    'enable_client_portal_help' => 'Mostrar/ocultar o portal do cliente.',
    'enable_client_portal_dashboard' => 'Dashboard',
    'enable_client_portal_dashboard_help' => 'Mostrar/ocultar o dashboard no portal do cliente.',

    // Plans
    'account_management' => 'Gerir Conta',
    'plan_status' => 'Estado do Plano',

    'plan_upgrade' => 'Upgrade',
    'plan_change' => 'Alterar Plano',
    'pending_change_to' => 'Altera Para',
    'plan_changes_to' => ':plan em :date',
    'plan_term_changes_to' => ':plan (:term) em :date',
    'cancel_plan_change' => 'Cancelar Alteração',
    'plan' => 'Plano',
    'expires' => 'Expira',
    'renews' => 'Renovação',
    'plan_expired' => ':plan Plano Expirado',
    'trial_expired' => ':plan Plano de Avaliação Terminou',
    'never' => 'Nunca',
    'plan_free' => 'Gratuíto',
    'plan_pro' => 'Pro',
    'plan_enterprise' => 'Enterprise',
    'plan_white_label' => 'Self Hosted (Marca Branca)',
    'plan_free_self_hosted' => 'Self Hosted (Gratuíto)',
    'plan_trial' => 'Avaliação',
    'plan_term' => 'Período',
    'plan_term_monthly' => 'Mensal',
    'plan_term_yearly' => 'Anual',
    'plan_term_month' => 'Mês',
    'plan_term_year' => 'Ano',
    'plan_price_monthly' => '$:price/Mês',
    'plan_price_yearly' => '$:price/Ano',
    'updated_plan' => 'Definições do plano atualizadas',
    'plan_paid' => 'Iniciou o período',
    'plan_started' => 'Iniciou o Plano',
    'plan_expires' => 'Plano Expira',

    'white_label_button' => 'Marca Branca',

    'pro_plan_year_description' => 'Subscrição de um ano no plano Invoice Ninja Pro.',
    'pro_plan_month_description' => 'Um mês de subscrição no plano Invoice Ninja Pro.',
    'enterprise_plan_product' => 'Plano Enterprise',
    'enterprise_plan_year_description' => 'Um ano de subscrição no plano Invoice Ninja Enterprise.',
    'enterprise_plan_month_description' => 'Um mês de subscrição no plano Invoice Ninja Enterprise.',
    'plan_credit_product' => 'Crédito',
    'plan_credit_description' => 'Crédito pelo tempo não utilizado',
    'plan_pending_monthly' => 'Vamos alterar para mensal em :date',
    'plan_refunded' => 'Foi realizada um reembolso.',

    'live_preview' => 'Pré-visualização',
    'page_size' => 'Tamanho da Página',
    'live_preview_disabled' => 'Pré-visualização em tempo real desactivada para suportar o tipo de letra selecionado',
    'invoice_number_padding' => 'Padding',
    'preview' => 'Pré-visualizar',
    'list_vendors' => 'Listar Fornecedores',
    'add_users_not_supported' => 'Altere para o plano Enterprise para adicionar utilizadores adicionais à sua conta.',
    'enterprise_plan_features' => 'O plano Enterprise adiciona suporte a multiplos utilizadores e anexos de ficheiros, :link para ver a lista completa de funcionalidades.',
    'return_to_app' => 'Return To App',


    // Payment updates
    'refund_payment' => 'Reembolsar Pagamento',
    'refund_max' => 'Máx:',
    'refund' => 'Reembolsar',
    'are_you_sure_refund' => 'Reembolsar os pagamentos selecionados?',
    'status_pending' => 'Pendente',
    'status_completed' => 'Completo',
    'status_failed' => 'Falhou',
    'status_partially_refunded' => 'Parcialmente Reembolsado',
    'status_partially_refunded_amount' => ':amount Reembolsado',
    'status_refunded' => 'Reembolsado',
    'status_voided' => 'Cancelado',
    'refunded_payment' => 'Pagamento Reembolsado',
    'activity_39' => ':user cancelled a :payment_amount payment :payment',
    'activity_40' => ':user refunded :adjustment of a :payment_amount payment :payment',
    'card_expiration' => 'Venc:&nbsp:expira',

    'card_creditcardother' => 'Desconhecido',
    'card_americanexpress' => 'American Express',
    'card_carteblanche' => 'Carte Blanche',
    'card_unionpay' => 'UnionPay',
    'card_diners' => 'Diners Club',
    'card_discover' => 'Discover',
    'card_jcb' => 'JCB',
    'card_laser' => 'Laser',
    'card_maestro' => 'Maestro',
    'card_mastercard' => 'MasterCard',
    'card_solo' => 'Solo',
    'card_switch' => 'Switch',
    'card_visacard' => 'Visa',
    'card_ach' => 'ACH',

    'payment_type_stripe' => 'Stripe',
    'ach' => 'ACH',
    'enable_ach' => 'Accept US bank transfers',
    'stripe_ach_help' => 'ACH support must also be enabled in :link.',
    'ach_disabled' => 'Existe outro gateway configurado para débito direto.',

    'plaid' => 'Plaid',
    'client_id' => 'Client Id',
    'secret' => 'Secret',
    'public_key' => 'Public Key',
    'plaid_optional' => '(opcional)',
    'plaid_environment_help' => 'When a Stripe test key is given, Plaid\'s development environment (tartan) will be used.',
    'other_providers' => 'Outros Provedores',
    'country_not_supported' => 'Este país não é suportado.',
    'invalid_routing_number' => 'O número de roteamento é inválido.',
    'invalid_account_number' => 'O número da conta e inválido.',
    'account_number_mismatch' => 'Os números da conta não correspondem.',
    'missing_account_holder_type' => 'Por favor, selecione uma conta ou empresa individual.',
    'missing_account_holder_name' => 'Por favor, indique o nome do proprietário da conta.',
    'routing_number' => 'Número de Roteamento',
    'confirm_account_number' => 'Confirmar Número de Conta',
    'individual_account' => 'Conta Individual',
    'company_account' => 'Conta Empresarial',
    'account_holder_name' => 'Nome do Proprietário da Conta',
    'add_account' => 'Adicionar Conta',
    'payment_methods' => 'Métodos de Pagamento',
    'complete_verification' => 'Verificação Completa',
    'verification_amount1' => 'Valor 1',
    'verification_amount2' => 'Valor 2',
    'payment_method_verified' => 'Verificação concluída com sucesso',
    'verification_failed' => 'Verificação falhou',
    'remove_payment_method' => 'Remover método de Pagamento',
    'confirm_remove_payment_method' => 'Deseja remover este método de pagamento?',
    'remove' => 'Remover',
    'payment_method_removed' => 'Método de pagamento removido.',
    'bank_account_verification_help' => 'Fizemos dois depósitos na sua conta com a descrição "VERIFICATION". Estes depósitos podem levar 1-2 dias úteis para aparecer no seu extracto. Por favor indique os valores de cada um deles abaixo.',
    'bank_account_verification_next_steps' => 'Fizemos dois depósitos na sua conta com a descrição "VERIFICATION". Estes depósitos podem levar 1-2 dias úteis para aparecer no seu extracto.
Quando tiver os valores dos depósitos, volte a esta página e conclua a verificação da sua conta.',
    'unknown_bank' => 'Banco Desconhecido',
    'ach_verification_delay_help' => 'Poderá utilizar esta conta após a concluir a verificação. A verificação normalmente leva 1 a 2 dias.',
    'add_credit_card' => 'Adicionar Cartão de Crédito',
    'payment_method_added' => 'Método de pagamento adicionado.',
    'use_for_auto_bill' => 'Usar para Pagamentos Automáticos',
    'used_for_auto_bill' => 'Método de Pagamentos Automáticos',
    'payment_method_set_as_default' => 'Definir método de pagamento automático.',
    'activity_41' => 'pagamento (:payment)  de :payment_amount falhou',
    'webhook_url' => 'Webhook URL',
    'stripe_webhook_help' => 'Deverá :link.',
    'stripe_webhook_help_link_text' => 'adicionar este URL como um endpoint no Stripe',
    'gocardless_webhook_help_link_text' => 'add this URL as an endpoint in GoCardless',
    'payment_method_error' => 'Houve um erro ao adicionar seu método de pagamento. Tente novamente.',
    'notification_invoice_payment_failed_subject' => 'Pagamento falhou para a Nota de Pagamento :invoice',
    'notification_invoice_payment_failed' => 'O pagamento feito pelo Cliente :client para a Nota de Pagamento :invoice falhou. O pagamento foi marcado como "falhado" e foram adicionados :amount ao saldo do cliente.',
    'link_with_plaid' => 'Ligar Automaticamente Conta com o Plaid',
    'link_manually' => 'Ligar Manualmente',
    'secured_by_plaid' => 'Assegurado por Plaid',
    'plaid_linked_status' => 'Conta bancária no :bank',
    'add_payment_method' => 'Adicionar Método de Pagamento',
    'account_holder_type' => 'Tipo do Proprietário da Conta',
    'ach_authorization' => 'Eu autorizo a :company a utilizar a minha conta bancária para pagamentos futuros e, se necessário, creditar electronicamente a minha conta para corrigir débitos incorrectos. Compreendo que posso revogar esta autorização a qualquer altura removendo o método de pagamento ou contactando :email.',
    'ach_authorization_required' => 'Deverá permitir transacções ACH.',
    'off' => 'Off',
    'opt_in' => 'Aceitar (Opt-in)',
    'opt_out' => 'Negar (Opt-out)',
    'always' => 'Sempre',
    'opted_out' => 'Negou (Opted out)',
    'opted_in' => 'Aceitou (Opted in)',
    'manage_auto_bill' => 'Gerir Pagamentos Automáticos',
    'enabled' => 'Ativo',
    'paypal' => 'PayPal',
    'braintree_enable_paypal' => 'Ativar pagamentos PayPal através do BrainTree',
    'braintree_paypal_disabled_help' => 'O gateway PayPal está a processar pagamentos PayPal',
    'braintree_paypal_help' => 'Deverá também :link.',
    'braintree_paypal_help_link_text' => 'ligar o PayPal à sua conta BrainTree',
    'token_billing_braintree_paypal' => 'Guardar detalhes do pagamento',
    'add_paypal_account' => 'Adicionar Conta PayPal',


    'no_payment_method_specified' => 'Nenhum método de pagamento definido',
    'chart_type' => 'Tipo de Gráfico',
    'format' => 'Formato',
    'import_ofx' => 'Importar OFX',
    'ofx_file' => 'Ficheiro OFX',
    'ofx_parse_failed' => 'Falha ao ler o ficheiro OFX',

    // WePay
    'wepay' => 'WePay',
    'sign_up_with_wepay' => 'Registar com WePay',
    'use_another_provider' => 'Utilizar outro provedor',
    'company_name' => 'Nome da Empresa',
    'wepay_company_name_help' => 'Isto irá aparecer no registo do cartão de crédito do cliente.',
    'wepay_description_help' => 'O objetivo desta conta.',
    'wepay_tos_agree' => 'Concordo com :link.',
    'wepay_tos_link_text' => 'Termos de Serviço do WePay',
    'resend_confirmation_email' => 'Reenviar Email de Confirmação',
    'manage_account' => 'Gerir Conta',
    'action_required' => 'Acção Necessária',
    'finish_setup' => 'Terminar Configuração',
    'created_wepay_confirmation_required' => 'Por favor verifique o seu email e confirme o seu email com o WePay',
    'switch_to_wepay' => 'Alterar para WePay',
    'switch' => 'Alterar',
    'restore_account_gateway' => 'Restaurar Gateway',
    'restored_account_gateway' => 'Gateway restaurado com sucesso',
    'united_states' => 'Estados Unidos',
    'canada' => 'Canadá',
    'accept_debit_cards' => 'Aceitar Cartão de Débito',
    'debit_cards' => 'Cartões de Débito',

    'warn_start_date_changed' => 'A próxima nota de pagamento será enviada na nova data de início.',
    'warn_start_date_changed_not_sent' => 'The next invoice will be created on the new start date.',
    'original_start_date' => 'Data de início original',
    'new_start_date' => 'Nova data de início',
    'security' => 'Segurança',
    'see_whats_new' => 'Veja as novidades na versão  v:version',
    'wait_for_upload' => 'Por favor aguardo pela conclusão do envio do documento',
    'upgrade_for_permissions' => 'Atualize para o nosso plano Enterprise para ativar as permissões.',
    'enable_second_tax_rate' => 'Permitir indicar um <b>segundo imposto</b>',
    'payment_file' => 'Ficheiro de Pagamento',
    'expense_file' => 'Ficheiro de Despesas',
    'product_file' => 'Ficheiro de Produtos',
    'import_products' => 'Produtos Importados',
    'products_will_create' => 'produtos serão criados',
    'product_key' => 'Produto',
    'created_products' => 'Successfully created/updated :count product(s)',
    'export_help' => 'Utilize JSON se planear importar os dados para o Invoice Ninja.<br/>O ficheiro incluí clientes, produtos, notas de pagamento, orçamentos e pagamentos.',
    'selfhost_export_help' => '<br/>We recommend using mysqldump to create a full backup.',
    'JSON_file' => 'Ficheiro JSON',

    'view_dashboard' => 'Ver Dashboard',
    'client_session_expired' => 'Sessão Expirada',
    'client_session_expired_message' => 'A sua sessão expirou. Por favor abra novamente o link no seu email.',

    'auto_bill_notification' => 'Esta nota de pagamento será paga automaticamente a :due_data através do seu :payment_method.',
    'auto_bill_payment_method_bank_transfer' => 'conta bancária',
    'auto_bill_payment_method_credit_card' => 'cartão de crédito',
    'auto_bill_payment_method_paypal' => 'conta PayPal',
    'auto_bill_notification_placeholder' => 'Esta nota de pagamento será paga automaticamente no seu cartão de crédito na data de vencimento.',
    'payment_settings' => 'Definições de Pagamento',

    'on_send_date' => 'Na data de envio',
    'on_due_date' => 'Na data de vencimento',
    'auto_bill_ach_date_help' => 'ACH fará sempre o pagamento automático na data de vencimento.',
    'warn_change_auto_bill' => 'Devido às regras NACHA, alterações a esta nota de pagamento podem evitar pagamentos automáticos ACH.',

    'bank_account' => 'Conta Bancária',
    'payment_processed_through_wepay' => 'Pagamentos ACH serão processados utilizando WePay.',
    'wepay_payment_tos_agree' => 'Eu concordo com :terms e :privacy_policy da WePay.',
    'privacy_policy' => 'Política de Privacidade',
    'wepay_payment_tos_agree_required' => 'Deve concordar com os Termos de Serviço e Política de Privacidade da WePay.',
    'ach_email_prompt' => 'Por favor indique o seu email:',
    'verification_pending' => 'Verificação Pendente',

    'update_font_cache' => 'Por favor force a actualização da página para actualizar a cache dos tipos de letra.',
    'more_options' => 'Mais opções',
    'credit_card' => 'Cartão de Crédito',
    'bank_transfer' => 'Transferência Bancária',
    'no_transaction_reference' => 'Não recebemos do gateway nenhuma referência a um pagamento.',
    'use_bank_on_file' => 'Utilizar o Banco no Ficheiro',
    'auto_bill_email_message' => 'Esta nota de pagamento será paga automaticamente na data de vencimento através do método de pagamento.',
    'bitcoin' => 'Bitcoin',
    'gocardless' => 'GoCardless',
    'added_on' => 'Adicionado em :date',
    'failed_remove_payment_method' => 'Erro ao remover o método de pagamento',
    'gateway_exists' => 'Este gateway já existe',
    'manual_entry' => 'Introdução manual',
    'start_of_week' => 'Primeiro Dia da Semana',

    // Frequencies
    'freq_inactive' => 'Inactive',
    'freq_daily' => 'Daily',
    'freq_weekly' => 'Semanal',
    'freq_biweekly' => 'Biweekly',
    'freq_two_weeks' => '2 semanas',
    'freq_four_weeks' => '4 semanas',
    'freq_monthly' => 'Mensal',
    'freq_three_months' => 'Trimestral',
    'freq_four_months' => 'Four months',
    'freq_six_months' => 'Semestral',
    'freq_annually' => 'Anual',
    'freq_two_years' => 'Two years',

    // Payment types
    'payment_type_Apply Credit' => 'Aplicar Crédito',
    'payment_type_Bank Transfer' => 'Transferência Bancária',
    'payment_type_Cash' => 'Dinheiro',
    'payment_type_Debit' => 'Débito',
    'payment_type_ACH' => 'ACH',
    'payment_type_Visa Card' => 'Cartão Visa',
    'payment_type_MasterCard' => 'MasterCard',
    'payment_type_American Express' => 'American Express',
    'payment_type_Discover Card' => 'Discover Card',
    'payment_type_Diners Card' => 'Diners Card',
    'payment_type_EuroCard' => 'EuroCard',
    'payment_type_Nova' => 'Nova',
    'payment_type_Credit Card Other' => 'Outro Cartão de Crédito',
    'payment_type_PayPal' => 'PayPal',
    'payment_type_Google Wallet' => 'Google Wallet',
    'payment_type_Check' => 'Cheque',
    'payment_type_Carte Blanche' => 'Carte Blanche',
    'payment_type_UnionPay' => 'UnionPay',
    'payment_type_JCB' => 'JCB',
    'payment_type_Laser' => 'Laser',
    'payment_type_Maestro' => 'Maestro',
    'payment_type_Solo' => 'Solo',
    'payment_type_Switch' => 'Switch',
    'payment_type_iZettle' => 'iZettle',
    'payment_type_Swish' => 'Swish',
    'payment_type_Alipay' => 'Alipay',
    'payment_type_Sofort' => 'Sofort',
    'payment_type_SEPA' => 'SEPA Direct Debit',
    'payment_type_Bitcoin' => 'Bitcoin',
    'payment_type_GoCardless' => 'GoCardless',
    'payment_type_Zelle' => 'Zelle',

    // Industries
    'industry_Accounting & Legal' => 'Contabilidade & Legislação',
    'industry_Advertising' => 'Publicidade',
    'industry_Aerospace' => 'Aeronáutica',
    'industry_Agriculture' => 'Agricultura',
    'industry_Automotive' => 'Automóveis',
    'industry_Banking & Finance' => 'Banca & Finanças',
    'industry_Biotechnology' => 'Biotecnologia',
    'industry_Broadcasting' => 'Radiodifusão',
    'industry_Business Services' => 'Serviços Empresariais',
    'industry_Commodities & Chemicals' => 'Produtos Químicos',
    'industry_Communications' => 'Comunicações',
    'industry_Computers & Hightech' => 'Computadores e Tecnologia',
    'industry_Defense' => 'Defesa',
    'industry_Energy' => 'Energia',
    'industry_Entertainment' => 'Entretenimento',
    'industry_Government' => 'Governo',
    'industry_Healthcare & Life Sciences' => 'Saúde & Ciências da Vida',
    'industry_Insurance' => 'Seguros',
    'industry_Manufacturing' => 'Indústria',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Media',
    'industry_Nonprofit & Higher Ed' => 'Sem Finds Lucrativos & Educação',
    'industry_Pharmaceuticals' => 'Fermacêutica',
    'industry_Professional Services & Consulting' => 'Serviços Profissionais & Consultoria',
    'industry_Real Estate' => 'Imobiliária',
    'industry_Restaurant & Catering' => 'Restaurant & Catering',
    'industry_Retail & Wholesale' => 'Retalho & Armazenistas',
    'industry_Sports' => 'Desporto',
    'industry_Transportation' => 'Transporte',
    'industry_Travel & Luxury' => 'Viagens & Luxo',
    'industry_Other' => 'Outros',
    'industry_Photography' => 'Fotografia',

    // Countries
    'country_Afghanistan' => 'Afghanistan',
    'country_Albania' => 'Albania',
    'country_Antarctica' => 'Antarctica',
    'country_Algeria' => 'Algeria',
    'country_American Samoa' => 'American Samoa',
    'country_Andorra' => 'Andorra',
    'country_Angola' => 'Angola',
    'country_Antigua and Barbuda' => 'Antigua and Barbuda',
    'country_Azerbaijan' => 'Azerbaijan',
    'country_Argentina' => 'Argentina',
    'country_Australia' => 'Australia',
    'country_Austria' => 'Austria',
    'country_Bahamas' => 'Bahamas',
    'country_Bahrain' => 'Bahrain',
    'country_Bangladesh' => 'Bangladesh',
    'country_Armenia' => 'Armenia',
    'country_Barbados' => 'Barbados',
    'country_Belgium' => 'Belgium',
    'country_Bermuda' => 'Bermuda',
    'country_Bhutan' => 'Bhutan',
    'country_Bolivia, Plurinational State of' => 'Bolivia, Plurinational State of',
    'country_Bosnia and Herzegovina' => 'Bosnia and Herzegovina',
    'country_Botswana' => 'Botswana',
    'country_Bouvet Island' => 'Bouvet Island',
    'country_Brazil' => 'Brazil',
    'country_Belize' => 'Belize',
    'country_British Indian Ocean Territory' => 'British Indian Ocean Territory',
    'country_Solomon Islands' => 'Solomon Islands',
    'country_Virgin Islands, British' => 'Virgin Islands, British',
    'country_Brunei Darussalam' => 'Brunei Darussalam',
    'country_Bulgaria' => 'Bulgaria',
    'country_Myanmar' => 'Myanmar',
    'country_Burundi' => 'Burundi',
    'country_Belarus' => 'Belarus',
    'country_Cambodia' => 'Cambodia',
    'country_Cameroon' => 'Cameroon',
    'country_Canada' => 'Canada',
    'country_Cape Verde' => 'Cape Verde',
    'country_Cayman Islands' => 'Cayman Islands',
    'country_Central African Republic' => 'Central African Republic',
    'country_Sri Lanka' => 'Sri Lanka',
    'country_Chad' => 'Chad',
    'country_Chile' => 'Chile',
    'country_China' => 'China',
    'country_Taiwan, Province of China' => 'Taiwan, Province of China',
    'country_Christmas Island' => 'Christmas Island',
    'country_Cocos (Keeling) Islands' => 'Cocos (Keeling) Islands',
    'country_Colombia' => 'Colombia',
    'country_Comoros' => 'Comoros',
    'country_Mayotte' => 'Mayotte',
    'country_Congo' => 'Congo',
    'country_Congo, the Democratic Republic of the' => 'Congo, the Democratic Republic of the',
    'country_Cook Islands' => 'Cook Islands',
    'country_Costa Rica' => 'Costa Rica',
    'country_Croatia' => 'Croatia',
    'country_Cuba' => 'Cuba',
    'country_Cyprus' => 'Cyprus',
    'country_Czech Republic' => 'Czech Republic',
    'country_Benin' => 'Benin',
    'country_Denmark' => 'Denmark',
    'country_Dominica' => 'Dominica',
    'country_Dominican Republic' => 'Dominican Republic',
    'country_Ecuador' => 'Ecuador',
    'country_El Salvador' => 'El Salvador',
    'country_Equatorial Guinea' => 'Equatorial Guinea',
    'country_Ethiopia' => 'Ethiopia',
    'country_Eritrea' => 'Eritrea',
    'country_Estonia' => 'Estonia',
    'country_Faroe Islands' => 'Faroe Islands',
    'country_Falkland Islands (Malvinas)' => 'Falkland Islands (Malvinas)',
    'country_South Georgia and the South Sandwich Islands' => 'South Georgia and the South Sandwich Islands',
    'country_Fiji' => 'Fiji',
    'country_Finland' => 'Finland',
    'country_Åland Islands' => 'Åland Islands',
    'country_France' => 'France',
    'country_French Guiana' => 'French Guiana',
    'country_French Polynesia' => 'French Polynesia',
    'country_French Southern Territories' => 'French Southern Territories',
    'country_Djibouti' => 'Djibouti',
    'country_Gabon' => 'Gabon',
    'country_Georgia' => 'Georgia',
    'country_Gambia' => 'Gambia',
    'country_Palestinian Territory, Occupied' => 'Palestinian Territory, Occupied',
    'country_Germany' => 'Germany',
    'country_Ghana' => 'Ghana',
    'country_Gibraltar' => 'Gibraltar',
    'country_Kiribati' => 'Kiribati',
    'country_Greece' => 'Greece',
    'country_Greenland' => 'Greenland',
    'country_Grenada' => 'Grenada',
    'country_Guadeloupe' => 'Guadeloupe',
    'country_Guam' => 'Guam',
    'country_Guatemala' => 'Guatemala',
    'country_Guinea' => 'Guinea',
    'country_Guyana' => 'Guyana',
    'country_Haiti' => 'Haiti',
    'country_Heard Island and McDonald Islands' => 'Heard Island and McDonald Islands',
    'country_Holy See (Vatican City State)' => 'Holy See (Vatican City State)',
    'country_Honduras' => 'Honduras',
    'country_Hong Kong' => 'Hong Kong',
    'country_Hungary' => 'Hungary',
    'country_Iceland' => 'Iceland',
    'country_India' => 'India',
    'country_Indonesia' => 'Indonesia',
    'country_Iran, Islamic Republic of' => 'Iran, Islamic Republic of',
    'country_Iraq' => 'Iraq',
    'country_Ireland' => 'Ireland',
    'country_Israel' => 'Israel',
    'country_Italy' => 'Italy',
    'country_Côte d\'Ivoire' => 'Côte d\'Ivoire',
    'country_Jamaica' => 'Jamaica',
    'country_Japan' => 'Japan',
    'country_Kazakhstan' => 'Kazakhstan',
    'country_Jordan' => 'Jordan',
    'country_Kenya' => 'Kenya',
    'country_Korea, Democratic People\'s Republic of' => 'Korea, Democratic People\'s Republic of',
    'country_Korea, Republic of' => 'Korea, Republic of',
    'country_Kuwait' => 'Kuwait',
    'country_Kyrgyzstan' => 'Kyrgyzstan',
    'country_Lao People\'s Democratic Republic' => 'Lao People\'s Democratic Republic',
    'country_Lebanon' => 'Lebanon',
    'country_Lesotho' => 'Lesotho',
    'country_Latvia' => 'Latvia',
    'country_Liberia' => 'Liberia',
    'country_Libya' => 'Libya',
    'country_Liechtenstein' => 'Liechtenstein',
    'country_Lithuania' => 'Lithuania',
    'country_Luxembourg' => 'Luxembourg',
    'country_Macao' => 'Macao',
    'country_Madagascar' => 'Madagascar',
    'country_Malawi' => 'Malawi',
    'country_Malaysia' => 'Malaysia',
    'country_Maldives' => 'Maldives',
    'country_Mali' => 'Mali',
    'country_Malta' => 'Malta',
    'country_Martinique' => 'Martinique',
    'country_Mauritania' => 'Mauritania',
    'country_Mauritius' => 'Mauritius',
    'country_Mexico' => 'Mexico',
    'country_Monaco' => 'Monaco',
    'country_Mongolia' => 'Mongolia',
    'country_Moldova, Republic of' => 'Moldova, Republic of',
    'country_Montenegro' => 'Montenegro',
    'country_Montserrat' => 'Montserrat',
    'country_Morocco' => 'Morocco',
    'country_Mozambique' => 'Mozambique',
    'country_Oman' => 'Oman',
    'country_Namibia' => 'Namibia',
    'country_Nauru' => 'Nauru',
    'country_Nepal' => 'Nepal',
    'country_Netherlands' => 'Netherlands',
    'country_Curaçao' => 'Curaçao',
    'country_Aruba' => 'Aruba',
    'country_Sint Maarten (Dutch part)' => 'Sint Maarten (Dutch part)',
    'country_Bonaire, Sint Eustatius and Saba' => 'Bonaire, Sint Eustatius and Saba',
    'country_New Caledonia' => 'New Caledonia',
    'country_Vanuatu' => 'Vanuatu',
    'country_New Zealand' => 'New Zealand',
    'country_Nicaragua' => 'Nicaragua',
    'country_Niger' => 'Niger',
    'country_Nigeria' => 'Nigeria',
    'country_Niue' => 'Niue',
    'country_Norfolk Island' => 'Norfolk Island',
    'country_Norway' => 'Norway',
    'country_Northern Mariana Islands' => 'Northern Mariana Islands',
    'country_United States Minor Outlying Islands' => 'United States Minor Outlying Islands',
    'country_Micronesia, Federated States of' => 'Micronesia, Federated States of',
    'country_Marshall Islands' => 'Marshall Islands',
    'country_Palau' => 'Palau',
    'country_Pakistan' => 'Pakistan',
    'country_Panama' => 'Panama',
    'country_Papua New Guinea' => 'Papua New Guinea',
    'country_Paraguay' => 'Paraguay',
    'country_Peru' => 'Peru',
    'country_Philippines' => 'Philippines',
    'country_Pitcairn' => 'Pitcairn',
    'country_Poland' => 'Poland',
    'country_Portugal' => 'Portugal',
    'country_Guinea-Bissau' => 'Guinea-Bissau',
    'country_Timor-Leste' => 'Timor-Leste',
    'country_Puerto Rico' => 'Puerto Rico',
    'country_Qatar' => 'Qatar',
    'country_Réunion' => 'Réunion',
    'country_Romania' => 'Romania',
    'country_Russian Federation' => 'Russian Federation',
    'country_Rwanda' => 'Rwanda',
    'country_Saint Barthélemy' => 'Saint Barthélemy',
    'country_Saint Helena, Ascension and Tristan da Cunha' => 'Saint Helena, Ascension and Tristan da Cunha',
    'country_Saint Kitts and Nevis' => 'Saint Kitts and Nevis',
    'country_Anguilla' => 'Anguilla',
    'country_Saint Lucia' => 'Saint Lucia',
    'country_Saint Martin (French part)' => 'Saint Martin (French part)',
    'country_Saint Pierre and Miquelon' => 'Saint Pierre and Miquelon',
    'country_Saint Vincent and the Grenadines' => 'Saint Vincent and the Grenadines',
    'country_San Marino' => 'San Marino',
    'country_Sao Tome and Principe' => 'Sao Tome and Principe',
    'country_Saudi Arabia' => 'Saudi Arabia',
    'country_Senegal' => 'Senegal',
    'country_Serbia' => 'Serbia',
    'country_Seychelles' => 'Seychelles',
    'country_Sierra Leone' => 'Sierra Leone',
    'country_Singapore' => 'Singapore',
    'country_Slovakia' => 'Slovakia',
    'country_Viet Nam' => 'Viet Nam',
    'country_Slovenia' => 'Slovenia',
    'country_Somalia' => 'Somalia',
    'country_South Africa' => 'South Africa',
    'country_Zimbabwe' => 'Zimbabwe',
    'country_Spain' => 'Spain',
    'country_South Sudan' => 'South Sudan',
    'country_Sudan' => 'Sudan',
    'country_Western Sahara' => 'Western Sahara',
    'country_Suriname' => 'Suriname',
    'country_Svalbard and Jan Mayen' => 'Svalbard and Jan Mayen',
    'country_Swaziland' => 'Swaziland',
    'country_Sweden' => 'Sweden',
    'country_Switzerland' => 'Switzerland',
    'country_Syrian Arab Republic' => 'Syrian Arab Republic',
    'country_Tajikistan' => 'Tajikistan',
    'country_Thailand' => 'Thailand',
    'country_Togo' => 'Togo',
    'country_Tokelau' => 'Tokelau',
    'country_Tonga' => 'Tonga',
    'country_Trinidad and Tobago' => 'Trinidad and Tobago',
    'country_United Arab Emirates' => 'United Arab Emirates',
    'country_Tunisia' => 'Tunisia',
    'country_Turkey' => 'Turkey',
    'country_Turkmenistan' => 'Turkmenistan',
    'country_Turks and Caicos Islands' => 'Turks and Caicos Islands',
    'country_Tuvalu' => 'Tuvalu',
    'country_Uganda' => 'Uganda',
    'country_Ukraine' => 'Ukraine',
    'country_Macedonia, the former Yugoslav Republic of' => 'Macedonia, the former Yugoslav Republic of',
    'country_Egypt' => 'Egypt',
    'country_United Kingdom' => 'United Kingdom',
    'country_Guernsey' => 'Guernsey',
    'country_Jersey' => 'Jersey',
    'country_Isle of Man' => 'Isle of Man',
    'country_Tanzania, United Republic of' => 'Tanzania, United Republic of',
    'country_United States' => 'United States',
    'country_Virgin Islands, U.S.' => 'Virgin Islands, U.S.',
    'country_Burkina Faso' => 'Burkina Faso',
    'country_Uruguay' => 'Uruguay',
    'country_Uzbekistan' => 'Uzbekistan',
    'country_Venezuela, Bolivarian Republic of' => 'Venezuela, Bolivarian Republic of',
    'country_Wallis and Futuna' => 'Wallis and Futuna',
    'country_Samoa' => 'Samoa',
    'country_Yemen' => 'Yemen',
    'country_Zambia' => 'Zambia',

    // Languages
    'lang_Brazilian Portuguese' => 'Português do Brasil',
    'lang_Croatian' => 'Croatian',
    'lang_Czech' => 'Czech',
    'lang_Danish' => 'Danish',
    'lang_Dutch' => 'Dutch',
    'lang_English' => 'English',
    'lang_French' => 'French',
    'lang_French - Canada' => 'French - Canada',
    'lang_German' => 'German',
    'lang_Italian' => 'Italian',
    'lang_Japanese' => 'Japanese',
    'lang_Lithuanian' => 'Lithuanian',
    'lang_Norwegian' => 'Norwegian',
    'lang_Polish' => 'Polish',
    'lang_Spanish' => 'Spanish',
    'lang_Spanish - Spain' => 'Spanish - Spain',
    'lang_Swedish' => 'Swedish',
    'lang_Albanian' => 'Albanian',
    'lang_Greek' => 'Grego',
    'lang_English - United Kingdom' => 'English - United Kingdom',
    'lang_English - Australia' => 'English - Australia',
    'lang_Slovenian' => 'Slovenian',
    'lang_Finnish' => 'Finnish',
    'lang_Romanian' => 'Romanian',
    'lang_Turkish - Turkey' => 'Turkish - Turkey',
    'lang_Portuguese - Brazilian' => 'Portuguese - Brazilian',
    'lang_Portuguese - Portugal' => 'Portuguese - Portugal',
    'lang_Thai' => 'Thai',
    'lang_Macedonian' => 'Macedonian',
    'lang_Chinese - Taiwan' => 'Chinese - Taiwan',
    'lang_Serbian' => 'Serbian',
    'lang_Bulgarian' => 'Bulgarian',
    'lang_Russian' => 'Russian',

    // Industries
    'industry_Accounting & Legal' => 'Contabilidade & Legislação',
    'industry_Advertising' => 'Publicidade',
    'industry_Aerospace' => 'Aeronáutica',
    'industry_Agriculture' => 'Agricultura',
    'industry_Automotive' => 'Automóveis',
    'industry_Banking & Finance' => 'Banca & Finanças',
    'industry_Biotechnology' => 'Biotecnologia',
    'industry_Broadcasting' => 'Radiodifusão',
    'industry_Business Services' => 'Serviços Empresariais',
    'industry_Commodities & Chemicals' => 'Produtos Químicos',
    'industry_Communications' => 'Comunicações',
    'industry_Computers & Hightech' => 'Computadores e Tecnologia',
    'industry_Defense' => 'Defesa',
    'industry_Energy' => 'Energia',
    'industry_Entertainment' => 'Entretenimento',
    'industry_Government' => 'Governo',
    'industry_Healthcare & Life Sciences' => 'Saúde & Ciências da Vida',
    'industry_Insurance' => 'Seguros',
    'industry_Manufacturing' => 'Indústria',
    'industry_Marketing' => 'Marketing',
    'industry_Media' => 'Media',
    'industry_Nonprofit & Higher Ed' => 'Sem Finds Lucrativos & Educação',
    'industry_Pharmaceuticals' => 'Fermacêutica',
    'industry_Professional Services & Consulting' => 'Serviços Profissionais & Consultoria',
    'industry_Real Estate' => 'Imobiliária',
    'industry_Retail & Wholesale' => 'Retalho & Armazenistas',
    'industry_Sports' => 'Desporto',
    'industry_Transportation' => 'Transporte',
    'industry_Travel & Luxury' => 'Viagens & Luxo',
    'industry_Other' => 'Outros',
    'industry_Photography' => 'Fotografia',

    'view_client_portal' => 'View client portal',
    'view_portal' => 'View Portal',
    'vendor_contacts' => 'Vendor Contacts',
    'all' => 'Todos',
    'selected' => 'Selecionados',
    'category' => 'Categoria',
    'categories' => 'Categorias',
    'new_expense_category' => 'Nova Categoria de Despesas',
    'edit_category' => 'Editar Categoria',
    'archive_expense_category' => 'Arquivar Categoria',
    'expense_categories' => 'Categorias de Despesas',
    'list_expense_categories' => 'Listar Categorias de Despesas',
    'updated_expense_category' => 'Categoria de despesa atualizada com sucesso',
    'created_expense_category' => 'Categoria de despesa criada com sucesso',
    'archived_expense_category' => 'Categoria de despesa arquivada com sucesso',
    'archived_expense_categories' => ':count categorias de despesa arquivadas com sucesso',
    'restore_expense_category' => 'Restaurar categoria de despesa',
    'restored_expense_category' => 'Categoria de despesa restaurada com sucesso',
    'apply_taxes' => 'Aplicar impostos',
    'min_to_max_users' => ':min a :max utilizadores',
    'max_users_reached' => 'Atingiu o números máximo de utilizadores.',
    'buy_now_buttons' => 'Botões Comprar Agora',
    'landing_page' => 'Página de Entrada',
    'payment_type' => 'Tipo de Pagamento',
    'form' => 'Formulário',
    'link' => 'Ligação',
    'fields' => 'Campos',
    'dwolla' => 'Dwolla',
    'buy_now_buttons_warning' => 'Nota: o cliente e a nota de pagamento serão criados mesmo que a transacção não seja concluída.',
    'buy_now_buttons_disabled' => 'Esta funcionalidade requer que tenha um produto e um gateway de pagamento configurados.',
    'enable_buy_now_buttons_help' => 'Ativar suporte para botões "comprar agora"',
    'changes_take_effect_immediately' => 'Nota: alterações terão efeito imediato',
    'wepay_account_description' => 'Gateway de pagamento para o Invoice Ninja',
    'payment_error_code' => 'Houve um erro a processar o seu pagamento [:code]. Por favor tente novamente mais tarde.',
    'standard_fees_apply' => 'Taxa: 2.9%/1.2% [Cartão de Cédito/Transf. Bancária] + $0.30 (aprox.
 €0.25) por pagamento realizado.',
    'limit_import_rows' => 'Os dados necessitam de ser importados em parcelas de :count linhas ou menos',
    'error_title' => 'Algo correu mal',
    'error_contact_text' => 'Se gostaria de ajudar por favor contacte-nos pelo endereço :mailaddress',
    'no_undo' => 'Aviso: isto não pode ser revertido.',
    'no_contact_selected' => 'Por favor selecione um contacto',
    'no_client_selected' => 'Por favor selecione um cliente',

    'gateway_config_error' => 'Poderá ajudar a definir novas palavras-passe ou a gerar novas chaves API.',
    'payment_type_on_file' => ':type guardado',
    'invoice_for_client' => 'Nota de Pagamento :invoice para :client',
    'intent_not_found' => 'Desculpe, não entendi o que está a perguntar.',
    'intent_not_supported' => 'Desculpe, Não consigo fazer isso.',
    'client_not_found' => 'Não consegui encontrar o cliente',
    'not_allowed' => 'Desculpe, não tem as permissões necessárias.',
    'bot_emailed_invoice' => 'A sua nota de pagamento foi enviada.',
    'bot_emailed_notify_viewed' => 'Irei enviar-lhe um email quando for visualidada.',
    'bot_emailed_notify_paid' => 'Irei enviar-lhe um email quando for paga.',
    'add_product_to_invoice' => 'Adicionar 1 :product',
    'not_authorized' => 'Não está autorizado',
    'bot_get_email' => 'Hi! (wave)<br/>Thanks for trying the Invoice Ninja Bot.<br/>You need to create a free account to use this bot.<br/>Send me your account email address to get started.',
    'bot_get_code' => 'Obrigado! Vou enviar-lhe um email com o seu código de segurança.',
    'bot_welcome' => 'Feito, a sua conta está verificada.<br/>',
    'email_not_found' => 'Não fui capaz de encontrar uma conta para :email',
    'invalid_code' => 'O código está incorrecto',
    'security_code_email_subject' => 'Código de segurança para o Invoice Ninja Bot',
    'security_code_email_line1' => 'Este é o seu código de segurança para o Invoice Ninja Bot.',
    'security_code_email_line2' => 'Nota: irá expirar em 10 minutos.',
    'bot_help_message' => 'Atualmente suporto:<br/>• Criar/atualizar/enviar uma nota de pagamento<br/>• Listar produtos:<br/><i>Por exemplo:<br/>faturar o bob por 2 bilhetes, definir a data de vencimento para a próxima quinta-feira e o desconto para 10%</i>',
    'list_products' => 'Listar Produtos',

    'include_item_taxes_inline' => 'Incluir <b>impostos dos items no total da linha</b>',
    'created_quotes' => ':count orçamento(s) criados com sucesso.',
    'limited_gateways' => 'Nota: suportamos um gateway de cartão de crédito por empresa.',

    'warning' => 'Aviso',
    'self-update' => 'Atualizar',
    'update_invoiceninja_title' => 'Atualizar Invoice Ninja',
    'update_invoiceninja_warning' => 'Antes de começar a atualizar o Invoice Ninja crie uma cópia de segurança da sua base de dados e ficheiros!',
    'update_invoiceninja_available' => 'Uma nova versão do Invoice Ninja está disponível.',
    'update_invoiceninja_unavailable' => 'Não existe uma versão mais recente do Invoice Ninja.',
    'update_invoiceninja_instructions' => 'Por favor instale a nova versão <strong>:version</strong> clicando <em>Atualizar agora</em> no botão abaixo. Depois será redireccionado para o painel de controlo.',
    'update_invoiceninja_update_start' => 'Atualizar agora',
    'update_invoiceninja_download_start' => 'Transferir :version',
    'create_new' => 'Criar Nova',

    'toggle_navigation' => 'Alternar Navegação',
    'toggle_history' => 'Alternar Histórico',
    'unassigned' => 'Não atribuído',
    'task' => 'Tarefa',
    'contact_name' => 'Nome do Contacto',
    'city_state_postal' => 'Cidade/Distrito/C. Postal',
    'custom_field' => 'Campo Personalizado',
    'account_fields' => 'Campos da Empresa',
    'facebook_and_twitter' => 'Facebook e Twitter',
    'facebook_and_twitter_help' => 'Siga os nossos feeds para nos ajudar a suportar o projecto',
    'reseller_text' => 'Nota: a licença de marca-branca é prevista para uso pessoal, por favor envie um email para :email se desejar revender a aplicação.',
    'unnamed_client' => 'Cliente Sem Nome',

    'day' => 'Dia',
    'week' => 'Semana',
    'month' => 'Mês',
    'inactive_logout' => 'Sessão terminada devido a inatividade',
    'reports' => 'Relatórios',
    'total_profit' => 'Lucro Total',
    'total_expenses' => 'Despesas Totais',
    'quote_to' => 'Orçamento para',

    // Limits
    'limit' => 'Limite',
    'min_limit' => 'Min: :min',
    'max_limit' => 'Max: :max',
    'no_limit' => 'Sem Limites',
    'set_limits' => 'Definir Limites de :gateway_type',
    'enable_min' => 'Ativar min',
    'enable_max' => 'Ativar max',
    'min' => 'Min',
    'max' => 'Max',
    'limits_not_met' => 'Esta Nota de Pag. não cumpre os limites para este tipo de pagamento.',

    'date_range' => 'Interevalo de Datas',
    'raw' => 'Raw',
    'raw_html' => 'Código HTML',
    'update' => 'Atualizar',
    'invoice_fields_help' => 'Arraste os campos para alterar a sua ordem e localização',
    'new_category' => 'Nova Categoria',
    'restore_product' => 'Restaurar Producto',
    'blank' => 'Vazio',
    'invoice_save_error' => 'Houve um erro ao guardar a nota de pagamento',
    'enable_recurring' => 'Ativar Recorrência',
    'disable_recurring' => 'Desativar Recorrência',
    'text' => 'Texto',
    'expense_will_create' => 'a despesa será criada',
    'expenses_will_create' => 'as despesas serão criadas',
    'created_expenses' => ':count despesa(s) criadas com sucesso',

    'translate_app' => 'Ajude a melhorar as nossas traduções com :link',
    'expense_category' => 'Categoria de Despesas',

    'go_ninja_pro' => 'Obtenha o Ninja Pro!',
    'go_enterprise' => 'Obtenha o Enterprise!',
    'upgrade_for_features' => 'Suba de Plano para Obter Mais Funcionalidades',
    'pay_annually_discount' => 'Pague anualmente por 10 meses + 2 grátis!',
    'pro_upgrade_title' => 'Ninja Pro',
    'pro_upgrade_feature1' => 'ASuaMarca.InvoiceNinja.com',
    'pro_upgrade_feature2' => 'Personalize todos os aspectos da sua nota de pagamento!',
    'enterprise_upgrade_feature1' => 'Defina permissões para vários utilizadores',
    'enterprise_upgrade_feature2' => 'Anexe ficheiros de terceiros às suas notas de pagamento & despesas',
    'much_more' => 'Muito Mais!',
    'all_pro_fetaures' => 'Plus all pro features!',

    'currency_symbol' => 'Símbolo',
    'currency_code' => 'Código',

    'buy_license' => 'Comprar Licença',
    'apply_license' => 'Aplicar Linceça',
    'submit' => 'Submeter',
    'white_label_license_key' => 'Chave de Licença',
    'invalid_white_label_license' => 'A licença de marca branca é inválida',
    'created_by' => 'Criado por :nome',
    'modules' => 'Módulos',
    'financial_year_start' => 'Primeiro Mês do Ano',
    'authentication' => 'Autenticação',
    'checkbox' => 'Checkbox',
    'invoice_signature' => 'Assinatura',
    'show_accept_invoice_terms' => 'Checkbox para Termos da Nota de Pagamento',
    'show_accept_invoice_terms_help' => 'Requer que o cliente confirme que aceita os termos da nota de pagamento.',
    'show_accept_quote_terms' => 'Checkbox para Termos do Orçamento',
    'show_accept_quote_terms_help' => 'Requer que o cliente confirme que aceita os termos do orçamento.',
    'require_invoice_signature' => 'Assinatura da Nota de Pagamento',
    'require_invoice_signature_help' => 'Requer que o cliente introduza a sua assinatura.',
    'require_quote_signature' => 'Assinatura de Orçamento',
    'require_quote_signature_help' => 'Pedir ao cliente para providenciar a sua assinatura.',
    'i_agree' => 'Concordo com os termos',
    'sign_here' => 'Por favor assine aqui:',
    'authorization' => 'Autorização',
    'signed' => 'Assinado',

    // BlueVine
    'bluevine_promo' => 'Tenha uma linha de crédito flexível usando BlueVine.',
    'bluevine_modal_label' => 'Registar com BlueVine',
    'bluevine_modal_text' => '<h3>Capital rápido para o seu negócio. Sem papelada.</h3>
<ul><li>Linhas de crédito flexíveis para o seu negócio.</li></ul>',
    'bluevine_create_account' => 'Criar uma conta',
    'quote_types' => 'Pedir orçamento para',
    'invoice_factoring' => 'Faturação de contas',
    'line_of_credit' => 'Linha de crédito',
    'fico_score' => 'Pontuação FICO',
    'business_inception' => 'Data de Criação do Negócio',
    'average_bank_balance' => 'Média do balanço das contas bancárias',
    'annual_revenue' => 'Anual faturado',
    'desired_credit_limit_factoring' => 'Limite de crédito desejado',
    'desired_credit_limit_loc' => 'Limite da linha de crédito desejado',
    'desired_credit_limit' => 'Limite de crédito desejado',
    'bluevine_credit_line_type_required' => 'Deve escolher pelo menos uma',
    'bluevine_field_required' => 'O campo é obrigatório',
    'bluevine_unexpected_error' => 'Ocorreu um erro inesperado.',
    'bluevine_no_conditional_offer' => 'É necessário mais informação antes de obter um orçamento. Clique abaixo para continuar.',
    'bluevine_invoice_factoring' => 'Faturação de Contas',
    'bluevine_conditional_offer' => 'Oferta Condicional',
    'bluevine_credit_line_amount' => 'Linha de Crédito',
    'bluevine_advance_rate' => 'Taxa de Avanço',
    'bluevine_weekly_discount_rate' => 'Taxa de Desconto Semanal',
    'bluevine_minimum_fee_rate' => 'Taxa Mínima',
    'bluevine_line_of_credit' => 'Linha de Crédito',
    'bluevine_interest_rate' => 'Taxa de Juro',
    'bluevine_weekly_draw_rate' => 'Weekly Draw Rate',
    'bluevine_continue' => 'Continuar para BlueVine',
    'bluevine_completed' => 'Registo com o BlueVine concluído',

    'vendor_name' => 'Fornecedor',
    'entity_state' => 'Estado',
    'client_created_at' => 'Data de Criação',
    'postmark_error' => 'Houve um problema ao enviar o email através do Postmark: :link',
    'project' => 'Projeto',
    'projects' => 'Projetos',
    'new_project' => 'Novo Projeto',
    'edit_project' => 'Editar Projeto',
    'archive_project' => 'Arquivar Projeto',
    'list_projects' => 'Listar projetos',
    'updated_project' => 'Projeto atualizado com sucesso',
    'created_project' => 'Projeto criado com sucesso',
    'archived_project' => 'Projeto arquivado com sucesso',
    'archived_projects' => ':count projetos arquivados com sucesso',
    'restore_project' => 'Restore Project',
    'restored_project' => 'Projeto restaurado com sucesso',
    'delete_project' => 'Delete Project',
    'deleted_project' => 'Projeto apagado com sucesso',
    'deleted_projects' => ':count projectos apagadas com sucesso',
    'delete_expense_category' => 'Apagar categoria',
    'deleted_expense_category' => 'Categoria apagada com sucesso',
    'delete_product' => 'Delete Product',
    'deleted_product' => 'Producto apagado com sucesso',
    'deleted_products' => ':count produtos apagados com sucesso',
    'restored_product' => 'Produto restaurado com sucesso',
    'update_credit' => 'Atualizar Crédito',
    'updated_credit' => 'Crédito atualizado com sucesso',
    'edit_credit' => 'Editar Crédito',
    'realtime_preview' => 'Realtime Preview',
    'realtime_preview_help' => 'Realtime refresh PDF preview on the invoice page when editing invoice.<br/>Disable this to improve performance when editing invoices.',
    'live_preview_help' => 'Display a live PDF preview on the invoice page.',
    'force_pdfjs_help' => 'Trocar o visualizador de PDF padrão em :chrome_link e :firefox_link.<br/>Ativar isto se o seu browser está a transferir o PDF automaticamente.',
    'force_pdfjs' => 'Evitar Transferência',
    'redirect_url' => 'Redirecionar URL',
    'redirect_url_help' => 'Opcionalmente especifique um URL para redirecionar após a introdução do pagamento',
    'save_draft' => 'Guardar Rascunho',
    'refunded_credit_payment' => 'Pagamento de crédito reembolsado',
    'keyboard_shortcuts' => 'Atalhos de Teclado',
    'toggle_menu' => 'Alternar Menu',
    'new_...' => 'Novo ...',
    'list_...' => 'Listar ...',
    'created_at' => 'Date Created',
    'contact_us' => 'Contacte-nos',
    'user_guide' => 'Guia do Utilizador',
    'promo_message' => 'Atualizar antes de :expires para obter :amount de desconto no seu primeiro ano dos pacotes Pro e Enterprise.',
    'discount_message' => ':amount de desconte expira a :expires',
    'mark_paid' => 'Marcar como Pago',
    'marked_sent_invoice' => 'Nota de pagamento marcada como enviada com sucesso',
    'marked_sent_invoices' => 'Notas de pagamento marcadas como enviadas com sucesso',
    'invoice_name' => 'Nota de Pagamento',
    'product_will_create' => 'produto será criado',
    'contact_us_response' => 'Obrigado pela sua mensagem! Vamos tentar responder o mais breve possível.',
    'last_7_days' => 'Últimos 7 dias',
    'last_30_days' => 'Últimos 30 dias',
    'this_month' => 'Este Mês',
    'last_month' => 'Último Mês',
    'current_quarter' => 'Current Quarter',
    'last_quarter' => 'Last Quarter',
    'last_year' => 'Último Ano',
    'custom_range' => 'Intervalo Personalizado',
    'url' => 'URL',
    'debug' => 'Debug',
    'https' => 'HTTPS',
    'require' => 'Requerer',
    'license_expiring' => 'Nota: A sua licença expira em :count dias, :link para renovar.',
    'security_confirmation' => 'O seu email foi confirmado.',
    'white_label_expired' => 'A sua licença de marca branca expirou, por favor consider renovar para suportar o nosso projecto.',
    'renew_license' => 'Renovar Licença',
    'iphone_app_message' => 'Considere transferir o nosso :link',
    'iphone_app' => 'iPhone app',
    'android_app' => 'Android app',
    'logged_in' => 'Sessão iniciada',
    'switch_to_primary' => 'Altere para a sua empresa primária (:name) para gerir o seu plano.',
    'inclusive' => 'Inclusive',
    'exclusive' => 'Exclusive',
    'postal_city_state' => 'Código-Postal/Cidade/Distrito',
    'phantomjs_help' => 'Em certos casos a aplicação utiliza :link_phantom para gerar os PDF, instale :link_docs para gerar os PDF localmente.',
    'phantomjs_local' => 'Usar PhantomJS local',
    'client_number' => 'Nº Cliente',
    'client_number_help' => 'Especifique um prefixo ou utilize um padrão personalizado para definir dinamicamente o número do cliente.',
    'next_client_number' => 'O próximo cliente será o número :number.',
    'generated_numbers' => 'Números gerados',
    'notes_reminder1' => 'Primeiro lembrete',
    'notes_reminder2' => 'Segundo lembrete',
    'notes_reminder3' => 'Terceiro Lembrete',
    'notes_reminder4' => 'Reminder',
    'bcc_email' => 'Email BCC',
    'tax_quote' => 'Imposto do orçamento',
    'tax_invoice' => 'Imposto da nota de pag.',
    'emailed_invoices' => 'Notas de pag. enviadas com sucesso',
    'emailed_quotes' => 'Orçamentos enviados com sucesso',
    'website_url' => 'Website URL',
    'domain' => 'Domínio',
    'domain_help' => 'Usado no portal do cliente e quando se enviam emails',
    'domain_help_website' => 'Usado quando se enviam emails.',
    'import_invoices' => 'Importar notas de pag.',
    'new_report' => 'Novo relatório',
    'edit_report' => 'Editar relatório',
    'columns' => 'Colunas',
    'filters' => 'Filtros',
    'sort_by' => 'Ordenar por',
    'draft' => 'Rascunho',
    'unpaid' => 'Não pago',
    'aging' => 'Vencidas',
    'age' => 'Idade',
    'days' => 'Dias',
    'age_group_0' => '0 - 30 Dias',
    'age_group_30' => '30 - 60 Dias',
    'age_group_60' => '60 - 90 Dias',
    'age_group_90' => '90 - 120 Dias',
    'age_group_120' => '120+ Dias',
    'invoice_details' => 'Detalhes da nota de pag.',
    'qty' => 'Quantidade',
    'profit_and_loss' => 'Lucro e prejuízo',
    'revenue' => 'Faturado',
    'profit' => 'Lucro',
    'group_when_sorted' => 'Group Sort',
    'group_dates_by' => 'Agrupar datas por',
    'year' => 'Ano',
    'view_statement' => 'Visualizar declaração',
    'statement' => 'Declaração',
    'statement_date' => 'Data da declaração',
    'mark_active' => 'Ativar',
    'send_automatically' => 'Enviar automaticamente',
    'initial_email' => 'Email inicial',
    'invoice_not_emailed' => 'Esta nota de pag. não foi enviada.',
    'quote_not_emailed' => 'Este orçamento não não foi enviado.',
    'sent_by' => 'Enviado por :user',
    'recipients' => 'Destinatários',
    'save_as_default' => 'Guardar como padrão',
    'start_of_week_help' => 'Utilizado pelos selectores <b>date</b>',
    'financial_year_start_help' => 'Utilizado pelos selectores <b>interevalo de data>',
    'reports_help' => 'Shift + Click to sort by multiple columns, Ctrl + Click to clear the grouping.',
    'this_year' => 'Este ano',

    // Updated login screen
    'ninja_tagline' => 'Criar. Enviar. Ser Pago.',
    'login_or_existing' => 'Or login with a connected account.',
    'sign_up_now' => 'Inicie sessão agora',
    'not_a_member_yet' => 'Ainda não é membro?',
    'login_create_an_account' => 'Criar uma conta!',

    // New Client Portal styling
    'invoice_from' => 'Notas de pag. From:',
    'email_alias_message' => 'Cada empresa deve ter um único email. <br/>Consider utilizar um alias. ex, email+label@example.com',
    'full_name' => 'Nome completo',
    'month_year' => 'MÊS/ANO',
    'valid_thru' => 'Válido\npor',

    'product_fields' => 'Campos do produto',
    'custom_product_fields_help' => 'Adicionar um campo quando criar um produto ou nota de pag. e mostrar esse campo e valor no PDF.',
    'freq_two_months' => 'Dois meses',
    'freq_yearly' => 'Anualmente',
    'profile' => 'Perfil',
    'payment_type_help' => 'Definir como padrão <b>Tipo de pagamento manual</b>.',
    'industry_Construction' => 'Indústria',
    'your_statement' => 'A declaração',
    'statement_issued_to' => 'Relatório aplicado a',
    'statement_to' => 'Declaração para',
    'customize_options' => 'Personalizar opções',
    'created_payment_term' => 'Criado termo de pagamento com sucesso',
    'updated_payment_term' => 'Atualizado termo de pagamento com sucesso',
    'archived_payment_term' => 'Arquivado termo de pagamento com sucesso',
    'resend_invite' => 'Reenviar convite',
    'credit_created_by' => 'Crédito criado por pagamento :transaction_reference',
    'created_payment_and_credit' => 'Criado pagamento e crédito com sucesso',
    'created_payment_and_credit_emailed_client' => 'Criado pagamento e crédito com sucesso, e cliente informado.',
    'create_project' => 'Criar projeto',
    'create_vendor' => 'Criar fornecedor',
    'create_expense_category' => 'Criar categoria',
    'pro_plan_reports' => ':link para ativar relatórios aderindo ao plano Pro',
    'mark_ready' => 'Marcar concluido',

    'limits' => 'Limites',
    'fees' => 'Taxas',
    'fee' => 'Taxa',
    'set_limits_fees' => 'Definir :gateway_type Limits/Fees',
    'fees_tax_help' => 'Ativar taxas do item para definir as taxas de imposto.',
    'fees_sample' => 'A taxa para :amount nota de pag. deve ser :total.',
    'discount_sample' => 'O desconto para :amount nota de pag. deve ser :total.',
    'no_fees' => 'Sem taxas',
    'gateway_fees_disclaimer' => 'Aviso: nem todos os estados/gateways de pagamento permitem adicionar taxas, por favor verifique a sua legislação/termos de serviço locais.',
    'percent' => 'Percentagem',
    'location' => 'Localização',
    'line_item' => 'Item',
    'surcharge' => 'Sobretaxa',
    'location_first_surcharge' => 'Ativo - Primeira Sobretaxa',
    'location_second_surcharge' => 'Ativo - Segunda sobretaxa',
    'location_line_item' => 'Ativo - Item',
    'online_payment_surcharge' => 'Taxa de Pagamento Online',
    'gateway_fees' => 'Taxas Gateway',
    'fees_disabled' => 'Taxas estão desativadas',
    'gateway_fees_help' => 'Automaticamente adicionar uma taxa/desconto ao pagamento online.',
    'gateway' => 'Gateway',
    'gateway_fee_change_warning' => 'Se tiver notas de pag. não pagas terá que atualizar as taxas manualmente.',
    'fees_surcharge_help' => 'Personalizar taxa :link.',
    'label_and_taxes' => 'etiquetas e impostos',
    'billable' => 'Faturável',
    'logo_warning_too_large' => 'A imagem é muito grande.',
    'logo_warning_fileinfo' => 'Aviso: Para suportar GIFSa extensão fileinfo PHP etem que estar ativa.',
    'logo_warning_invalid' => 'Há um problemas a ler a imagem, por favor tente outro formato.',

    'error_refresh_page' => 'An error occurred, please refresh the page and try again.',
    'data' => 'Data',
    'imported_settings' => 'Definições importadas com sucesso',
    'reset_counter' => 'Redefinir contador',
    'next_reset' => 'Próxima redefinição',
    'reset_counter_help' => 'Redefinir automaticamente os contadores das notas de pag. e dos orçamentos.',
    'auto_bill_failed' => 'Auto-faturar para a nota de pag. :invoice_number failed',
    'online_payment_discount' => 'Desconto de pagamento online',
    'created_new_company' => 'Nova empresa criada com sucesso',
    'fees_disabled_for_gateway' => 'Taxas desativadas para este gateway.',
    'logout_and_delete' => 'Sair/Apagar conta',
    'tax_rate_type_help' => 'Inclusive tax rates adjust the line item cost when selected.<br/>Only exclusive tax rates can be used as a default.',
    'invoice_footer_help' => 'Usar $pageNumber e $pageCount para mostrar a informação da página.',
    'credit_note' => 'Nota de crédito',
    'credit_issued_to' => 'Crédito atribuido a',
    'credit_to' => 'Crédito para',
    'your_credit' => 'A sua Nota de crédito',
    'credit_number' => 'Nota de rédito número',
    'create_credit_note' => 'Criar nota de crédito',
    'menu' => 'Menu',
    'error_incorrect_gateway_ids' => 'Erro: A tabela de gateways tem ids incorretos.',
    'purge_data' => 'Purgar dados',
    'delete_data' => 'Apagar dados',
    'purge_data_help' => 'Permanently delete all data but keep the account and settings.',
    'cancel_account_help' => 'Apagar permanentemente a conta, todos os dados e as definições.',
    'purge_successful' => 'Successfully purged company data',
    'forbidden' => 'Proibido',
    'purge_data_message' => 'Aviso: apagará todos os seus dados.',
    'contact_phone' => 'Contato telefónico',
    'contact_email' => 'Email',
    'reply_to_email' => 'Email de resposta',
    'reply_to_email_help' => 'Especificar o email de resposa para os clientes',
    'bcc_email_help' => 'Incluir este email com os emais do cliente.',
    'import_complete' => 'A importação está completa.',
    'confirm_account_to_import' => 'Por favor confirme a sua conta para importar os dados.',
    'import_started' => 'A importação começou, quando estiver completa receberá um email.',
    'listening' => 'A ouvir...',
    'microphone_help' => 'Diga "nova nota de pag. para [cliente] ou "mostre-me o pagamentos arquivados de [cliente]"',
    'voice_commands' => 'Comandos de voz',
    'sample_commands' => 'Comandos de exemplo',
    'voice_commands_feedback' => 'Estamos a trabalhar para melhorar esta questão, se quiser por enviar-nos um email para :email.',
    'payment_type_Venmo' => 'Venmo',
    'payment_type_Money Order' => 'Money Order',
    'archived_products' => ':count Produtos arquivados com sucesso',
    'recommend_on' => 'Recomendamos <b>ativar</b> esta definição.',
    'recommend_off' => 'Recomendamos <b>desativar</b> esta definição.',
    'notes_auto_billed' => 'Auto-cobrado',
    'surcharge_label' => 'Etiqueta de Sobretaxa',
    'contact_fields' => 'Campos de contato',
    'custom_contact_fields_help' => 'Add a field when creating a contact and optionally display the label and value on the PDF.',
    'datatable_info' => 'A mostrar :start a :end de :total entradas',
    'credit_total' => 'Total em crédito',
    'mark_billable' => 'Marcar faturável',
    'billed' => 'Faturado',
    'company_variables' => 'Variáveis da empresa',
    'client_variables' => 'Variáveis do cliente',
    'invoice_variables' => 'Variáveis da nota de pag.',
    'navigation_variables' => 'Variáveis de navegação',
    'custom_variables' => 'Variáveis personalizadas',
    'invalid_file' => 'Tipo de ficheiro inválido',
    'add_documents_to_invoice' => 'Adicionar documento à nota de pag.',
    'mark_expense_paid' => 'Marcar Pago',
    'white_label_license_error' => 'Falhou a validar a licença, verifique storage/logs/laravel-error.log para mais detalhes.',
    'plan_price' => 'Plan Price',
    'wrong_confirmation' => 'Incorrect confirmation code',
    'oauth_taken' => 'The account is already registered',
    'emailed_payment' => 'Successfully emailed payment',
    'email_payment' => 'Email Payment',
    'invoiceplane_import' => 'Use :link to migrate your data from InvoicePlane.',
    'duplicate_expense_warning' => 'Warning: This :link may be a duplicate',
    'expense_link' => 'expense',
    'resume_task' => 'Resume Task',
    'resumed_task' => 'Successfully resumed task',
    'quote_design' => 'Quote Design',
    'default_design' => 'Standard Design',
    'custom_design1' => 'Custom Design 1',
    'custom_design2' => 'Custom Design 2',
    'custom_design3' => 'Custom Design 3',
    'empty' => 'Empty',
    'load_design' => 'Load Design',
    'accepted_card_logos' => 'Accepted Card Logos',
    'phantomjs_local_and_cloud' => 'Using local PhantomJS, falling back to phantomjscloud.com',
    'google_analytics' => 'Google Analytics',
    'analytics_key' => 'Analytics Key',
    'analytics_key_help' => 'Track payments using :link',
    'start_date_required' => 'The start date is required',
    'application_settings' => 'Application Settings',
    'database_connection' => 'Database Connection',
    'driver' => 'Driver',
    'host' => 'Host',
    'database' => 'Database',
    'test_connection' => 'Test connection',
    'from_name' => 'From Name',
    'from_address' => 'From Address',
    'port' => 'Port',
    'encryption' => 'Encryption',
    'mailgun_domain' => 'Mailgun Domain',
    'mailgun_private_key' => 'Mailgun Private Key',
    'send_test_email' => 'Send test email',
    'select_label' => 'Select Label',
    'label' => 'Label',
    'service' => 'Service',
    'update_payment_details' => 'Update payment details',
    'updated_payment_details' => 'Successfully updated payment details',
    'update_credit_card' => 'Update Credit Card',
    'recurring_expenses' => 'Recurring Expenses',
    'recurring_expense' => 'Recurring Expense',
    'new_recurring_expense' => 'New Recurring Expense',
    'edit_recurring_expense' => 'Edit Recurring Expense',
    'archive_recurring_expense' => 'Archive Recurring Expense',
    'list_recurring_expense' => 'List Recurring Expenses',
    'updated_recurring_expense' => 'Successfully updated recurring expense',
    'created_recurring_expense' => 'Successfully created recurring expense',
    'archived_recurring_expense' => 'Successfully archived recurring expense',
    'restore_recurring_expense' => 'Restore Recurring Expense',
    'restored_recurring_expense' => 'Successfully restored recurring expense',
    'delete_recurring_expense' => 'Delete Recurring Expense',
    'deleted_recurring_expense' => 'Successfully deleted project',
    'view_recurring_expense' => 'View Recurring Expense',
    'taxes_and_fees' => 'Taxes and fees',
    'import_failed' => 'Import Failed',
    'recurring_prefix' => 'Recurring Prefix',
    'options' => 'Options',
    'credit_number_help' => 'Specify a prefix or use a custom pattern to dynamically set the credit number for negative invoices.',
    'next_credit_number' => 'The next credit number is :number.',
    'padding_help' => 'The number of zero\'s to pad the number.',
    'import_warning_invalid_date' => 'Warning: The date format appears to be invalid.',
    'product_notes' => 'Product Notes',
    'app_version' => 'App Version',
    'ofx_version' => 'OFX Version',
    'gateway_help_23' => ':link to get your Stripe API keys.',
    'error_app_key_set_to_default' => 'Error: APP_KEY is set to a default value, to update it backup your database and then run <code>php artisan ninja:update-key</code>',
    'charge_late_fee' => 'Charge Late Fee',
    'late_fee_amount' => 'Late Fee Amount',
    'late_fee_percent' => 'Late Fee Percent',
    'late_fee_added' => 'Late fee added on :date',
    'download_invoice' => 'Download Invoice',
    'download_quote' => 'Download Quote',
    'invoices_are_attached' => 'Your invoice PDFs are attached.',
    'downloaded_invoice' => 'An email will be sent with the invoice PDF',
    'downloaded_quote' => 'An email will be sent with the quote PDF',
    'downloaded_invoices' => 'An email will be sent with the invoice PDFs',
    'downloaded_quotes' => 'An email will be sent with the quote PDFs',
    'clone_expense' => 'Clone Expense',
    'default_documents' => 'Default Documents',
    'send_email_to_client' => 'Send email to the client',
    'refund_subject' => 'Refund Processed',
    'refund_body' => 'You have been processed a refund of :amount for invoice :invoice_number.',

    'currency_us_dollar' => 'US Dollar',
    'currency_british_pound' => 'British Pound',
    'currency_euro' => 'Euro',
    'currency_south_african_rand' => 'South African Rand',
    'currency_danish_krone' => 'Danish Krone',
    'currency_israeli_shekel' => 'Israeli Shekel',
    'currency_swedish_krona' => 'Swedish Krona',
    'currency_kenyan_shilling' => 'Kenyan Shilling',
    'currency_canadian_dollar' => 'Canadian Dollar',
    'currency_philippine_peso' => 'Philippine Peso',
    'currency_indian_rupee' => 'Indian Rupee',
    'currency_australian_dollar' => 'Australian Dollar',
    'currency_singapore_dollar' => 'Singapore Dollar',
    'currency_norske_kroner' => 'Norske Kroner',
    'currency_new_zealand_dollar' => 'New Zealand Dollar',
    'currency_vietnamese_dong' => 'Vietnamese Dong',
    'currency_swiss_franc' => 'Swiss Franc',
    'currency_guatemalan_quetzal' => 'Guatemalan Quetzal',
    'currency_malaysian_ringgit' => 'Malaysian Ringgit',
    'currency_brazilian_real' => 'Brazilian Real',
    'currency_thai_baht' => 'Thai Baht',
    'currency_nigerian_naira' => 'Nigerian Naira',
    'currency_argentine_peso' => 'Argentine Peso',
    'currency_bangladeshi_taka' => 'Bangladeshi Taka',
    'currency_united_arab_emirates_dirham' => 'United Arab Emirates Dirham',
    'currency_hong_kong_dollar' => 'Hong Kong Dollar',
    'currency_indonesian_rupiah' => 'Indonesian Rupiah',
    'currency_mexican_peso' => 'Mexican Peso',
    'currency_egyptian_pound' => 'Egyptian Pound',
    'currency_colombian_peso' => 'Colombian Peso',
    'currency_west_african_franc' => 'West African Franc',
    'currency_chinese_renminbi' => 'Chinese Renminbi',
    'currency_rwandan_franc' => 'Rwandan Franc',
    'currency_tanzanian_shilling' => 'Tanzanian Shilling',
    'currency_netherlands_antillean_guilder' => 'Netherlands Antillean Guilder',
    'currency_trinidad_and_tobago_dollar' => 'Trinidad and Tobago Dollar',
    'currency_east_caribbean_dollar' => 'East Caribbean Dollar',
    'currency_ghanaian_cedi' => 'Ghanaian Cedi',
    'currency_bulgarian_lev' => 'Bulgarian Lev',
    'currency_aruban_florin' => 'Aruban Florin',
    'currency_turkish_lira' => 'Turkish Lira',
    'currency_romanian_new_leu' => 'Romanian New Leu',
    'currency_croatian_kuna' => 'Croatian Kuna',
    'currency_saudi_riyal' => 'Saudi Riyal',
    'currency_japanese_yen' => 'Japanese Yen',
    'currency_maldivian_rufiyaa' => 'Maldivian Rufiyaa',
    'currency_costa_rican_colon' => 'Costa Rican Colón',
    'currency_pakistani_rupee' => 'Pakistani Rupee',
    'currency_polish_zloty' => 'Polish Zloty',
    'currency_sri_lankan_rupee' => 'Sri Lankan Rupee',
    'currency_czech_koruna' => 'Czech Koruna',
    'currency_uruguayan_peso' => 'Uruguayan Peso',
    'currency_namibian_dollar' => 'Namibian Dollar',
    'currency_tunisian_dinar' => 'Tunisian Dinar',
    'currency_russian_ruble' => 'Russian Ruble',
    'currency_mozambican_metical' => 'Mozambican Metical',
    'currency_omani_rial' => 'Omani Rial',
    'currency_ukrainian_hryvnia' => 'Ukrainian Hryvnia',
    'currency_macanese_pataca' => 'Macanese Pataca',
    'currency_taiwan_new_dollar' => 'Taiwan New Dollar',
    'currency_dominican_peso' => 'Dominican Peso',
    'currency_chilean_peso' => 'Chilean Peso',
    'currency_icelandic_krona' => 'Icelandic Króna',
    'currency_papua_new_guinean_kina' => 'Papua New Guinean Kina',
    'currency_jordanian_dinar' => 'Jordanian Dinar',
    'currency_myanmar_kyat' => 'Myanmar Kyat',
    'currency_peruvian_sol' => 'Peruvian Sol',
    'currency_botswana_pula' => 'Botswana Pula',
    'currency_hungarian_forint' => 'Hungarian Forint',
    'currency_ugandan_shilling' => 'Ugandan Shilling',
    'currency_barbadian_dollar' => 'Barbadian Dollar',
    'currency_brunei_dollar' => 'Brunei Dollar',
    'currency_georgian_lari' => 'Georgian Lari',
    'currency_qatari_riyal' => 'Qatari Riyal',
    'currency_honduran_lempira' => 'Honduran Lempira',
    'currency_surinamese_dollar' => 'Surinamese Dollar',
    'currency_bahraini_dinar' => 'Bahraini Dinar',
    'currency_venezuelan_bolivars' => 'Venezuelan Bolivars',
    'currency_south_korean_won' => 'South Korean Won',
    'currency_moroccan_dirham' => 'Moroccan Dirham',
    'currency_jamaican_dollar' => 'Jamaican Dollar',
    'currency_angolan_kwanza' => 'Angolan Kwanza',
    'currency_haitian_gourde' => 'Haitian Gourde',
    'currency_zambian_kwacha' => 'Zambian Kwacha',
    'currency_nepalese_rupee' => 'Nepalese Rupee',
    'currency_cfp_franc' => 'CFP Franc',
    'currency_mauritian_rupee' => 'Mauritian Rupee',
    'currency_cape_verdean_escudo' => 'Cape Verdean Escudo',
    'currency_kuwaiti_dinar' => 'Kuwaiti Dinar',
    'currency_algerian_dinar' => 'Algerian Dinar',
    'currency_macedonian_denar' => 'Macedonian Denar',
    'currency_fijian_dollar' => 'Fijian Dollar',
    'currency_bolivian_boliviano' => 'Bolivian Boliviano',
    'currency_albanian_lek' => 'Albanian Lek',
    'currency_serbian_dinar' => 'Serbian Dinar',
    'currency_lebanese_pound' => 'Lebanese Pound',
    'currency_armenian_dram' => 'Armenian Dram',
    'currency_azerbaijan_manat' => 'Azerbaijan Manat',
    'currency_bosnia_and_herzegovina_convertible_mark' => 'Bosnia and Herzegovina Convertible Mark',
    'currency_belarusian_ruble' => 'Belarusian Ruble',
    'currency_moldovan_leu' => 'Moldovan Leu',
    'currency_kazakhstani_tenge' => 'Kazakhstani Tenge',
    'currency_gibraltar_pound' => 'Gibraltar Pound',

    'review_app_help' => 'We hope you\'re enjoying using the app.<br/>If you\'d consider :link we\'d greatly appreciate it!',
    'writing_a_review' => 'writing a review',

    'use_english_version' => 'Make sure to use the English version of the files.<br/>We use the column headers to match the fields.',
    'tax1' => 'First Tax',
    'tax2' => 'Second Tax',
    'fee_help' => 'Gateway fees are the costs charged for access to the financial networks that handle the processing of online payments.',
    'format_export' => 'Exporting format',
    'custom1' => 'First Custom',
    'custom2' => 'Second Custom',
    'contact_first_name' => 'Contact First Name',
    'contact_last_name' => 'Contact Last Name',
    'contact_custom1' => 'Contact First Custom',
    'contact_custom2' => 'Contact Second Custom',
    'currency' => 'Currency',
    'ofx_help' => 'To troubleshoot check for comments on :ofxhome_link and test with :ofxget_link.',
    'comments' => 'comments',

    'item_product' => 'Item Product',
    'item_notes' => 'Item Notes',
    'item_cost' => 'Item Cost',
    'item_quantity' => 'Item Quantity',
    'item_tax_rate' => 'Item Tax Rate',
    'item_tax_name' => 'Item Tax Name',
    'item_tax1' => 'Item Tax1',
    'item_tax2' => 'Item Tax2',

    'delete_company' => 'Delete Company',
    'delete_company_help' => 'Permanently delete the company along with all data and setting.',
    'delete_company_message' => 'Warning: This will permanently delete your company, there is no undo.',

    'applied_discount' => 'The coupon has been applied, the plan price has been reduced by :discount%.',
    'applied_free_year' => 'The coupon has been applied, your account has been upgraded to pro for one year.',

    'contact_us_help' => 'If you\'re reporting an error please include any relevant logs from storage/logs/laravel-error.log',
    'include_errors' => 'Include Errors',
    'include_errors_help' => 'Include :link from storage/logs/laravel-error.log',
    'recent_errors' => 'recent errors',
    'customer' => 'Customer',
    'customers' => 'Customers',
    'created_customer' => 'Successfully created customer',
    'created_customers' => 'Successfully created :count customers',

    'purge_details' => 'The data in your company (:account) has been successfully purged.',
    'deleted_company' => 'Successfully deleted company',
    'deleted_account' => 'Successfully canceled account',
    'deleted_company_details' => 'Your company (:account) has been successfully deleted.',
    'deleted_account_details' => 'Your account (:account) has been successfully deleted.',

    'alipay' => 'Alipay',
    'sofort' => 'Sofort',
    'sepa' => 'SEPA Direct Debit',
    'enable_alipay' => 'Accept Alipay',
    'enable_sofort' => 'Accept EU bank transfers',
    'stripe_alipay_help' => 'These gateways also need to be activated in :link.',
    'calendar' => 'Calendar',
    'pro_plan_calendar' => ':link to enable the calendar by joining the Pro Plan',

    'what_are_you_working_on' => 'What are you working on?',
    'time_tracker' => 'Time Tracker',
    'refresh' => 'Refresh',
    'filter_sort' => 'Filter/Sort',
    'no_description' => 'No Description',
    'time_tracker_login' => 'Time Tracker Login',
    'save_or_discard' => 'Save or discard your changes',
    'discard_changes' => 'Discard Changes',
    'tasks_not_enabled' => 'Tasks are not enabled.',
    'started_task' => 'Successfully started task',
    'create_client' => 'Create Client',

    'download_desktop_app' => 'Download the desktop app',
    'download_iphone_app' => 'Download the iPhone app',
    'download_android_app' => 'Download the Android app',
    'time_tracker_mobile_help' => 'Double tap a task to select it',
    'stopped' => 'Stopped',
    'ascending' => 'Ascending',
    'descending' => 'Descending',
    'sort_field' => 'Sort By',
    'sort_direction' => 'Direction',
    'discard' => 'Discard',
    'time_am' => 'AM',
    'time_pm' => 'PM',
    'time_mins' => 'mins',
    'time_hr' => 'hr',
    'time_hrs' => 'hrs',
    'clear' => 'Clear',
    'warn_payment_gateway' => 'Note: accepting online payments requires a payment gateway, :link to add one.',
    'task_rate' => 'Task Rate',
    'task_rate_help' => 'Set the default rate for invoiced tasks.',
    'past_due' => 'Past Due',
    'document' => 'Document',
    'invoice_or_expense' => 'Invoice/Expense',
    'invoice_pdfs' => 'Invoice PDFs',
    'enable_sepa' => 'Accept SEPA',
    'enable_bitcoin' => 'Accept Bitcoin',
    'iban' => 'IBAN',
    'sepa_authorization' => 'By providing your IBAN and confirming this payment, you are authorizing :company and Stripe, our payment service provider, to send instructions to your bank to debit your account and your bank to debit your account in accordance with those instructions. You are entitled to a refund from your bank under the terms and conditions of your agreement with your bank. A refund must be claimed within 8 weeks starting from the date on which your account was debited.',
    'recover_license' => 'Recover License',
    'purchase' => 'Purchase',
    'recover' => 'Recover',
    'apply' => 'Apply',
    'recover_white_label_header' => 'Recover White Label License',
    'apply_white_label_header' => 'Apply White Label License',
    'videos' => 'Videos',
    'video' => 'Video',
    'return_to_invoice' => 'Return to Invoice',
    'gateway_help_13' => 'To use ITN leave the PDT Key field blank.',
    'partial_due_date' => 'Partial Due Date',
    'task_fields' => 'Task Fields',
    'product_fields_help' => 'Drag and drop fields to change their order',
    'custom_value1' => 'Custom Value',
    'custom_value2' => 'Custom Value',
    'enable_two_factor' => 'Two-Factor Authentication',
    'enable_two_factor_help' => 'Use your phone to confirm your identity when logging in',
    'two_factor_setup' => 'Two-Factor Setup',
    'two_factor_setup_help' => 'Scan the bar code with a :link compatible app.',
    'one_time_password' => 'One Time Password',
    'set_phone_for_two_factor' => 'Set your mobile phone number as a backup to enable.',
    'enabled_two_factor' => 'Successfully enabled Two-Factor Authentication',
    'add_product' => 'Add Product',
    'email_will_be_sent_on' => 'Note: the email will be sent on :date.',
    'invoice_product' => 'Invoice Product',
    'self_host_login' => 'Self-Host Login',
    'set_self_hoat_url' => 'Self-Host URL',
    'local_storage_required' => 'Error: local storage is not available.',
    'your_password_reset_link' => 'Your Password Reset Link',
    'subdomain_taken' => 'The subdomain is already in use',
    'client_login' => 'Iniciar sessão como cliente',
    'converted_amount' => 'Converted Amount',
    'default' => 'Default',
    'shipping_address' => 'Shipping Address',
    'bllling_address' => 'Billing Address',
    'billing_address1' => 'Billing Street',
    'billing_address2' => 'Billing Apt/Suite',
    'billing_city' => 'Billing City',
    'billing_state' => 'Billing State/Province',
    'billing_postal_code' => 'Billing Postal Code',
    'billing_country' => 'Billing Country',
    'shipping_address1' => 'Shipping Street',
    'shipping_address2' => 'Shipping Apt/Suite',
    'shipping_city' => 'Shipping City',
    'shipping_state' => 'Shipping State/Province',
    'shipping_postal_code' => 'Shipping Postal Code',
    'shipping_country' => 'Shipping Country',
    'classify' => 'Classify',
    'show_shipping_address_help' => 'Require client to provide their shipping address',
    'ship_to_billing_address' => 'Ship to billing address',
    'delivery_note' => 'Delivery Note',
    'show_tasks_in_portal' => 'Show tasks in the client portal',
    'cancel_schedule' => 'Cancel Schedule',
    'scheduled_report' => 'Scheduled Report',
    'scheduled_report_help' => 'Email the :report report as :format to :email',
    'created_scheduled_report' => 'Successfully scheduled report',
    'deleted_scheduled_report' => 'Successfully canceled scheduled report',
    'scheduled_report_attached' => 'Your scheduled :type report is attached.',
    'scheduled_report_error' => 'Failed to create schedule report',
    'invalid_one_time_password' => 'Invalid one time password',
    'apple_pay' => 'Apple/Google Pay',
    'enable_apple_pay' => 'Accept Apple Pay and Pay with Google',
    'requires_subdomain' => 'This payment type requires that a :link.',
    'subdomain_is_set' => 'subdomain is set',
    'verification_file' => 'Verification File',
    'verification_file_missing' => 'The verification file is needed to accept payments.',
    'apple_pay_domain' => 'Use <code>:domain</code> as the domain in :link.',
    'apple_pay_not_supported' => 'Sorry, Apple/Google Pay isn\'t supported by your browser',
    'optional_payment_methods' => 'Optional Payment Methods',
    'add_subscription' => 'Add Subscription',
    'target_url' => 'Target',
    'target_url_help' => 'When the selected event occurs the app will post the entity to the target URL.',
    'event' => 'Event',
    'subscription_event_1' => 'Created Client',
    'subscription_event_2' => 'Created Invoice',
    'subscription_event_3' => 'Created Quote',
    'subscription_event_4' => 'Created Payment',
    'subscription_event_5' => 'Created Vendor',
    'subscription_event_6' => 'Updated Quote',
    'subscription_event_7' => 'Deleted Quote',
    'subscription_event_8' => 'Updated Invoice',
    'subscription_event_9' => 'Deleted Invoice',
    'subscription_event_10' => 'Updated Client',
    'subscription_event_11' => 'Deleted Client',
    'subscription_event_12' => 'Deleted Payment',
    'subscription_event_13' => 'Updated Vendor',
    'subscription_event_14' => 'Deleted Vendor',
    'subscription_event_15' => 'Created Expense',
    'subscription_event_16' => 'Updated Expense',
    'subscription_event_17' => 'Deleted Expense',
    'subscription_event_18' => 'Created Task',
    'subscription_event_19' => 'Updated Task',
    'subscription_event_20' => 'Deleted Task',
    'subscription_event_21' => 'Approved Quote',
    'subscriptions' => 'Subscriptions',
    'updated_subscription' => 'Successfully updated subscription',
    'created_subscription' => 'Successfully created subscription',
    'edit_subscription' => 'Edit Subscription',
    'archive_subscription' => 'Archive Subscription',
    'archived_subscription' => 'Successfully archived subscription',
    'project_error_multiple_clients' => 'The projects can\'t belong to different clients',
    'invoice_project' => 'Invoice Project',
    'module_recurring_invoice' => 'Recurring Invoices',
    'module_credit' => 'Credits',
    'module_quote' => 'Quotes & Proposals',
    'module_task' => 'Tasks & Projects',
    'module_expense' => 'Expenses & Vendors',
    'module_ticket' => 'Tickets',
    'reminders' => 'Reminders',
    'send_client_reminders' => 'Send email reminders',
    'can_view_tasks' => 'Tasks are visible in the portal',
    'is_not_sent_reminders' => 'Reminders are not sent',
    'promotion_footer' => 'Your promotion will expire soon, :link to upgrade now.',
    'unable_to_delete_primary' => 'Note: to delete this company first delete all linked companies.',
    'please_register' => 'Please register your account',
    'processing_request' => 'Processing request',
    'mcrypt_warning' => 'Warning: Mcrypt is deprecated, run :command to update your cipher.',
    'edit_times' => 'Edit Times',
    'inclusive_taxes_help' => 'Include <b>taxes in the cost</b>',
    'inclusive_taxes_notice' => 'This setting can not be changed once an invoice has been created.',
    'inclusive_taxes_warning' => 'Warning: existing invoices will need to be resaved',
    'copy_shipping' => 'Copy Shipping',
    'copy_billing' => 'Copy Billing',
    'quote_has_expired' => 'The quote has expired, please contact the merchant.',
    'empty_table_footer' => 'Showing 0 to 0 of 0 entries',
    'do_not_trust' => 'Do not remember this device',
    'trust_for_30_days' => 'Trust for 30 days',
    'trust_forever' => 'Trust forever',
    'kanban' => 'Kanban',
    'backlog' => 'Backlog',
    'ready_to_do' => 'Ready to do',
    'in_progress' => 'In progress',
    'add_status' => 'Add status',
    'archive_status' => 'Archive Status',
    'new_status' => 'New Status',
    'convert_products' => 'Convert Products',
    'convert_products_help' => 'Automatically convert product prices to the client\'s currency',
    'improve_client_portal_link' => 'Set a subdomain to shorten the client portal link.',
    'budgeted_hours' => 'Budgeted Hours',
    'progress' => 'Progress',
    'view_project' => 'View Project',
    'summary' => 'Summary',
    'endless_reminder' => 'Endless Reminder',
    'signature_on_invoice_help' => 'Add the following code to show your client\'s signature on the PDF.',
    'signature_on_pdf' => 'Show on PDF',
    'signature_on_pdf_help' => 'Show the client signature on the invoice/quote PDF.',
    'expired_white_label' => 'The white label license has expired',
    'return_to_login' => 'Return to Login',
    'convert_products_tip' => 'Note: add a :link named ":name" to see the exchange rate.',
    'amount_greater_than_balance' => 'The amount is greater than the invoice balance, a credit will be created with the remaining amount.',
    'custom_fields_tip' => 'Use <code>Label|Option1,Option2</code> to show a select box.',
    'client_information' => 'Client Information',
    'updated_client_details' => 'Successfully updated client details',
    'auto' => 'Auto',
    'tax_amount' => 'Tax Amount',
    'tax_paid' => 'Tax Paid',
    'none' => 'None',
    'proposal_message_button' => 'To view your proposal for :amount, click the button below.',
    'proposal' => 'Proposal',
    'proposals' => 'Proposals',
    'list_proposals' => 'List Proposals',
    'new_proposal' => 'New Proposal',
    'edit_proposal' => 'Edit Proposal',
    'archive_proposal' => 'Archive Proposal',
    'delete_proposal' => 'Delete Proposal',
    'created_proposal' => 'Successfully created proposal',
    'updated_proposal' => 'Successfully updated proposal',
    'archived_proposal' => 'Successfully archived proposal',
    'deleted_proposal' => 'Successfully archived proposal',
    'archived_proposals' => 'Successfully archived :count proposals',
    'deleted_proposals' => 'Successfully archived :count proposals',
    'restored_proposal' => 'Successfully restored proposal',
    'restore_proposal' => 'Restore Proposal',
    'snippet' => 'Snippet',
    'snippets' => 'Snippets',
    'proposal_snippet' => 'Snippet',
    'proposal_snippets' => 'Snippets',
    'new_proposal_snippet' => 'New Snippet',
    'edit_proposal_snippet' => 'Edit Snippet',
    'archive_proposal_snippet' => 'Archive Snippet',
    'delete_proposal_snippet' => 'Delete Snippet',
    'created_proposal_snippet' => 'Successfully created snippet',
    'updated_proposal_snippet' => 'Successfully updated snippet',
    'archived_proposal_snippet' => 'Successfully archived snippet',
    'deleted_proposal_snippet' => 'Successfully archived snippet',
    'archived_proposal_snippets' => 'Successfully archived :count snippets',
    'deleted_proposal_snippets' => 'Successfully archived :count snippets',
    'restored_proposal_snippet' => 'Successfully restored snippet',
    'restore_proposal_snippet' => 'Restore Snippet',
    'template' => 'Template',
    'templates' => 'Templates',
    'proposal_template' => 'Template',
    'proposal_templates' => 'Templates',
    'new_proposal_template' => 'New Template',
    'edit_proposal_template' => 'Edit Template',
    'archive_proposal_template' => 'Archive Template',
    'delete_proposal_template' => 'Delete Template',
    'created_proposal_template' => 'Successfully created template',
    'updated_proposal_template' => 'Successfully updated template',
    'archived_proposal_template' => 'Successfully archived template',
    'deleted_proposal_template' => 'Successfully archived template',
    'archived_proposal_templates' => 'Successfully archived :count templates',
    'deleted_proposal_templates' => 'Successfully archived :count templates',
    'restored_proposal_template' => 'Successfully restored template',
    'restore_proposal_template' => 'Restore Template',
    'proposal_category' => 'Category',
    'proposal_categories' => 'Categories',
    'new_proposal_category' => 'New Category',
    'edit_proposal_category' => 'Edit Category',
    'archive_proposal_category' => 'Archive Category',
    'delete_proposal_category' => 'Delete Category',
    'created_proposal_category' => 'Successfully created category',
    'updated_proposal_category' => 'Successfully updated category',
    'archived_proposal_category' => 'Successfully archived category',
    'deleted_proposal_category' => 'Successfully archived category',
    'archived_proposal_categories' => 'Successfully archived :count categories',
    'deleted_proposal_categories' => 'Successfully archived :count categories',
    'restored_proposal_category' => 'Successfully restored category',
    'restore_proposal_category' => 'Restore Category',
    'delete_status' => 'Delete Status',
    'standard' => 'Standard',
    'icon' => 'Icon',
    'proposal_not_found' => 'The requested proposal is not available',
    'create_proposal_category' => 'Create category',
    'clone_proposal_template' => 'Clone Template',
    'proposal_email' => 'Proposal Email',
    'proposal_subject' => 'New proposal :number from :account',
    'proposal_message' => 'To view your proposal for :amount, click the link below.',
    'emailed_proposal' => 'Successfully emailed proposal',
    'load_template' => 'Load Template',
    'no_assets' => 'No images, drag to upload',
    'add_image' => 'Add Image',
    'select_image' => 'Select Image',
    'upgrade_to_upload_images' => 'Upgrade to the enterprise plan to upload images',
    'delete_image' => 'Delete Image',
    'delete_image_help' => 'Warning: deleting the image will remove it from all proposals.',
    'amount_variable_help' => 'Note: the invoice $amount field will use the partial/deposit field if set otherwise it will use the invoice balance.',
    'taxes_are_included_help' => 'Note: Inclusive taxes have been enabled.',
    'taxes_are_not_included_help' => 'Note: Inclusive taxes are not enabled.',
    'change_requires_purge' => 'Changing this setting requires :link the account data.',
    'purging' => 'purging',
    'warning_local_refund' => 'The refund will be recorded in the app but will NOT be processed by the payment gateway.',
    'email_address_changed' => 'Email address has been changed',
    'email_address_changed_message' => 'The email address for your account has been changed from :old_email to :new_email.',
    'test' => 'Test',
    'beta' => 'Beta',
    'gmp_required' => 'Exporting to ZIP requires the GMP extension',
    'email_history' => 'Email History',
    'loading' => 'Loading',
    'no_messages_found' => 'No messages found',
    'processing' => 'Processing',
    'reactivate' => 'Reactivate',
    'reactivated_email' => 'The email address has been reactivated',
    'emails' => 'Emails',
    'opened' => 'Opened',
    'bounced' => 'Bounced',
    'total_sent' => 'Total Sent',
    'total_opened' => 'Total Opened',
    'total_bounced' => 'Total Bounced',
    'total_spam' => 'Total Spam',
    'platforms' => 'Platforms',
    'email_clients' => 'Email Clients',
    'mobile' => 'Mobile',
    'desktop' => 'Desktop',
    'webmail' => 'Webmail',
    'group' => 'Group',
    'subgroup' => 'Subgroup',
    'unset' => 'Unset',
    'received_new_payment' => 'You\'ve received a new payment!',
    'slack_webhook_help' => 'Receive payment notifications using :link.',
    'slack_incoming_webhooks' => 'Slack incoming webhooks',
    'accept' => 'Accept',
    'accepted_terms' => 'Successfully accepted the latest terms of service',
    'invalid_url' => 'Invalid URL',
    'workflow_settings' => 'Workflow Settings',
    'auto_email_invoice' => 'Auto Email',
    'auto_email_invoice_help' => 'Automatically email recurring invoices when they are created.',
    'auto_archive_invoice' => 'Auto Archive',
    'auto_archive_invoice_help' => 'Automatically archive invoices when they are paid.',
    'auto_archive_quote' => 'Auto Archive',
    'auto_archive_quote_help' => 'Automatically archive quotes when they are converted.',
    'require_approve_quote' => 'Require approve quote',
    'require_approve_quote_help' => 'Require clients to approve quotes.',
    'allow_approve_expired_quote' => 'Allow approve expired quote',
    'allow_approve_expired_quote_help' => 'Allow clients to approve expired quotes.',
    'invoice_workflow' => 'Invoice Workflow',
    'quote_workflow' => 'Quote Workflow',
    'client_must_be_active' => 'Error: the client must be active',
    'purge_client' => 'Purge Client',
    'purged_client' => 'Successfully purged client',
    'purge_client_warning' => 'All related records (invoices, tasks, expenses, documents, etc) will also be deleted.',
    'clone_product' => 'Clone Product',
    'item_details' => 'Item Details',
    'send_item_details_help' => 'Send line item details to the payment gateway.',
    'view_proposal' => 'View Proposal',
    'view_in_portal' => 'View in Portal',
    'cookie_message' => 'This website uses cookies to ensure you get the best experience on our website.',
    'got_it' => 'Got it!',
    'vendor_will_create' => 'vendor will be created',
    'vendors_will_create' => 'vendors will be created',
    'created_vendors' => 'Successfully created :count vendor(s)',
    'import_vendors' => 'Import Vendors',
    'company' => 'Company',
    'client_field' => 'Client Field',
    'contact_field' => 'Contact Field',
    'product_field' => 'Product Field',
    'task_field' => 'Task Field',
    'project_field' => 'Project Field',
    'expense_field' => 'Expense Field',
    'vendor_field' => 'Vendor Field',
    'company_field' => 'Company Field',
    'invoice_field' => 'Invoice Field',
    'invoice_surcharge' => 'Invoice Surcharge',
    'custom_task_fields_help' => 'Add a field when creating a task.',
    'custom_project_fields_help' => 'Add a field when creating a project.',
    'custom_expense_fields_help' => 'Add a field when creating an expense.',
    'custom_vendor_fields_help' => 'Add a field when creating a vendor.',
    'messages' => 'Messages',
    'unpaid_invoice' => 'Unpaid Invoice',
    'paid_invoice' => 'Paid Invoice',
    'unapproved_quote' => 'Unapproved Quote',
    'unapproved_proposal' => 'Unapproved Proposal',
    'autofills_city_state' => 'Auto-fills city/state',
    'no_match_found' => 'No match found',
    'password_strength' => 'Password Strength',
    'strength_weak' => 'Weak',
    'strength_good' => 'Good',
    'strength_strong' => 'Strong',
    'mark' => 'Mark',
    'updated_task_status' => 'Successfully update task status',
    'background_image' => 'Background Image',
    'background_image_help' => 'Use the :link to manage your images, we recommend using a small file.',
    'proposal_editor' => 'proposal editor',
    'background' => 'Background',
    'guide' => 'Guide',
    'gateway_fee_item' => 'Gateway Fee Item',
    'gateway_fee_description' => 'Gateway Fee Surcharge',
    'gateway_fee_discount_description' => 'Gateway Fee Discount',
    'show_payments' => 'Show Payments',
    'show_aging' => 'Show Aging',
    'reference' => 'Reference',
    'amount_paid' => 'Amount Paid',
    'send_notifications_for' => 'Send Notifications For',
    'all_invoices' => 'All Invoices',
    'my_invoices' => 'My Invoices',
    'payment_reference' => 'Payment Reference',
    'maximum' => 'Maximum',
    'sort' => 'Sort',
    'refresh_complete' => 'Refresh Complete',
    'please_enter_your_email' => 'Please enter your email',
    'please_enter_your_password' => 'Please enter your password',
    'please_enter_your_url' => 'Please enter your URL',
    'please_enter_a_product_key' => 'Please enter a product key',
    'an_error_occurred' => 'An error occurred',
    'overview' => 'Overview',
    'copied_to_clipboard' => 'Copied :value to the clipboard',
    'error' => 'Error',
    'could_not_launch' => 'Could not launch',
    'additional' => 'Additional',
    'ok' => 'Ok',
    'email_is_invalid' => 'Email is invalid',
    'items' => 'Items',
    'partial_deposit' => 'Partial/Deposit',
    'add_item' => 'Add Item',
    'total_amount' => 'Total Amount',
    'pdf' => 'PDF',
    'invoice_status_id' => 'Invoice Status',
    'click_plus_to_add_item' => 'Click + to add an item',
    'count_selected' => ':count selected',
    'dismiss' => 'Dismiss',
    'please_select_a_date' => 'Please select a date',
    'please_select_a_client' => 'Please select a client',
    'language' => 'Language',
    'updated_at' => 'Updated',
    'please_enter_an_invoice_number' => 'Please enter an invoice number',
    'please_enter_a_quote_number' => 'Please enter a quote number',
    'clients_invoices' => ':client\'s invoices',
    'viewed' => 'Viewed',
    'approved' => 'Approved',
    'invoice_status_1' => 'Draft',
    'invoice_status_2' => 'Sent',
    'invoice_status_3' => 'Viewed',
    'invoice_status_4' => 'Approved',
    'invoice_status_5' => 'Partial',
    'invoice_status_6' => 'Paid',
    'marked_invoice_as_sent' => 'Successfully marked invoice as sent',
    'please_enter_a_client_or_contact_name' => 'Please enter a client or contact name',
    'restart_app_to_apply_change' => 'Restart the app to apply the change',
    'refresh_data' => 'Refresh Data',
    'blank_contact' => 'Blank Contact',
    'no_records_found' => 'No records found',
    'industry' => 'Industry',
    'size' => 'Size',
    'net' => 'Net',
    'show_tasks' => 'Show tasks',
    'email_reminders' => 'Email Reminders',
    'reminder1' => 'First Reminder',
    'reminder2' => 'Second Reminder',
    'reminder3' => 'Third Reminder',
    'send' => 'Send',
    'auto_billing' => 'Auto billing',
    'button' => 'Button',
    'more' => 'More',
    'edit_recurring_invoice' => 'Edit Recurring Invoice',
    'edit_recurring_quote' => 'Edit Recurring Quote',
    'quote_status' => 'Quote Status',
    'please_select_an_invoice' => 'Please select an invoice',
    'filtered_by' => 'Filtered by',
    'payment_status' => 'Payment Status',
    'payment_status_1' => 'Pending',
    'payment_status_2' => 'Voided',
    'payment_status_3' => 'Failed',
    'payment_status_4' => 'Completed',
    'payment_status_5' => 'Partially Refunded',
    'payment_status_6' => 'Refunded',
    'send_receipt_to_client' => 'Send receipt to the client',
    'refunded' => 'Refunded',
    'marked_quote_as_sent' => 'Successfully marked quote as sent',
    'custom_module_settings' => 'Custom Module Settings',
    'ticket' => 'Ticket',
    'tickets' => 'Tickets',
    'ticket_number' => 'Ticket #',
    'new_ticket' => 'New Ticket',
    'edit_ticket' => 'Edit Ticket',
    'view_ticket' => 'View Ticket',
    'archive_ticket' => 'Archive Ticket',
    'restore_ticket' => 'Restore Ticket',
    'delete_ticket' => 'Delete Ticket',
    'archived_ticket' => 'Successfully archived ticket',
    'archived_tickets' => 'Successfully archived tickets',
    'restored_ticket' => 'Successfully restored ticket',
    'deleted_ticket' => 'Successfully deleted ticket',
    'open' => 'Open',
    'new' => 'New',
    'closed' => 'Closed',
    'reopened' => 'Reopened',
    'priority' => 'Priority',
    'last_updated' => 'Last Updated',
    'comment' => 'Comments',
    'tags' => 'Tags',
    'linked_objects' => 'Linked Objects',
    'low' => 'Low',
    'medium' => 'Medium',
    'high' => 'High',
    'no_due_date' => 'No due date set',
    'assigned_to' => 'Assigned to',
    'reply' => 'Reply',
    'awaiting_reply' => 'Awaiting reply',
    'ticket_close' => 'Close Ticket',
    'ticket_reopen' => 'Reopen Ticket',
    'ticket_open' => 'Open Ticket',
    'ticket_split' => 'Split Ticket',
    'ticket_merge' => 'Merge Ticket',
    'ticket_update' => 'Update Ticket',
    'ticket_settings' => 'Ticket Settings',
    'updated_ticket' => 'Ticket Updated',
    'mark_spam' => 'Mark as Spam',
    'local_part' => 'Local Part',
    'local_part_unavailable' => 'Name taken',
    'local_part_available' => 'Name available',
    'local_part_invalid' => 'Invalid name (alpha numeric only, no spaces',
    'local_part_help' => 'Customize the local part of your inbound support email, ie. YOUR_NAME@support.invoiceninja.com',
    'from_name_help' => 'From name is the recognizable sender which is displayed instead of the email address, ie Support Center',
    'local_part_placeholder' => 'YOUR_NAME',
    'from_name_placeholder' => 'Support Center',
    'attachments' => 'Attachments',
    'client_upload' => 'Client uploads',
    'enable_client_upload_help' => 'Allow clients to upload documents/attachments',
    'max_file_size_help' => 'Maximum file size (KB) is limited by your post_max_size and upload_max_filesize variables as set in your PHP.INI',
    'max_file_size' => 'Maximum file size',
    'mime_types' => 'Mime types',
    'mime_types_placeholder' => '.pdf , .docx, .jpg',
    'mime_types_help' => 'Comma separated list of allowed mime types, leave blank for all',
    'ticket_number_start_help' => 'Ticket number must be greater than the current ticket number',
    'new_ticket_template_id' => 'New ticket',
    'new_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a new ticket is created',
    'update_ticket_template_id' => 'Updated ticket',
    'update_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a ticket is updated',
    'close_ticket_template_id' => 'Closed ticket',
    'close_ticket_autoresponder_help' => 'Selecting a template will send an auto response to a client/contact when a ticket is closed',
    'default_priority' => 'Default priority',
    'alert_new_comment_id' => 'New comment',
    'alert_comment_ticket_help' => 'Selecting a template will send a notification (to agent) when a comment is made.',
    'alert_comment_ticket_email_help' => 'Comma separated emails to bcc on new comment.',
    'new_ticket_notification_list' => 'Additional new ticket notifications',
    'update_ticket_notification_list' => 'Additional new comment notifications',
    'comma_separated_values' => 'admin@example.com, supervisor@example.com',
    'alert_ticket_assign_agent_id' => 'Ticket assignment',
    'alert_ticket_assign_agent_id_hel' => 'Selecting a template will send a notification (to agent) when a ticket is assigned.',
    'alert_ticket_assign_agent_id_notifications' => 'Additional ticket assigned notifications',
    'alert_ticket_assign_agent_id_help' => 'Comma separated emails to bcc on ticket assignment.',
    'alert_ticket_transfer_email_help' => 'Comma separated emails to bcc on ticket transfer.',
    'alert_ticket_overdue_agent_id' => 'Ticket overdue',
    'alert_ticket_overdue_email' => 'Additional overdue ticket notifications',
    'alert_ticket_overdue_email_help' => 'Comma separated emails to bcc on ticket overdue.',
    'alert_ticket_overdue_agent_id_help' => 'Selecting a template will send a notification (to agent) when a ticket becomes overdue.',
    'ticket_master' => 'Ticket Master',
    'ticket_master_help' => 'Has the ability to assign and transfer tickets. Assigned as the default agent for all tickets.',
    'default_agent' => 'Default Agent',
    'default_agent_help' => 'If selected will automatically be assigned to all inbound tickets',
    'show_agent_details' => 'Show agent details on responses',
    'avatar' => 'Avatar',
    'remove_avatar' => 'Remove avatar',
    'ticket_not_found' => 'Ticket not found',
    'add_template' => 'Add Template',
    'ticket_template' => 'Ticket Template',
    'ticket_templates' => 'Ticket Templates',
    'updated_ticket_template' => 'Updated Ticket Template',
    'created_ticket_template' => 'Created Ticket Template',
    'archive_ticket_template' => 'Archive Template',
    'restore_ticket_template' => 'Restore Template',
    'archived_ticket_template' => 'Successfully archived template',
    'restored_ticket_template' => 'Successfully restored template',
    'close_reason' => 'Let us know why you are closing this ticket',
    'reopen_reason' => 'Let us know why you are reopening this ticket',
    'enter_ticket_message' => 'Please enter a message to update the ticket',
    'show_hide_all' => 'Show / Hide all',
    'subject_required' => 'Subject required',
    'mobile_refresh_warning' => 'If you\'re using the mobile app you may need to do a full refresh.',
    'enable_proposals_for_background' => 'To upload a background image :link to enable the proposals module.',
    'ticket_assignment' => 'Ticket :ticket_number has been assigned to :agent',
    'ticket_contact_reply' => 'Ticket :ticket_number has been updated by client :contact',
    'ticket_new_template_subject' => 'Ticket :ticket_number has been created.',
    'ticket_updated_template_subject' => 'Ticket :ticket_number has been updated.',
    'ticket_closed_template_subject' => 'Ticket :ticket_number has been closed.',
    'ticket_overdue_template_subject' => 'Ticket :ticket_number is now overdue',
    'merge' => 'Merge',
    'merged' => 'Merged',
    'agent' => 'Agent',
    'parent_ticket' => 'Parent Ticket',
    'linked_tickets' => 'Linked Tickets',
    'merge_prompt' => 'Enter ticket number to merge into',
    'merge_from_to' => 'Ticket #:old_ticket merged into Ticket #:new_ticket',
    'merge_closed_ticket_text' => 'Ticket #:old_ticket was closed and merged into Ticket#:new_ticket - :subject',
    'merge_updated_ticket_text' => 'Ticket #:old_ticket was closed and merged into this ticket',
    'merge_placeholder' => 'Merge ticket #:ticket into the following ticket',
    'select_ticket' => 'Select Ticket',
    'new_internal_ticket' => 'New internal ticket',
    'internal_ticket' => 'Internal ticket',
    'create_ticket' => 'Create ticket',
    'allow_inbound_email_tickets_external' => 'New Tickets by email (Client)',
    'allow_inbound_email_tickets_external_help' => 'Allow clients to create new tickets by email',
    'include_in_filter' => 'Include in filter',
    'custom_client1' => ':VALUE',
    'custom_client2' => ':VALUE',
    'compare' => 'Compare',
    'hosted_login' => 'Hosted Login',
    'selfhost_login' => 'Selfhost Login',
    'google_login' => 'Google Login',
    'thanks_for_patience' => 'Thank for your patience while we work to implement these features.\n\nWe hope to have them completed in the next few months.\n\nUntil then we\'ll continue to support the',
    'legacy_mobile_app' => 'legacy mobile app',
    'today' => 'Today',
    'current' => 'Current',
    'previous' => 'Previous',
    'current_period' => 'Current Period',
    'comparison_period' => 'Comparison Period',
    'previous_period' => 'Previous Period',
    'previous_year' => 'Previous Year',
    'compare_to' => 'Compare to',
    'last_week' => 'Last Week',
    'clone_to_invoice' => 'Clone to Invoice',
    'clone_to_quote' => 'Clone to Quote',
    'convert' => 'Convert',
    'last7_days' => 'Last 7 Days',
    'last30_days' => 'Last 30 Days',
    'custom_js' => 'Custom JS',
    'adjust_fee_percent_help' => 'Adjust percent to account for fee',
    'show_product_notes' => 'Show product details',
    'show_product_notes_help' => 'Include the <b>description and cost</b> in the product dropdown',
    'important' => 'Important',
    'thank_you_for_using_our_app' => 'Thank you for using our app!',
    'if_you_like_it' => 'If you like it please',
    'to_rate_it' => 'to rate it.',
    'average' => 'Average',
    'unapproved' => 'Unapproved',
    'authenticate_to_change_setting' => 'Please authenticate to change this setting',
    'locked' => 'Locked',
    'authenticate' => 'Authenticate',
    'please_authenticate' => 'Please authenticate',
    'biometric_authentication' => 'Biometric Authentication',
    'auto_start_tasks' => 'Auto Start Tasks',
    'budgeted' => 'Budgeted',
    'please_enter_a_name' => 'Please enter a name',
    'click_plus_to_add_time' => 'Click + to add time',
    'design' => 'Design',
    'password_is_too_short' => 'Password is too short',
    'failed_to_find_record' => 'Failed to find record',
    'valid_until_days' => 'Valid Until',
    'valid_until_days_help' => 'Automatically sets the <b>Valid Until</b> value on quotes to this many days in the future.  Leave blank to disable.',
    'usually_pays_in_days' => 'Days',
    'requires_an_enterprise_plan' => 'Requires an enterprise plan',
    'take_picture' => 'Take Picture',
    'upload_file' => 'Upload File',
    'new_document' => 'New Document',
    'edit_document' => 'Edit Document',
    'uploaded_document' => 'Successfully uploaded document',
    'updated_document' => 'Successfully updated document',
    'archived_document' => 'Successfully archived document',
    'deleted_document' => 'Successfully deleted document',
    'restored_document' => 'Successfully restored document',
    'no_history' => 'No History',
    'expense_status_1' => 'Logged',
    'expense_status_2' => 'Pending',
    'expense_status_3' => 'Invoiced',
    'no_record_selected' => 'No record selected',
    'error_unsaved_changes' => 'Please save or cancel your changes',
    'thank_you_for_your_purchase' => 'Thank you for your purchase!',
    'redeem' => 'Redeem',
    'back' => 'Back',
    'past_purchases' => 'Past Purchases',
    'annual_subscription' => 'Annual Subscription',
    'pro_plan' => 'Pro Plan',
    'enterprise_plan' => 'Enterprise Plan',
    'count_users' => ':count users',
    'upgrade' => 'Upgrade',
    'please_enter_a_first_name' => 'Please enter a first name',
    'please_enter_a_last_name' => 'Please enter a last name',
    'please_agree_to_terms_and_privacy' => 'Please agree to the terms of service and privacy policy to create an account.',
    'i_agree_to_the' => 'I agree to the',
    'terms_of_service_link' => 'terms of service',
    'privacy_policy_link' => 'privacy policy',
    'view_website' => 'View Website',
    'create_account' => 'Create Account',
    'email_login' => 'Email Login',
    'late_fees' => 'Late Fees',
    'payment_number' => 'Payment Number',
    'before_due_date' => 'Before the due date',
    'after_due_date' => 'After the due date',
    'after_invoice_date' => 'After the invoice date',
    'filtered_by_user' => 'Filtered by User',
    'created_user' => 'Successfully created user',
    'primary_font' => 'Primary Font',
    'secondary_font' => 'Secondary Font',
    'number_padding' => 'Number Padding',
    'general' => 'General',
    'surcharge_field' => 'Surcharge Field',
    'company_value' => 'Company Value',
    'credit_field' => 'Credit Field',
    'payment_field' => 'Payment Field',
    'group_field' => 'Group Field',
    'number_counter' => 'Number Counter',
    'number_pattern' => 'Number Pattern',
    'custom_javascript' => 'Custom JavaScript',
    'portal_mode' => 'Portal Mode',
    'attach_pdf' => 'Attach PDF',
    'attach_documents' => 'Attach Documents',
    'attach_ubl' => 'Attach UBL',
    'email_style' => 'Email Style',
    'processed' => 'Processed',
    'fee_amount' => 'Fee Amount',
    'fee_percent' => 'Fee Percent',
    'fee_cap' => 'Fee Cap',
    'limits_and_fees' => 'Limits/Fees',
    'credentials' => 'Credentials',
    'require_billing_address_help' => 'Require client to provide their billing address',
    'require_shipping_address_help' => 'Require client to provide their shipping address',
    'deleted_tax_rate' => 'Successfully deleted tax rate',
    'restored_tax_rate' => 'Successfully restored tax rate',
    'provider' => 'Provider',
    'company_gateway' => 'Payment Gateway',
    'company_gateways' => 'Payment Gateways',
    'new_company_gateway' => 'New Gateway',
    'edit_company_gateway' => 'Edit Gateway',
    'created_company_gateway' => 'Successfully created gateway',
    'updated_company_gateway' => 'Successfully updated gateway',
    'archived_company_gateway' => 'Successfully archived gateway',
    'deleted_company_gateway' => 'Successfully deleted gateway',
    'restored_company_gateway' => 'Successfully restored gateway',
    'continue_editing' => 'Continue Editing',
    'default_value' => 'Default value',
    'currency_format' => 'Currency Format',
    'first_day_of_the_week' => 'First Day of the Week',
    'first_month_of_the_year' => 'First Month of the Year',
    'symbol' => 'Symbol',
    'ocde' => 'Code',
    'date_format' => 'Date Format',
    'datetime_format' => 'Datetime Format',
    'send_reminders' => 'Send Reminders',
    'timezone' => 'Timezone',
    'filtered_by_group' => 'Filtered by Group',
    'filtered_by_invoice' => 'Filtered by Invoice',
    'filtered_by_client' => 'Filtered by Client',
    'filtered_by_vendor' => 'Filtered by Vendor',
    'group_settings' => 'Group Settings',
    'groups' => 'Groups',
    'new_group' => 'New Group',
    'edit_group' => 'Edit Group',
    'created_group' => 'Successfully created group',
    'updated_group' => 'Successfully updated group',
    'archived_group' => 'Successfully archived group',
    'deleted_group' => 'Successfully deleted group',
    'restored_group' => 'Successfully restored group',
    'upload_logo' => 'Upload Logo',
    'uploaded_logo' => 'Successfully uploaded logo',
    'saved_settings' => 'Successfully saved settings',
    'device_settings' => 'Device Settings',
    'credit_cards_and_banks' => 'Credit Cards & Banks',
    'price' => 'Price',
    'email_sign_up' => 'Email Sign Up',
    'google_sign_up' => 'Google Sign Up',
    'sign_up_with_google' => 'Sign Up With Google',
    'long_press_multiselect' => 'Long-press Multiselect',
    'migrate_to_next_version' => 'Migrate to the next version of Invoice Ninja',
    'migrate_intro_text' => 'We\'ve been working on next version of Invoice Ninja. Click the button bellow to start the migration.',
    'start_the_migration' => 'Start the migration',
    'migration' => 'Migration',
    'welcome_to_the_new_version' => 'Welcome to the new version of Invoice Ninja',
    'next_step_data_download' => 'At the next step, we\'ll let you download your data for the migration.',
    'download_data' => 'Press button below to download the data.',
    'migration_import' => 'Awesome! Now you are ready to import your migration. Go to your new installation to import your data',
    'continue' => 'Continue',
    'company1' => 'Custom Company 1',
    'company2' => 'Custom Company 2',
    'company3' => 'Custom Company 3',
    'company4' => 'Custom Company 4',
    'product1' => 'Custom Product 1',
    'product2' => 'Custom Product 2',
    'product3' => 'Custom Product 3',
    'product4' => 'Custom Product 4',
    'client1' => 'Custom Client 1',
    'client2' => 'Custom Client 2',
    'client3' => 'Custom Client 3',
    'client4' => 'Custom Client 4',
    'contact1' => 'Custom Contact 1',
    'contact2' => 'Custom Contact 2',
    'contact3' => 'Custom Contact 3',
    'contact4' => 'Custom Contact 4',
    'task1' => 'Custom Task 1',
    'task2' => 'Custom Task 2',
    'task3' => 'Custom Task 3',
    'task4' => 'Custom Task 4',
    'project1' => 'Custom Project 1',
    'project2' => 'Custom Project 2',
    'project3' => 'Custom Project 3',
    'project4' => 'Custom Project 4',
    'expense1' => 'Custom Expense 1',
    'expense2' => 'Custom Expense 2',
    'expense3' => 'Custom Expense 3',
    'expense4' => 'Custom Expense 4',
    'vendor1' => 'Custom Vendor 1',
    'vendor2' => 'Custom Vendor 2',
    'vendor3' => 'Custom Vendor 3',
    'vendor4' => 'Custom Vendor 4',
    'invoice1' => 'Custom Invoice 1',
    'invoice2' => 'Custom Invoice 2',
    'invoice3' => 'Custom Invoice 3',
    'invoice4' => 'Custom Invoice 4',
    'payment1' => 'Custom Payment 1',
    'payment2' => 'Custom Payment 2',
    'payment3' => 'Custom Payment 3',
    'payment4' => 'Custom Payment 4',
    'surcharge1' => 'Custom Surcharge 1',
    'surcharge2' => 'Custom Surcharge 2',
    'surcharge3' => 'Custom Surcharge 3',
    'surcharge4' => 'Custom Surcharge 4',
    'group1' => 'Custom Group 1',
    'group2' => 'Custom Group 2',
    'group3' => 'Custom Group 3',
    'group4' => 'Custom Group 4',
    'number' => 'Number',
    'count' => 'Count',
    'is_active' => 'Is Active',
    'contact_last_login' => 'Contact Last Login',
    'contact_full_name' => 'Contact Full Name',
    'contact_custom_value1' => 'Contact Custom Value 1',
    'contact_custom_value2' => 'Contact Custom Value 2',
    'contact_custom_value3' => 'Contact Custom Value 3',
    'contact_custom_value4' => 'Contact Custom Value 4',
    'assigned_to_id' => 'Assigned To Id',
    'created_by_id' => 'Created By Id',
    'add_column' => 'Add Column',
    'edit_columns' => 'Edit Columns',
    'to_learn_about_gogle_fonts' => 'to learn about Google Fonts',
    'refund_date' => 'Refund Date',
    'multiselect' => 'Multiselect',
    'verify_password' => 'Verify Password',
    'applied' => 'Applied',
    'include_recent_errors' => 'Include recent errors from the logs',
    'your_message_has_been_received' => 'We have received your message and will try to respond promptly.',
    'show_product_details' => 'Show Product Details',
    'show_product_details_help' => 'Include the description and cost in the product dropdown',
    'pdf_min_requirements' => 'The PDF renderer requires :version',
    'adjust_fee_percent' => 'Adjust Fee Percent',
    'configure_settings' => 'Configure Settings',
    'about' => 'About',
    'credit_email' => 'Credit Email',
    'domain_url' => 'Domain URL',
    'password_is_too_easy' => 'Password must contain an upper case character and a number',
    'client_portal_tasks' => 'Client Portal Tasks',
    'client_portal_dashboard' => 'Client Portal Dashboard',
    'please_enter_a_value' => 'Please enter a value',
    'deleted_logo' => 'Successfully deleted logo',
    'generate_number' => 'Generate Number',
    'when_saved' => 'When Saved',
    'when_sent' => 'When Sent',
    'select_company' => 'Select Company',
    'float' => 'Float',
    'collapse' => 'Collapse',
    'show_or_hide' => 'Show/hide',
    'menu_sidebar' => 'Menu Sidebar',
    'history_sidebar' => 'History Sidebar',
    'tablet' => 'Tablet',
    'layout' => 'Layout',
    'module' => 'Module',
    'first_custom' => 'First Custom',
    'second_custom' => 'Second Custom',
    'third_custom' => 'Third Custom',
    'show_cost' => 'Show Cost',
    'show_cost_help' => 'Display a product cost field to track the markup/profit',
    'show_product_quantity' => 'Show Product Quantity',
    'show_product_quantity_help' => 'Display a product quantity field, otherwise default to one',
    'show_invoice_quantity' => 'Show Invoice Quantity',
    'show_invoice_quantity_help' => 'Display a line item quantity field, otherwise default to one',
    'default_quantity' => 'Default Quantity',
    'default_quantity_help' => 'Automatically set the line item quantity to one',
    'one_tax_rate' => 'One Tax Rate',
    'two_tax_rates' => 'Two Tax Rates',
    'three_tax_rates' => 'Three Tax Rates',
    'default_tax_rate' => 'Default Tax Rate',
    'invoice_tax' => 'Invoice Tax',
    'line_item_tax' => 'Line Item Tax',
    'inclusive_taxes' => 'Inclusive Taxes',
    'invoice_tax_rates' => 'Invoice Tax Rates',
    'item_tax_rates' => 'Item Tax Rates',
    'configure_rates' => 'Configure rates',
    'tax_settings_rates' => 'Tax Rates',
    'accent_color' => 'Accent Color',
    'comma_sparated_list' => 'Comma separated list',
    'single_line_text' => 'Single-line text',
    'multi_line_text' => 'Multi-line text',
    'dropdown' => 'Dropdown',
    'field_type' => 'Field Type',
    'recover_password_email_sent' => 'A password recovery email has been sent',
    'removed_user' => 'Successfully removed user',
    'freq_three_years' => 'Three Years',
    'military_time_help' => '24 Hour Display',
    'click_here_capital' => 'Click here',
    'marked_invoice_as_paid' => 'Successfully marked invoice as sent',
    'marked_invoices_as_sent' => 'Successfully marked invoices as sent',
    'marked_invoices_as_paid' => 'Successfully marked invoices as sent',
    'activity_57' => 'System failed to email invoice :invoice',
    'custom_value3' => 'Custom Value 3',
    'custom_value4' => 'Custom Value 4',
    'email_style_custom' => 'Custom Email Style',
    'custom_message_dashboard' => 'Custom Dashboard Message',
    'custom_message_unpaid_invoice' => 'Custom Unpaid Invoice Message',
    'custom_message_paid_invoice' => 'Custom Paid Invoice Message',
    'custom_message_unapproved_quote' => 'Custom Unapproved Quote Message',
    'lock_sent_invoices' => 'Lock Sent Invoices',
    'translations' => 'Translations',
    'task_number_pattern' => 'Task Number Pattern',
    'task_number_counter' => 'Task Number Counter',
    'expense_number_pattern' => 'Expense Number Pattern',
    'expense_number_counter' => 'Expense Number Counter',
    'vendor_number_pattern' => 'Vendor Number Pattern',
    'vendor_number_counter' => 'Vendor Number Counter',
    'ticket_number_pattern' => 'Ticket Number Pattern',
    'ticket_number_counter' => 'Ticket Number Counter',
    'payment_number_pattern' => 'Payment Number Pattern',
    'payment_number_counter' => 'Payment Number Counter',
    'invoice_number_pattern' => 'Invoice Number Pattern',
    'quote_number_pattern' => 'Quote Number Pattern',
    'client_number_pattern' => 'Credit Number Pattern',
    'client_number_counter' => 'Credit Number Counter',
    'credit_number_pattern' => 'Credit Number Pattern',
    'credit_number_counter' => 'Credit Number Counter',
    'reset_counter_date' => 'Reset Counter Date',
    'counter_padding' => 'Counter Padding',
    'shared_invoice_quote_counter' => 'Shared Invoice Quote Counter',
    'default_tax_name_1' => 'Default Tax Name 1',
    'default_tax_rate_1' => 'Default Tax Rate 1',
    'default_tax_name_2' => 'Default Tax Name 2',
    'default_tax_rate_2' => 'Default Tax Rate 2',
    'default_tax_name_3' => 'Default Tax Name 3',
    'default_tax_rate_3' => 'Default Tax Rate 3',
    'email_subject_invoice' => 'Email Invoice Subject',
    'email_subject_quote' => 'Email Quote Subject',
    'email_subject_payment' => 'Email Payment Subject',
    'switch_list_table' => 'Switch List Table',
    'client_city' => 'Client City',
    'client_state' => 'Client State',
    'client_country' => 'Client Country',
    'client_is_active' => 'Client is Active',
    'client_balance' => 'Client Balance',
    'client_address1' => 'Client Street',
    'client_address2' => 'Client Apt/Suite',
    'client_shipping_address1' => 'Client Shipping Street',
    'client_shipping_address2' => 'Client Shipping Apt/Suite',
    'tax_rate1' => 'Tax Rate 1',
    'tax_rate2' => 'Tax Rate 2',
    'tax_rate3' => 'Tax Rate 3',
    'archived_at' => 'Archived At',
    'has_expenses' => 'Has Expenses',
    'custom_taxes1' => 'Custom Taxes 1',
    'custom_taxes2' => 'Custom Taxes 2',
    'custom_taxes3' => 'Custom Taxes 3',
    'custom_taxes4' => 'Custom Taxes 4',
    'custom_surcharge1' => 'Custom Surcharge 1',
    'custom_surcharge2' => 'Custom Surcharge 2',
    'custom_surcharge3' => 'Custom Surcharge 3',
    'custom_surcharge4' => 'Custom Surcharge 4',
    'is_deleted' => 'Is Deleted',
    'vendor_city' => 'Vendor City',
    'vendor_state' => 'Vendor State',
    'vendor_country' => 'Vendor Country',
    'credit_footer' => 'Credit Footer',
    'credit_terms' => 'Credit Terms',
    'untitled_company' => 'Untitled Company',
    'added_company' => 'Successfully added company',
    'supported_events' => 'Supported Events',
    'custom3' => 'Third Custom',
    'custom4' => 'Fourth Custom',
    'optional' => 'Optional',
    'license' => 'License',
    'invoice_balance' => 'Invoice Balance',
    'saved_design' => 'Successfully saved design',
    'client_details' => 'Client Details',
    'company_address' => 'Company Address',
    'quote_details' => 'Quote Details',
    'credit_details' => 'Credit Details',
    'product_columns' => 'Product Columns',
    'task_columns' => 'Task Columns',
    'add_field' => 'Add Field',
    'all_events' => 'All Events',
    'owned' => 'Owned',
    'payment_success' => 'Payment Success',
    'payment_failure' => 'Payment Failure',
    'quote_sent' => 'Quote Sent',
    'credit_sent' => 'Credit Sent',
    'invoice_viewed' => 'Invoice Viewed',
    'quote_viewed' => 'Quote Viewed',
    'credit_viewed' => 'Credit Viewed',
    'quote_approved' => 'Quote Approved',
    'receive_all_notifications' => 'Receive All Notifications',
    'purchase_license' => 'Purchase License',
    'enable_modules' => 'Enable Modules',
    'converted_quote' => 'Successfully converted quote',
    'credit_design' => 'Credit Design',
    'includes' => 'Includes',
    'css_framework' => 'CSS Framework',
    'custom_designs' => 'Custom Designs',
    'designs' => 'Designs',
    'new_design' => 'New Design',
    'edit_design' => 'Edit Design',
    'created_design' => 'Successfully created design',
    'updated_design' => 'Successfully updated design',
    'archived_design' => 'Successfully archived design',
    'deleted_design' => 'Successfully deleted design',
    'removed_design' => 'Successfully removed design',
    'restored_design' => 'Successfully restored design',
    'recurring_tasks' => 'Recurring Tasks',
    'removed_credit' => 'Successfully removed credit',
    'latest_version' => 'Latest Version',
    'update_now' => 'Update Now',
    'a_new_version_is_available' => 'A new version of the web app is available',
    'update_available' => 'Update Available',
    'app_updated' => 'Update successfully completed',
    'integrations' => 'Integrations',
    'tracking_id' => 'Tracking Id',
    'slack_webhook_url' => 'Slack Webhook URL',
    'partial_payment' => 'Partial Payment',
    'partial_payment_email' => 'Partial Payment Email',
    'clone_to_credit' => 'Clone to Credit',
    'emailed_credit' => 'Successfully emailed credit',
    'marked_credit_as_sent' => 'Successfully marked credit as sent',
    'email_subject_payment_partial' => 'Email Partial Payment Subject',
    'is_approved' => 'Is Approved',
    'migration_went_wrong' => 'Oops, something went wrong! Please make sure you have setup an Invoice Ninja v5 instance before starting the migration.',
    'cross_migration_message' => 'Cross account migration is not allowed. Please read more about it here: <a href="https://invoiceninja.github.io/docs/migration/#troubleshooting">https://invoiceninja.github.io/docs/migration/#troubleshooting</a>',
    'email_credit' => 'Email Credit',
    'client_email_not_set' => 'Client does not have an email address set',
    'ledger' => 'Ledger',
    'view_pdf' => 'View PDF',
    'all_records' => 'All records',
    'owned_by_user' => 'Owned by user',
    'credit_remaining' => 'Credit Remaining',
    'use_default' => 'Use default',
    'reminder_endless' => 'Endless Reminders',
    'number_of_days' => 'Number of days',
    'configure_payment_terms' => 'Configure Payment Terms',
    'payment_term' => 'Payment Term',
    'new_payment_term' => 'New Payment Term',
    'deleted_payment_term' => 'Successfully deleted payment term',
    'removed_payment_term' => 'Successfully removed payment term',
    'restored_payment_term' => 'Successfully restored payment term',
    'full_width_editor' => 'Full Width Editor',
    'full_height_filter' => 'Full Height Filter',
    'email_sign_in' => 'Sign in with email',
    'change' => 'Change',
    'change_to_mobile_layout' => 'Change to the mobile layout?',
    'change_to_desktop_layout' => 'Change to the desktop layout?',
    'send_from_gmail' => 'Send from Gmail',
    'reversed' => 'Reversed',
    'cancelled' => 'Cancelled',
    'quote_amount' => 'Quote Amount',
    'hosted' => 'Hosted',
    'selfhosted' => 'Self-Hosted',
    'hide_menu' => 'Hide Menu',
    'show_menu' => 'Show Menu',
    'partially_refunded' => 'Partially Refunded',
    'search_documents' => 'Search Documents',
    'search_designs' => 'Search Designs',
    'search_invoices' => 'Search Invoices',
    'search_clients' => 'Search Clients',
    'search_products' => 'Search Products',
    'search_quotes' => 'Search Quotes',
    'search_credits' => 'Search Credits',
    'search_vendors' => 'Search Vendors',
    'search_users' => 'Search Users',
    'search_tax_rates' => 'Search Tax Rates',
    'search_tasks' => 'Search Tasks',
    'search_settings' => 'Search Settings',
    'search_projects' => 'Search Projects',
    'search_expenses' => 'Search Expenses',
    'search_payments' => 'Search Payments',
    'search_groups' => 'Search Groups',
    'search_company' => 'Search Company',
    'cancelled_invoice' => 'Successfully cancelled invoice',
    'cancelled_invoices' => 'Successfully cancelled invoices',
    'reversed_invoice' => 'Successfully reversed invoice',
    'reversed_invoices' => 'Successfully reversed invoices',
    'reverse' => 'Reverse',
    'filtered_by_project' => 'Filtered by Project',
    'google_sign_in' => 'Sign in with Google',
    'activity_58' => ':user reversed invoice :invoice',
    'activity_59' => ':user cancelled invoice :invoice',
    'payment_reconciliation_failure' => 'Reconciliation Failure',
    'payment_reconciliation_success' => 'Reconciliation Success',
    'gateway_success' => 'Gateway Success',
    'gateway_failure' => 'Gateway Failure',
    'gateway_error' => 'Gateway Error',
    'email_send' => 'Email Send',
    'email_retry_queue' => 'Email Retry Queue',
    'failure' => 'Failure',
    'quota_exceeded' => 'Quota Exceeded',
    'upstream_failure' => 'Upstream Failure',
    'system_logs' => 'System Logs',
    'copy_link' => 'Copy Link',
    'welcome_to_invoice_ninja' => 'Welcome to Invoice Ninja',
    'optin' => 'Opt-In',
    'optout' => 'Opt-Out',
    'auto_convert' => 'Auto Convert',
    'reminder1_sent' => 'Reminder 1 Sent',
    'reminder2_sent' => 'Reminder 2 Sent',
    'reminder3_sent' => 'Reminder 3 Sent',
    'reminder_last_sent' => 'Reminder Last Sent',
    'pdf_page_info' => 'Page :current of :total',
    'emailed_credits' => 'Successfully emailed credits',
    'view_in_stripe' => 'View in Stripe',
    'rows_per_page' => 'Rows Per Page',
    'apply_payment' => 'Apply Payment',
    'unapplied' => 'Unapplied',
    'custom_labels' => 'Custom Labels',
    'record_type' => 'Record Type',
    'record_name' => 'Record Name',
    'file_type' => 'File Type',
    'height' => 'Height',
    'width' => 'Width',
    'health_check' => 'Health Check',
    'last_login_at' => 'Last Login At',
    'company_key' => 'Company Key',
    'storefront' => 'Storefront',
    'storefront_help' => 'Enable third-party apps to create invoices',
    'count_records_selected' => ':count records selected',
    'count_record_selected' => ':count record selected',
    'client_created' => 'Client Created',
    'online_payment_email' => 'Online Payment Email',
    'manual_payment_email' => 'Manual Payment Email',
    'completed' => 'Completed',
    'gross' => 'Gross',
    'net_amount' => 'Net Amount',
    'net_balance' => 'Net Balance',
    'client_settings' => 'Client Settings',
    'selected_invoices' => 'Selected Invoices',
    'selected_payments' => 'Selected Payments',
    'selected_quotes' => 'Selected Quotes',
    'selected_tasks' => 'Selected Tasks',
    'selected_expenses' => 'Selected Expenses',
    'past_due_invoices' => 'Past Due Invoices',
    'create_payment' => 'Create Payment',
    'update_quote' => 'Update Quote',
    'update_invoice' => 'Update Invoice',
    'update_client' => 'Update Client',
    'update_vendor' => 'Update Vendor',
    'create_expense' => 'Create Expense',
    'update_expense' => 'Update Expense',
    'update_task' => 'Update Task',
    'approve_quote' => 'Approve Quote',
    'when_paid' => 'When Paid',
    'expires_on' => 'Expires On',
    'show_sidebar' => 'Show Sidebar',
    'hide_sidebar' => 'Hide Sidebar',
    'event_type' => 'Event Type',
    'copy' => 'Copy',
    'must_be_online' => 'Please restart the app once connected to the internet',
    'crons_not_enabled' => 'The crons need to be enabled',
    'api_webhooks' => 'API Webhooks',
    'search_webhooks' => 'Search :count Webhooks',
    'search_webhook' => 'Search 1 Webhook',
    'webhook' => 'Webhook',
    'webhooks' => 'Webhooks',
    'new_webhook' => 'New Webhook',
    'edit_webhook' => 'Edit Webhook',
    'created_webhook' => 'Successfully created webhook',
    'updated_webhook' => 'Successfully updated webhook',
    'archived_webhook' => 'Successfully archived webhook',
    'deleted_webhook' => 'Successfully deleted webhook',
    'removed_webhook' => 'Successfully removed webhook',
    'restored_webhook' => 'Successfully restored webhook',
    'search_tokens' => 'Search :count Tokens',
    'search_token' => 'Search 1 Token',
    'new_token' => 'New Token',
    'removed_token' => 'Successfully removed token',
    'restored_token' => 'Successfully restored token',
    'client_registration' => 'Client Registration',
    'client_registration_help' => 'Enable clients to self register in the portal',
    'customize_and_preview' => 'Customize & Preview',
    'search_document' => 'Search 1 Document',
    'search_design' => 'Search 1 Design',
    'search_invoice' => 'Search 1 Invoice',
    'search_client' => 'Search 1 Client',
    'search_product' => 'Search 1 Product',
    'search_quote' => 'Search 1 Quote',
    'search_credit' => 'Search 1 Credit',
    'search_vendor' => 'Search 1 Vendor',
    'search_user' => 'Search 1 User',
    'search_tax_rate' => 'Search 1 Tax Rate',
    'search_task' => 'Search 1 Tasks',
    'search_project' => 'Search 1 Project',
    'search_expense' => 'Search 1 Expense',
    'search_payment' => 'Search 1 Payment',
    'search_group' => 'Search 1 Group',
    'created_on' => 'Created On',
    'payment_status_-1' => 'Unapplied',
    'lock_invoices' => 'Lock Invoices',
    'show_table' => 'Show Table',
    'show_list' => 'Show List',
    'view_changes' => 'View Changes',
    'force_update' => 'Force Update',
    'force_update_help' => 'You are running the latest version but there may be pending fixes available.',
    'mark_paid_help' => 'Track the expense has been paid',
    'mark_invoiceable_help' => 'Enable the expense to be invoiced',
    'add_documents_to_invoice_help' => 'Make the documents visible',
    'convert_currency_help' => 'Set an exchange rate',
    'expense_settings' => 'Expense Settings',
    'clone_to_recurring' => 'Clone to Recurring',
    'crypto' => 'Crypto',
    'user_field' => 'User Field',
    'variables' => 'Variables',
    'show_password' => 'Show Password',
    'hide_password' => 'Hide Password',
    'copy_error' => 'Copy Error',
    'capture_card' => 'Capture Card',
    'auto_bill_enabled' => 'Auto Bill Enabled',
    'total_taxes' => 'Total Taxes',
    'line_taxes' => 'Line Taxes',
    'total_fields' => 'Total Fields',
    'stopped_recurring_invoice' => 'Successfully stopped recurring invoice',
    'started_recurring_invoice' => 'Successfully started recurring invoice',
    'resumed_recurring_invoice' => 'Successfully resumed recurring invoice',
    'gateway_refund' => 'Gateway Refund',
    'gateway_refund_help' => 'Process the refund with the payment gateway',
    'due_date_days' => 'Due Date',
    'paused' => 'Paused',
    'day_count' => 'Day :count',
    'first_day_of_the_month' => 'First Day of the Month',
    'last_day_of_the_month' => 'Last Day of the Month',
    'use_payment_terms' => 'Use Payment Terms',
    'endless' => 'Endless',
    'next_send_date' => 'Next Send Date',
    'remaining_cycles' => 'Remaining Cycles',
    'created_recurring_invoice' => 'Successfully created recurring invoice',
    'updated_recurring_invoice' => 'Successfully updated recurring invoice',
    'removed_recurring_invoice' => 'Successfully removed recurring invoice',
    'search_recurring_invoice' => 'Search 1 Recurring Invoice',
    'search_recurring_invoices' => 'Search :count Recurring Invoices',
    'send_date' => 'Send Date',
    'auto_bill_on' => 'Auto Bill On',
    'minimum_under_payment_amount' => 'Minimum Under Payment Amount',
    'allow_over_payment' => 'Allow Over Payment',
    'allow_over_payment_help' => 'Support paying extra to accept tips',
    'allow_under_payment' => 'Allow Under Payment',
    'allow_under_payment_help' => 'Support paying at minimum the partial/deposit amount',
    'test_mode' => 'Test Mode',
    'calculated_rate' => 'Calculated Rate',
    'default_task_rate' => 'Default Task Rate',
    'clear_cache' => 'Clear Cache',
    'sort_order' => 'Sort Order',
    'task_status' => 'Status',
    'task_statuses' => 'Task Statuses',
    'new_task_status' => 'New Task Status',
    'edit_task_status' => 'Edit Task Status',
    'created_task_status' => 'Successfully created task status',
    'archived_task_status' => 'Successfully archived task status',
    'deleted_task_status' => 'Successfully deleted task status',
    'removed_task_status' => 'Successfully removed task status',
    'restored_task_status' => 'Successfully restored task status',
    'search_task_status' => 'Search 1 Task Status',
    'search_task_statuses' => 'Search :count Task Statuses',
    'show_tasks_table' => 'Show Tasks Table',
    'show_tasks_table_help' => 'Always show the tasks section when creating invoices',
    'invoice_task_timelog' => 'Invoice Task Timelog',
    'invoice_task_timelog_help' => 'Add time details to the invoice line items',
    'auto_start_tasks_help' => 'Start tasks before saving',
    'configure_statuses' => 'Configure Statuses',
    'task_settings' => 'Task Settings',
    'configure_categories' => 'Configure Categories',
    'edit_expense_category' => 'Edit Expense Category',
    'removed_expense_category' => 'Successfully removed expense category',
    'search_expense_category' => 'Search 1 Expense Category',
    'search_expense_categories' => 'Search :count Expense Categories',
    'use_available_credits' => 'Use Available Credits',
    'show_option' => 'Show Option',
    'negative_payment_error' => 'The credit amount cannot exceed the payment amount',
    'should_be_invoiced_help' => 'Enable the expense to be invoiced',
    'configure_gateways' => 'Configure Gateways',
    'payment_partial' => 'Partial Payment',
    'is_running' => 'Is Running',
    'invoice_currency_id' => 'Invoice Currency ID',
    'tax_name1' => 'Tax Name 1',
    'tax_name2' => 'Tax Name 2',
    'transaction_id' => 'Transaction ID',
    'invoice_late' => 'Invoice Late',
    'quote_expired' => 'Quote Expired',
    'recurring_invoice_total' => 'Invoice Total',
    'actions' => 'Actions',
    'expense_number' => 'Expense Number',
    'task_number' => 'Task Number',
    'project_number' => 'Project Number',
    'view_settings' => 'View Settings',
    'company_disabled_warning' => 'Warning: this company has not yet been activated',
    'late_invoice' => 'Late Invoice',
    'expired_quote' => 'Expired Quote',
    'remind_invoice' => 'Remind Invoice',
    'client_phone' => 'Client Phone',
    'required_fields' => 'Required Fields',
    'enabled_modules' => 'Enabled Modules',
    'activity_60' => ':contact viewed quote :quote',
    'activity_61' => ':user updated client :client',
    'activity_62' => ':user updated vendor :vendor',
    'activity_63' => ':user emailed first reminder for invoice :invoice to :contact',
    'activity_64' => ':user emailed second reminder for invoice :invoice to :contact',
    'activity_65' => ':user emailed third reminder for invoice :invoice to :contact',
    'activity_66' => ':user emailed endless reminder for invoice :invoice to :contact',
    'expense_category_id' => 'Expense Category ID',
    'view_licenses' => 'View Licenses',
    'fullscreen_editor' => 'Fullscreen Editor',
    'sidebar_editor' => 'Sidebar Editor',
    'please_type_to_confirm' => 'Please type ":value" to confirm',
    'purge' => 'Purge',
    'clone_to' => 'Clone To',
    'clone_to_other' => 'Clone to Other',
    'labels' => 'Labels',
    'add_custom' => 'Add Custom',
    'payment_tax' => 'Payment Tax',
    'white_label' => 'White Label',
    'sent_invoices_are_locked' => 'Sent invoices are locked',
    'paid_invoices_are_locked' => 'Paid invoices are locked',
    'source_code' => 'Source Code',
    'app_platforms' => 'App Platforms',
    'archived_task_statuses' => 'Successfully archived :value task statuses',
    'deleted_task_statuses' => 'Successfully deleted :value task statuses',
    'restored_task_statuses' => 'Successfully restored :value task statuses',
    'deleted_expense_categories' => 'Successfully deleted expense :value categories',
    'restored_expense_categories' => 'Successfully restored expense :value categories',
    'archived_recurring_invoices' => 'Successfully archived recurring :value invoices',
    'deleted_recurring_invoices' => 'Successfully deleted recurring :value invoices',
    'restored_recurring_invoices' => 'Successfully restored recurring :value invoices',
    'archived_webhooks' => 'Successfully archived :value webhooks',
    'deleted_webhooks' => 'Successfully deleted :value webhooks',
    'removed_webhooks' => 'Successfully removed :value webhooks',
    'restored_webhooks' => 'Successfully restored :value webhooks',
    'api_docs' => 'API Docs',
    'archived_tokens' => 'Successfully archived :value tokens',
    'deleted_tokens' => 'Successfully deleted :value tokens',
    'restored_tokens' => 'Successfully restored :value tokens',
    'archived_payment_terms' => 'Successfully archived :value payment terms',
    'deleted_payment_terms' => 'Successfully deleted :value payment terms',
    'restored_payment_terms' => 'Successfully restored :value payment terms',
    'archived_designs' => 'Successfully archived :value designs',
    'deleted_designs' => 'Successfully deleted :value designs',
    'restored_designs' => 'Successfully restored :value designs',
    'restored_credits' => 'Successfully restored :value credits',
    'archived_users' => 'Successfully archived :value users',
    'deleted_users' => 'Successfully deleted :value users',
    'removed_users' => 'Successfully removed :value users',
    'restored_users' => 'Successfully restored :value users',
    'archived_tax_rates' => 'Successfully archived :value tax rates',
    'deleted_tax_rates' => 'Successfully deleted :value tax rates',
    'restored_tax_rates' => 'Successfully restored :value tax rates',
    'archived_company_gateways' => 'Successfully archived :value gateways',
    'deleted_company_gateways' => 'Successfully deleted :value gateways',
    'restored_company_gateways' => 'Successfully restored :value gateways',
    'archived_groups' => 'Successfully archived :value groups',
    'deleted_groups' => 'Successfully deleted :value groups',
    'restored_groups' => 'Successfully restored :value groups',
    'archived_documents' => 'Successfully archived :value documents',
    'deleted_documents' => 'Successfully deleted :value documents',
    'restored_documents' => 'Successfully restored :value documents',
    'restored_vendors' => 'Successfully restored :value vendors',
    'restored_expenses' => 'Successfully restored :value expenses',
    'restored_tasks' => 'Successfully restored :value tasks',
    'restored_projects' => 'Successfully restored :value projects',
    'restored_products' => 'Successfully restored :value products',
    'restored_clients' => 'Successfully restored :value clients',
    'restored_invoices' => 'Successfully restored :value invoices',
    'restored_payments' => 'Successfully restored :value payments',
    'restored_quotes' => 'Successfully restored :value quotes',
    'update_app' => 'Update App',
    'started_import' => 'Successfully started import',
    'duplicate_column_mapping' => 'Duplicate column mapping',
    'uses_inclusive_taxes' => 'Uses Inclusive Taxes',
    'is_amount_discount' => 'Is Amount Discount',
    'map_to' => 'Map To',
    'first_row_as_column_names' => 'Use first row as column names',
    'no_file_selected' => 'No File Selected',
    'import_type' => 'Import Type',
    'draft_mode' => 'Draft Mode',
    'draft_mode_help' => 'Preview updates faster but is less accurate',
    'show_product_discount' => 'Show Product Discount',
    'show_product_discount_help' => 'Display a line item discount field',
    'tax_name3' => 'Tax Name 3',
    'debug_mode_is_enabled' => 'Debug mode is enabled',
    'debug_mode_is_enabled_help' => 'Warning: it is intended for use on local machines, it can leak credentials. Click to learn more.',
    'running_tasks' => 'Running Tasks',
    'recent_tasks' => 'Recent Tasks',
    'recent_expenses' => 'Recent Expenses',
    'upcoming_expenses' => 'Upcoming Expenses',
    'search_payment_term' => 'Search 1 Payment Term',
    'search_payment_terms' => 'Search :count Payment Terms',
    'save_and_preview' => 'Save and Preview',
    'save_and_email' => 'Save and Email',
    'converted_balance' => 'Converted Balance',
    'is_sent' => 'Is Sent',
    'document_upload' => 'Document Upload',
    'document_upload_help' => 'Enable clients to upload documents',
    'expense_total' => 'Expense Total',
    'enter_taxes' => 'Enter Taxes',
    'by_rate' => 'By Rate',
    'by_amount' => 'By Amount',
    'enter_amount' => 'Enter Amount',
    'before_taxes' => 'Before Taxes',
    'after_taxes' => 'After Taxes',
    'color' => 'Color',
    'show' => 'Show',
    'empty_columns' => 'Empty Columns',
    'project_name' => 'Project Name',
    'counter_pattern_error' => 'To use :client_counter please add either :client_number or :client_id_number to prevent conflicts',
    'this_quarter' => 'This Quarter',
    'to_update_run' => 'To update run',
    'registration_url' => 'Registration URL',
    'show_product_cost' => 'Show Product Cost',
    'complete' => 'Complete',
     'next' => 'Next',
     'next_step' => 'Next step',
     'notification_credit_sent_subject' => 'Credit :invoice was sent to :client',
     'notification_credit_viewed_subject' => 'Credit :invoice was viewed by :client',
     'notification_credit_sent' => 'The following client :client was emailed Credit :invoice for :amount.',
     'notification_credit_viewed' => 'The following client :client viewed Credit :credit for :amount.',
     'reset_password_text' => 'Enter your email to reset your password.',
     'password_reset' => 'Password reset',
     'account_login_text' => 'Welcome back! Glad to see you.',
     'request_cancellation' => 'Request cancellation',
     'delete_payment_method' => 'Delete Payment Method',
     'about_to_delete_payment_method' => 'You are about to delete the payment method.',
     'action_cant_be_reversed' => 'Action can\'t be reversed',
     'profile_updated_successfully' => 'The profile has been updated successfully.',
     'currency_ethiopian_birr' => 'Ethiopian Birr',
     'client_information_text' => 'Use a permanent address where you can receive mail.',
     'status_id' => 'Invoice Status',
     'email_already_register' => 'This email is already linked to an account',
     'locations' => 'Locations',
     'freq_indefinitely' => 'Indefinitely',
     'cycles_remaining' => 'Cycles remaining',
     'i_understand_delete' => 'I understand, delete',
     'download_files' => 'Download Files',
     'download_timeframe' => 'Use this link to download your files, the link will expire in 1 hour.',
     'new_signup' => 'New Signup',
     'new_signup_text' => 'A new account has been created by :user - :email - from IP address: :ip',
     'notification_payment_paid_subject' => 'Payment was made by :client',
     'notification_partial_payment_paid_subject' => 'Partial payment was made by :client',
     'notification_payment_paid' => 'A payment of :amount was made by client :client towards :invoice',
     'notification_partial_payment_paid' => 'A partial payment of :amount was made by client :client towards :invoice',
     'notification_bot' => 'Notification Bot',
     'invoice_number_placeholder' => 'Invoice # :invoice',
     'entity_number_placeholder' => ':entity # :entity_number',
     'email_link_not_working' => 'If the button above isn\'t working for you, please click on the link',
     'display_log' => 'Display Log',
     'send_fail_logs_to_our_server' => 'Report errors in realtime',
     'setup' => 'Setup',
     'quick_overview_statistics' => 'Quick overview & statistics',
     'update_your_personal_info' => 'Update your personal information',
     'name_website_logo' => 'Name, website & logo',
     'make_sure_use_full_link' => 'Make sure you use full link to your site',
     'personal_address' => 'Personal address',
     'enter_your_personal_address' => 'Enter your personal address',
     'enter_your_shipping_address' => 'Enter your shipping address',
     'list_of_invoices' => 'List of invoices',
     'with_selected' => 'With selected',
     'invoice_still_unpaid' => 'This invoice is still not paid. Click the button to complete the payment',
     'list_of_recurring_invoices' => 'List of recurring invoices',
     'details_of_recurring_invoice' => 'Here are some details about recurring invoice',
     'cancellation' => 'Cancellation',
     'about_cancellation' => 'In case you want to stop the recurring invoice,\n please click the request the cancellation.',
     'cancellation_warning' => 'Warning! You are requesting a cancellation of this service.\n Your service may be cancelled with no further notification to you.',
     'cancellation_pending' => 'Cancellation pending, we\'ll be in touch!',
     'list_of_payments' => 'List of payments',
     'payment_details' => 'Details of the payment',
     'list_of_payment_invoices' => 'List of invoices affected by the payment',
     'list_of_payment_methods' => 'List of payment methods',
     'payment_method_details' => 'Details of payment method',
     'permanently_remove_payment_method' => 'Permanently remove this payment method.',
     'warning_action_cannot_be_reversed' => 'Warning! This action can not be reversed!',
     'confirmation' => 'Confirmation',
     'list_of_quotes' => 'Quotes',
     'waiting_for_approval' => 'Waiting for approval',
     'quote_still_not_approved' => 'This quote is still not approved',
     'list_of_credits' => 'Credits',
     'required_extensions' => 'Required extensions',
     'php_version' => 'PHP version',
     'writable_env_file' => 'Writable .env file',
     'env_not_writable' => '.env file is not writable by the current user.',
     'minumum_php_version' => 'Minimum PHP version',
     'satisfy_requirements' => 'Make sure all requirements are satisfied.',
     'oops_issues' => 'Oops, something does not look right!',
     'open_in_new_tab' => 'Open in new tab',
     'complete_your_payment' => 'Complete payment',
     'authorize_for_future_use' => 'Authorize payment method for future use',
     'page' => 'Page',
     'per_page' => 'Per page',
     'of' => 'Of',
     'view_credit' => 'View Credit',
     'to_view_entity_password' => 'To view the :entity you need to enter password.',
     'showing_x_of' => 'Showing :first to :last out of :total results',
     'no_results' => 'No results found.',
     'payment_failed_subject' => 'Payment failed for Client :client',
     'payment_failed_body' => 'A payment made by client :client failed with message :message',
     'register' => 'Register',
     'register_label' => 'Create your account in seconds',
     'password_confirmation' => 'Confirm your password',
     'verification' => 'Verification',
     'complete_your_bank_account_verification' => 'Before using a bank account it must be verified.',
     'checkout_com' => 'Checkout.com',
     'footer_label' => 'Copyright © :year :company.',
     'credit_card_invalid' => 'Provided credit card number is not valid.',
     'month_invalid' => 'Provided month is not valid.',
     'year_invalid' => 'Provided year is not valid.',
     'https_required' => 'HTTPS is required, form will fail',
     'if_you_need_help' => 'If you need help you can post to our',
     'update_password_on_confirm' => 'After updating password, your account will be confirmed.',
     'bank_account_not_linked' => 'To pay with a bank account, first you have to add it as payment method.',
     'application_settings_label' => 'Let\'s store basic information about your Invoice Ninja!',
     'recommended_in_production' => 'Highly recommended in production',
     'enable_only_for_development' => 'Enable only for development',
     'test_pdf' => 'Test PDF',
     'checkout_authorize_label' => 'Checkout.com can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store credit card details" during payment process.',
     'sofort_authorize_label' => 'Bank account (SOFORT) can be can saved as payment method for future use, once you complete your first transaction. Don\'t forget to check "Store payment details" during payment process.',
     'node_status' => 'Node status',
     'npm_status' => 'NPM status',
     'node_status_not_found' => 'I could not find Node anywhere. Is it installed?',
     'npm_status_not_found' => 'I could not find NPM anywhere. Is it installed?',
     'locked_invoice' => 'This invoice is locked and unable to be modified',
     'downloads' => 'Downloads',
     'resource' => 'Resource',
     'document_details' => 'Details about the document',
     'hash' => 'Hash',
     'resources' => 'Resources',
     'allowed_file_types' => 'Allowed file types:',
     'common_codes' => 'Common codes and their meanings',
     'payment_error_code_20087' => '20087: Bad Track Data (invalid CVV and/or expiry date)',
     'download_selected' => 'Download selected',
     'to_pay_invoices' => 'To pay invoices, you have to',
     'add_payment_method_first' => 'add payment method',
     'no_items_selected' => 'No items selected.',
     'payment_due' => 'Payment due',
     'account_balance' => 'Account balance',
     'thanks' => 'Thanks',
     'minimum_required_payment' => 'Minimum required payment is :amount',
     'under_payments_disabled' => 'Company doesn\'t support under payments.',
     'over_payments_disabled' => 'Company doesn\'t support over payments.',
     'saved_at' => 'Saved at :time',
     'credit_payment' => 'Credit applied to Invoice :invoice_number',
     'credit_subject' => 'New credit :number from :account',
     'credit_message' => 'To view your credit for :amount, click the link below.',
     'payment_type_Crypto' => 'Cryptocurrency',
     'payment_type_Credit' => 'Credit',
     'store_for_future_use' => 'Store for future use',
     'pay_with_credit' => 'Pay with credit',
     'payment_method_saving_failed' => 'Payment method can\'t be saved for future use.',
     'pay_with' => 'Pay with',
     'n/a' => 'N/A',
     'by_clicking_next_you_accept_terms' => 'By clicking "Next step" you accept terms.',
     'not_specified' => 'Not specified',
     'before_proceeding_with_payment_warning' => 'Before proceeding with payment, you have to fill following fields',
     'after_completing_go_back_to_previous_page' => 'After completing, go back to previous page.',
     'pay' => 'Pay',
     'instructions' => 'Instructions',
     'notification_invoice_reminder1_sent_subject' => 'Reminder 1 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder2_sent_subject' => 'Reminder 2 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder3_sent_subject' => 'Reminder 3 for Invoice :invoice was sent to :client',
     'notification_invoice_reminder_endless_sent_subject' => 'Endless reminder for Invoice :invoice was sent to :client',
     'assigned_user' => 'Assigned User',
     'setup_steps_notice' => 'To proceed to next step, make sure you test each section.',
     'setup_phantomjs_note' => 'Note about Phantom JS. Read more.',
     'minimum_payment' => 'Minimum Payment',
     'no_action_provided' => 'No action provided. If you believe this is wrong, please contact the support.',
     'no_payable_invoices_selected' => 'No payable invoices selected. Make sure you are not trying to pay draft invoice or invoice with zero balance due.',
     'required_payment_information' => 'Required payment details',
     'required_payment_information_more' => 'To complete a payment we need more details about you.',
     'required_client_info_save_label' => 'We will save this, so you don\'t have to enter it next time.',
     'notification_credit_bounced' => 'We were unable to deliver Credit :invoice to :contact. \n :error',
     'notification_credit_bounced_subject' => 'Unable to deliver Credit :invoice',
     'save_payment_method_details' => 'Save payment method details',
     'new_card' => 'New card',
     'new_bank_account' => 'New bank account',
     'company_limit_reached' => 'Limit of 10 companies per account.',
     'credits_applied_validation' => 'Total credits applied cannot be MORE than total of invoices',
     'credit_number_taken' => 'Credit number already taken',
     'credit_not_found' => 'Credit not found',
     'invoices_dont_match_client' => 'Selected invoices are not from a single client',
     'duplicate_credits_submitted' => 'Duplicate credits submitted.',
     'duplicate_invoices_submitted' => 'Duplicate invoices submitted.',
     'credit_with_no_invoice' => 'You must have an invoice set when using a credit in a payment',
     'client_id_required' => 'Client id is required',
     'expense_number_taken' => 'Expense number already taken',
     'invoice_number_taken' => 'Invoice number already taken',
     'payment_id_required' => 'Payment `id` required.',
     'unable_to_retrieve_payment' => 'Unable to retrieve specified payment',
     'invoice_not_related_to_payment' => 'Invoice id :invoice is not related to this payment',
     'credit_not_related_to_payment' => 'Credit id :credit is not related to this payment',
     'max_refundable_invoice' => 'Attempting to refund more than allowed for invoice id :invoice, maximum refundable amount is :amount',
     'refund_without_invoices' => 'Attempting to refund a payment with invoices attached, please specify valid invoice/s to be refunded.',
     'refund_without_credits' => 'Attempting to refund a payment with credits attached, please specify valid credits/s to be refunded.',
     'max_refundable_credit' => 'Attempting to refund more than allowed for credit :credit, maximum refundable amount is :amount',
     'project_client_do_not_match' => 'Project client does not match entity client',
     'quote_number_taken' => 'Quote number already taken',
     'recurring_invoice_number_taken' => 'Recurring Invoice number :number already taken',
     'user_not_associated_with_account' => 'User not associated with this account',
     'amounts_do_not_balance' => 'Amounts do not balance correctly.',
     'insufficient_applied_amount_remaining' => 'Insufficient applied amount remaining to cover payment.',
     'insufficient_credit_balance' => 'Insufficient balance on credit.',
     'one_or_more_invoices_paid' => 'One or more of these invoices have been paid',
     'invoice_cannot_be_refunded' => 'Invoice id :number cannot be refunded',
     'attempted_refund_failed' => 'Attempting to refund :amount only :refundable_amount available for refund',
     'user_not_associated_with_this_account' => 'This user is unable to be attached to this company. Perhaps they have already registered a user on another account?',
     'migration_completed' => 'Migration completed',
     'migration_completed_description' => 'Your migration has completed, please review your data after logging in.',
     'api_404' => '404 | Nothing to see here!',
     'large_account_update_parameter' => 'Cannot load a large account without a updated_at parameter',
     'no_backup_exists' => 'No backup exists for this activity',
     'company_user_not_found' => 'Company User record not found',
     'no_credits_found' => 'No credits found.',
     'action_unavailable' => 'The requested action :action is not available.',
     'no_documents_found' => 'No Documents Found',
     'no_group_settings_found' => 'No group settings found',
     'access_denied' => 'Insufficient privileges to access/modify this resource',
     'invoice_cannot_be_marked_paid' => 'Invoice cannot be marked as paid',
     'invoice_license_or_environment' => 'Invalid license, or invalid environment :environment',
     'route_not_available' => 'Route not available',
     'invalid_design_object' => 'Invalid custom design object',
     'quote_not_found' => 'Quote/s not found',
     'quote_unapprovable' => 'Unable to approve this quote as it has expired.',
     'scheduler_has_run' => 'Scheduler has run',
     'scheduler_has_never_run' => 'Scheduler has never run',
     'self_update_not_available' => 'Self update not available on this system.',
     'user_detached' => 'User detached from company',
     'create_webhook_failure' => 'Failed to create Webhook',
     'payment_message_extended' => 'Thank you for your payment of :amount for :invoice',
     'online_payments_minimum_note' => 'Note: Online payments are supported only if amount is bigger than $1 or currency equivalent.',
     'payment_token_not_found' => 'Payment token not found, please try again. If an issue still persist, try with another payment method',
     'vendor_address1' => 'Vendor Street',
     'vendor_address2' => 'Vendor Apt/Suite',
     'partially_unapplied' => 'Partially Unapplied',
     'select_a_gmail_user' => 'Please select a user authenticated with Gmail',
     'list_long_press' => 'List Long Press',
     'show_actions' => 'Show Actions',
     'start_multiselect' => 'Start Multiselect',
     'email_sent_to_confirm_email' => 'An email has been sent to confirm the email address',
     'converted_paid_to_date' => 'Converted Paid to Date',
     'converted_credit_balance' => 'Converted Credit Balance',
     'converted_total' => 'Converted Total',
     'reply_to_name' => 'Reply-To Name',
     'payment_status_-2' => 'Partially Unapplied',
     'color_theme' => 'Color Theme',
     'start_migration' => 'Start Migration',
     'recurring_cancellation_request' => 'Request for recurring invoice cancellation from :contact',
     'recurring_cancellation_request_body' => ':contact from Client :client requested to cancel Recurring Invoice :invoice',
     'hello' => 'Hello',
     'group_documents' => 'Group documents',
     'quote_approval_confirmation_label' => 'Are you sure you want to approve this quote?',
     'migration_select_company_label' => 'Select companies to migrate',
     'force_migration' => 'Force migration',
     'require_password_with_social_login' => 'Require Password with Social Login',
     'stay_logged_in' => 'Stay Logged In',
     'session_about_to_expire' => 'Warning: Your session is about to expire',
     'count_hours' => ':count Hours',
     'count_day' => '1 Day',
     'count_days' => ':count Days',
     'web_session_timeout' => 'Web Session Timeout',
     'security_settings' => 'Security Settings',
     'resend_email' => 'Resend Email',
     'confirm_your_email_address' => 'Please confirm your email address',
     'freshbooks' => 'FreshBooks',
     'invoice2go' => 'Invoice2go',
     'invoicely' => 'Invoicely',
     'waveaccounting' => 'Wave Accounting',
     'zoho' => 'Zoho',
     'accounting' => 'Accounting',
     'required_files_missing' => 'Please provide all CSVs.',
     'migration_auth_label' => 'Let\'s continue by authenticating. (These credentials should be identical across systems)',
     'api_secret' => 'API secret',
     'migration_api_secret_notice' => 'You can find API_SECRET in the .env file or Invoice Ninja v5. If property is missing, leave field blank.',
     'billing_coupon_notice' => 'Your discount will be applied on the checkout.',
     'use_last_email' => 'Use last email',
     'activate_company' => 'Activate Company',
     'activate_company_help' => 'Enable emails, recurring invoices and notifications',
     'an_error_occurred_try_again' => 'An error occurred, please try again',
     'please_first_set_a_password' => 'Please first set a password',
     'changing_phone_disables_two_factor' => 'Warning: Changing your phone number will disable 2FA',
     'help_translate' => 'Help Translate',
     'please_select_a_country' => 'Please select a country',
     'disabled_two_factor' => 'Successfully disabled 2FA',
     'connected_google' => 'Successfully connected account',
     'disconnected_google' => 'Successfully disconnected account',
     'delivered' => 'Delivered',
     'spam' => 'Spam',
     'view_docs' => 'View Docs',
     'enter_phone_to_enable_two_factor' => 'Please provide a mobile phone number to enable two factor authentication',
     'send_sms' => 'Send SMS',
     'sms_code' => 'SMS Code',
     'connect_google' => 'Connect Google',
     'disconnect_google' => 'Disconnect Google',
     'disable_two_factor' => 'Disable Two Factor',
     'invoice_task_datelog' => 'Invoice Task Datelog',
     'invoice_task_datelog_help' => 'Add date details to the invoice line items',
     'promo_code' => 'Promo code',
     'recurring_invoice_issued_to' => 'Recurring invoice issued to',
     'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
     'move_top' => 'Move Top',
     'move_up' => 'Move Up',
     'move_down' => 'Move Down',
     'move_bottom' => 'Move Bottom',
     'body_variable_missing' => 'Error: the custom email must include a :body variable',
     'add_body_variable_message' => 'Make sure to include a :body variable',
     'view_date_formats' => 'View Date Formats',
     'is_viewed' => 'Is Viewed',
     'letter' => 'Letter',
     'legal' => 'Legal',
     'page_layout' => 'Page Layout',
     'portrait' => 'Portrait',
     'landscape' => 'Landscape',
     'upgrade_to_paid_plan' => 'Upgrade to a paid plan to enable the advanded settings',
     'invoice_payment_terms' => 'Invoice Payment Terms',
     'quote_valid_until' => 'Quote Valid Until',
     'no_headers' => 'No Headers',
     'add_header' => 'Add Header',
     'remove_header' => 'Remove Header',
     'return_url' => 'Return URL',
     'rest_method' => 'REST Method',
     'header_key' => 'Header Key',
     'header_value' => 'Header Value',
     'recurring_products' => 'Recurring Products',
     'promo_discount' => 'Promo Discount',
     'allow_cancellation' => 'Allow Cancellation',
     'per_seat_enabled' => 'Per Seat Enabled',
     'max_seats_limit' => 'Max Seats Limit',
     'trial_enabled' => 'Trial Enabled',
     'trial_duration' => 'Trial Duration',
     'allow_query_overrides' => 'Allow Query Overrides',
     'allow_plan_changes' => 'Allow Plan Changes',
     'plan_map' => 'Plan Map',
     'refund_period' => 'Refund Period',
     'webhook_configuration' => 'Webhook Configuration',
     'purchase_page' => 'Purchase Page',
     'email_bounced' => 'Email Bounced',
     'email_spam_complaint' => 'Spam Complaint',
     'email_delivery' => 'Email Delivery',
     'webhook_response' => 'Webhook Response',
     'pdf_response' => 'PDF Response',
     'authentication_failure' => 'Authentication Failure',
     'pdf_failed' => 'PDF Failed',
     'pdf_success' => 'PDF Success',
     'modified' => 'Modified',
     'subscription' => 'Subscription',
     'new_subscription' => 'New Subscription',
     'deleted_subscription' => 'Successfully deleted subscription',
     'removed_subscription' => 'Successfully removed subscription',
     'restored_subscription' => 'Successfully restored subscription',
     'search_subscription' => 'Search 1 Subscription',
     'search_subscriptions' => 'Search :count Subscriptions',
     'subdomain_is_not_available' => 'Subdomain is not available',
     'connect_gmail' => 'Connect Gmail',
     'disconnect_gmail' => 'Disconnect Gmail',
     'connected_gmail' => 'Successfully connected Gmail',
     'disconnected_gmail' => 'Successfully disconnected Gmail',
     'update_fail_help' => 'Changes to the codebase may be blocking the update, you can run this command to discard the changes:',
     'client_id_number' => 'Client ID Number',
     'count_minutes' => ':count Minutes',
     'password_timeout' => 'Password Timeout',
     'shared_invoice_credit_counter' => 'Shared Invoice/Credit Counter',
    'activity_80' => ':user created subscription :subscription',
    'activity_81' => ':user updated subscription :subscription',
    'activity_82' => ':user archived subscription :subscription',
    'activity_83' => ':user deleted subscription :subscription',
    'activity_84' => ':user restored subscription :subscription',

    'amount_greater_than_balance_v5' => 'The amount is greater than the invoice balance. You cannot overpay an invoice.',
    'click_to_continue' => 'Click to continue',

    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_invoice_created_subject' => 'Invoice :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_quote_created_subject' => 'Quote :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'notification_credit_created_subject' => 'Credit :invoice was created to :client',
    'migration_create_account_notice' => 'Please ensure you have created an account on the new platform first <a href="https://invoicing.co">here</a> , please ensure that the credentials are <b>identical</b> to your v4 credentials. Once the account has been created, you can start the migration process here.',
    'auth' => 'Authentication',
    'companies' => 'Select companies for migration',
    'activity_100' => ':user created recurring invoice :recurring_invoice',
    'activity_101' => ':user updated recurring invoice :recurring_invoice',
    'activity_102' => ':user archived recurring invoice :recurring_invoice',
    'activity_103' => ':user deleted recurring invoice :recurring_invoice',
    'activity_104' => ':user restored recurring invoice :recurring_invoice',

    'import_settings' => 'Import Settings',
    'json_file_missing' => 'Please provide the JSON file',
    'json_option_missing' => 'Please select to import the settings and/or data',
    'json' => 'JSON',
    'no_payment_types_enabled' => 'No payment types enabled',
    'wait_for_data' => 'Please wait for the data to finish loading',
    'net_total' => 'Net Total',
    'has_taxes' => 'Has Taxes',
    'import_customers' => 'Import Customers',
    'imported_customers' => 'Successfully started importing customers',
    'login_success' => 'Successful Login',
    'login_failure' => 'Failed Login',
    'exported_data' => 'Once the file is ready you"ll receive an email with a download link',
    'include_deleted_clients' => 'Include Deleted Clients',
    'include_deleted_clients_help' => 'Load records belonging to deleted clients',
    'step_1_sign_in' => 'Step 1: Sign In',
    'step_2_authorize' => 'Step 2: Authorize',
    'account_id' => 'Account ID',
    'migration_not_yet_completed' => 'The migration has not yet completed',
    'wizard_warning' => 'If you are migrating from the legacy version stop here and begin the migration. Once the migration completes click "Refesh" and use the dropdown in the top left corner to switch companies.',
    'show_task_end_date' => 'Show Task End Date',
    'show_task_end_date_help' => 'Enable specifying the task end date',
    'gateway_setup' => 'Gateway Setup',
    'preview_sidebar' => 'Preview Sidebar',
    'years_data_shown' => 'Years Data Shown',
    'ended_all_sessions' => 'Successfully ended all sessions',
    'end_all_sessions' => 'End All Sessions',
    'count_session' => '1 Session',
    'count_sessions' => ':count Sessions',
    'invoice_created' => 'Invoice Created',
    'quote_created' => 'Quote Created',
    'credit_created' => 'Credit Created',
    'enterprise' => 'Enterprise',
    'invoice_item' => 'Invoice Item',
    'quote_item' => 'Quote Item',
    'order' => 'Order',
    'search_kanban' => 'Search Kanban',
    'search_kanbans' => 'Search Kanban',
    'owner_upgrade_to_paid_plan' => 'The account owner can upgrade to a paid plan to enable the advanced advanced settings',
    'html_mode' => 'HTML Mode',
    'html_mode_help' => 'Preview updates faster but is less accurate',

);

return $LANG;

?>
